
* Master-file 
* User: Laura Pohlan (lpo)


cap log close
clear all

capture set more off 
clear matrix
set varabbrev off

********************************************************************************
* commands
*ssc install parallel
*ssc install radiusmatch

* Replication of estimation results
********************************************************************************
* set seed
****************************************************************************
set seed 123456

*set matsize
set matsize 10000

* global bootstrap runs
global bs_runs = 2500
global bs_runs_radius = 2500


********************************************************************************
**** call do files - data preparation                     **********************
********************************************************************************
*Set globals
global prog "Z:\Project_Unemployment\prog" 
global data "Z:\Project_Unemployment\data"
global log "Z:\Project_Unemployment\log"
global orig "Z:\Project_Unemployment\orig"
global results "Z:\Project_Unemployment\results"



* Data preparation PASS
do "$prog/lpo01_1_Prep_socio.do"     // Sociodemographics
do "$prog/lpo02_1_Prep_job_search.do"  // Job search
do "$prog/lpo03_1_Prep_labor_market.do"  // Labor market
do "$prog/lpo04_1_Prep_household.do"      // Household characteristics
do "$prog/lpo05_1_Prep_p_register.do"    // Save id of partner
do "$prog/lpo06_1_Prep_persnr_date.do"   // Save interview date in long und wide format
do "$prog/lpo07_1_Prep_Biospell.do" // Biospells


* Data preparation PASS-Adiab
do "$prog/lpo08_1_Prep_PASS_adiab_firm.do" // Firm data
do "$prog/lpo09_1_Prep_PASS_adiab.do"                            // Personal admin data 


* Mergen files
do "$prog/lpo10_1_Prep_merge.do"


* Final data
do "$prog/lpo11_1_Final_Data.do"                            // Final data set



********************************************************************************
* Estimation********************************************************************
********************************************************************************

* set globals for Matching

* Outcomes
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"
global d_outcomes "d_soz_teil_ges d_zufr_leben d_seele d_depindg2 d_zufr_lebensstandard d_anzahl_engefreunde d_engagement d_soz_pos d_selbstwirksamkeit"
global outcomes_lead1 "soz_teil_ges_lead1 zufr_leben_lead1 seele_lead1 depindg2_lead1 zufr_lebensstandard_lead1 anzahl_engefreunde_lead1 engagement_lead1 soz_pos_lead1 selbstwirksamkeit_lead1"
global d_2_outcomes "d_2_soz_teil_ges d_2_zufr_leben d_2_seele d_2_depindg2 d_2_zufr_lebensstandard d_2_anzahl_engefreunde d_2_engagement d_2_soz_pos d_2_selbstwirksamkeit"
global dlag_outcomes "dlag_soz_teil_ges dlag_zufr_leben dlag_seele dlag_depindg2 dlag_zufr_lebensstandard dlag_anzahl_engefreunde dlag_engagement dlag_soz_pos dlag_selbstwirksamkeit"
global dlag2_outcomes "dlag2_soz_teil_ges dlag2_zufr_leben dlag2_seele dlag2_depindg2 dlag2_zufr_lebensstandard dlag2_anzahl_engefreunde dlag2_engagement dlag2_soz_pos dlag2_selbstwirksamkeit"
global dlag3_outcomes "dlag3_soz_teil_ges dlag3_zufr_leben dlag3_seele dlag3_depindg2 dlag3_zufr_lebensstandard dlag3_anzahl_engefreunde dlag3_engagement dlag3_soz_pos dlag3_selbstwirksamkeit"

* control variables

* Initial outcome levels
global control_outcomes "soz_teil_ges zufr_leben_1 zufr_leben_2 zufr_leben_3 zufr_leben_4 seele depindg2_1 depindg2_2 depindg2_3 depindg2_4 depindg2_5 zufr_lebensstandard anz_engefreunde_p engagement soz_pos selbstwirksamkeit_med selbstwirksamkeit_high"

* Sociodemographics
global control_sozio "female age25_34 age35_44 age45_54 age55 mig_dummy famstand_verheiratet religion raucher_jemals gesund_einschr d_krankenhaus_l12"
global control_sozio_des "female age mig_dummy famstand_verheiratet religion raucher_jemals gesund_einschr d_krankenhaus_l12"
global control_educ "BA_lehre BA_meister BA_akademisch"
global control_educ_des "BA_keine BA_lehre BA_meister BA_akademisch"

* Subjective indicators
global control_sub_ind "work_attitude zufr_gesundheit"
global control_sub_ind_des "work_attitude zufr_gesundheit"

* Individual characteristics
global control_ind "$control_sozio $control_educ d_ostdeutschland $control_sub_ind"
global control_ind_des "$control_sozio_des $control_educ_des d_ostdeutschland $control_sub_ind_des"
global control_big5 "extraversion extraversion_mis tolerance tolerance_mis conscientiousness conscientiousness_mis neuroticism neuroticism_mis openess openess_mis"

* Household characteristics
global control_HH "einkommenHH1000_1500 einkommenHH1500_2000 einkommenHH2000_3000 einkommenHH3000 hhtyp_paarmitkindernu16 female_partner_hindu16 HHkind1 HHkind2 HHkind3more eigentum"
global control_HH_des "einkommenHH1000  einkommenHH1000_1500 einkommenHH1500_2000 einkommenHH2000_3000 einkommenHH3000 hhtyp_paarmitkindernu16 female_partner_hindu16 anzahl_kindHH eigentum"

* Partner
global control_partner "partner partner_BA_lehre partner_BA_akademisch_meister partner_BA_mis partner_espell partner_empl_mis"
global control_partner_des "partner partner_BA_keine partner_BA_lehre partner_BA_akademisch_meister partner_BA_mis partner_espell partner_empl_mis"

* Employment History
global espell_last "d_espell_soz_last espell_vz_last contract_permanent contract_permanent_mis d_espell_jobkl_last_agg_2 d_espell_jobkl_last_agg_3 d_espell_jobkl_last_agg_4 d_espell_jobkl_last_agg_5  espell_dauer_last_p25p50 espell_dauer_last_p50p75 espell_dauer_last_p75 espell_entgelt_last_p25p50 espell_entgelt_last_p50p75 espell_entgelt_last_p75"
global espell_last_des "d_espell_soz_last espell_vz_last contract_permanent contract_permanent_mis d_espell_jobkl_last_agg_1 d_espell_jobkl_last_agg_2 d_espell_jobkl_last_agg_3 d_espell_jobkl_last_agg_4 d_espell_jobkl_last_agg_5  espell_dauer_last espell_entgelt_last"

global firm_last "espell_betr_gr_last_10_k50 espell_betr_gr_last_50_k250 espell_betr_gr_last_250_k500 espell_betr_gr_last_500 d_espell_sectorkl_last_agg_2 d_espell_sectorkl_last_agg_3 d_espell_sectorkl_last_agg_4 d_espell_sectorkl_last_agg_5 d_espell_sectorkl_last_agg_6 d_espell_sectorkl_last_agg_7 d_espell_sectorkl_last_agg_8"
global firm_last_selbst "espell_betr_gr_last_10_k50 espell_betr_gr_last_50_k250 espell_betr_gr_last_250_k500 espell_betr_gr_last_500 d_espell_sectorkl_last_agg_2 d_espell_sectorkl_last_agg_3 d_espell_sectorkl_last_agg_4 d_espell_sectorkl_last_agg_5 d_espell_sectorkl_last_agg_6 d_espell_sectorkl_last_agg_7"
global firm_last_des "espell_betr_gr_last_k10 espell_betr_gr_last_10_k50 espell_betr_gr_last_50_k250 espell_betr_gr_last_250_k500 espell_betr_gr_last_500 d_espell_sectorkl_last_agg_1 d_espell_sectorkl_last_agg_2 d_espell_sectorkl_last_agg_3 d_espell_sectorkl_last_agg_4 d_espell_sectorkl_last_agg_5 d_espell_sectorkl_last_agg_6 d_espell_sectorkl_last_agg_7 d_espell_sectorkl_last_agg_8"
global firm_last_ext "espell_betr_gr_last_10_k50 espell_betr_gr_last_50_k250 espell_betr_gr_last_250_k500 espell_betr_gr_last_500 espell_betr_ml_last_p0p25 espell_betr_ml_last_p25p50 espell_betr_ml_last_p50p75 espell_betr_ml_last_p75 d_espell_sectorkl_last_agg_1 d_espell_sectorkl_last_agg_2 d_espell_sectorkl_last_agg_3 d_espell_sectorkl_last_agg_4 d_espell_sectorkl_last_agg_5 d_espell_sectorkl_last_agg_6 d_espell_sectorkl_last_agg_7 d_espell_sectorkl_last_agg_8"

global dauern "n_espell_soz espell_soz_dauer_p25p50 espell_soz_dauer_p50p75 espell_soz_dauer_p75 n_espell_ger espell_ger_dauer_p25p50 espell_ger_dauer_p50p75 espell_ger_dauer_p75 n_uspell uspell_dauer_p0p25 uspell_dauer_p25p50 uspell_dauer_p50p75 uspell_dauer_p75 n_nspell nspell_dauer_cum"
global dauern_des "n_espell_soz  espell_soz_dauer_cum n_espell_ger espell_ger_dauer_cum n_uspell uspell_dauer_cum n_nspell nspell_dauer_cum"

global control_empl_h "$espell_last $firm_last $dauern U_ratio"
global control_empl_h_selbst "$espell_last $firm_last_selbst $dauern U_ratio"
global control_empl_h_des "$espell_last_des $firm_last_des $dauern_des U_ratio"
global control_empl_h_ext "$espell_last $firm_last_ext $dauern U_ratio"

* Wave
global control_welle "welle2 welle3 welle4 welle5 welle6 welle7 welle8"

global control_all "$control_outcomes $control_ind $control_HH $control_partner $control_empl_h $control_welle"
global control_all_selbst "$control_outcomes $control_ind $control_HH $control_partner $control_empl_h_selbst  $control_welle"
global control_all_ext "$control_outcomes $control_ind $control_big5 $control_HH $control_partner $control_empl_h_ext $control_welle"
global control_all_1 "$control_ind $control_HH $control_partner $control_empl_h $control_welle"
global control_all_2 "$control_outcomes $control_ind $control_empl_h $control_welle"
global control_all_3 "$control_outcomes $control_ind $control_HH $control_partner $control_welle"
global control_all_des "$control_ind_des $control_HH_des $control_partner_des $control_empl_h_des welle1 $control_welle"
global control_all_test "$outcomes $control_ind_des $control_big5 $control_HH_des $control_partner_des $control_empl_h_des welle1 $control_welle"

global control_all_partner "$control_outcomes $control_ind $control_HH partner_BA_lehre partner_BA_akademisch_meister partner_espell partner_empl_mis  $control_empl_h $control_welle"

********************************************************************************
**** Descriptives *************************************************************
********************************************************************************

do "$prog/lpo12_2_Descriptives.do"


do "$prog/lpo13_2_Distribution_outcomes.do"

********************************************************************************
* Inverse Propensity Score Weighting********************************************
********************************************************************************


* Baseline specification
do "$prog/lpo14_3_IPW_diff_in_diff.do"
* Bootstrapped SE
do "$prog/lpo15_3_IPW_diff_in_diff_bs.do"

* Placebo Tests
do "$prog/lpo16_3_IPW_diff_in_diff_placebo.do"
do "$prog/lpo17_3_IPW_diff_in_diff_placebo_bs.do"
do "$prog/lpo18_3_Plot_placebo.do"

* Robustness Covariates/Sample
do "$prog/lpo19_3_IPW_diff_in_diff_control_sample.do"
do "$prog/lpo20_3_IPW_diff_in_diff_control_sample_bs.do"

* Robustness Checks
do "$prog/lpo21_3_IPW_diff_in_diff_model.do"
do "$prog/lpo22_3_IPW_diff_in_diff_model_bs.do"
do "$prog/lpo23_3_RadiusMatch_diff_in_diff.do"
do "$prog/lpo24_3_RadiusMatch_diff_in_diff_bs.do"


* Subgroups
do "$prog/lpo25_3_IPW_diff_in_diff_het_treat_socio.do"
do "$prog/lpo26_3_BS_diff_het_treat_socio.do"
do "$prog/lpo27_3_IPW_diff_in_diff_het_treat_job.do"
do "$prog/lpo28_3_BS_diff_het_treat_job.do"

* Mechanism with Fixed Effects regression
do "$prog/lpo29_3_Deprivation.do"
do "$prog/lpo30_3_Deprivation_bs.do"

do "$prog/lpo31_3_Relation_outcomes.do"
do "$prog/lpo32_3_Employment_prospects"
do "$prog/lpo33_3_mechanism_FE.do"

* Comparison conditional and unconditional DiD
do "$prog/lpo34_3_diff_in_diff.do"

* IPW
do "$prog/lpo35_3_IPW"

* Additional analyses
do "$prog/lpo36_3_Additional_Analyses"

********************************************************************************










