cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo01_1_Prep_socio.log", replace

* Content: Preparation PASS - Sociodemographics

clear all
capture set more off 

use "$orig/PENDDAT.dta", clear


********************************************************************************
****  Date                                         **********************
********************************************************************************

rename pnr persnr
rename pintjahr year
rename pintmon month
rename pinttag day
rename pintdat date

gen edate = mdy(month, day, year)

format edate %d
format date %d

drop date

rename edate date
label var date "Datum"

order persnr- day date

********************************************************************************
****   Age, Sex, etc.                                   **********************
********************************************************************************
gen female = 1 if zpsex == 2
replace female = 0 if zpsex == 1
label var female "Female"

*Sex should be constant over time, females have priority

by persnr: egen female_max = max(female)
replace female = female_max
drop female_max

sort persnr welle

gen age = palter
replace age = zpalthh if age <=0 & zpalthh > 0
replace age = . if age <= 0
label var age "Age"

* Fuer 4 von 16 Personen kann das Alter aufgefuellt werden:
bysort persnr (welle): replace age = age[_n+1]-1 if age[_n+1]!=. & age == .

********************************************************************************

* Groesse und Gewicht

rename PG1285 height
replace height = . if height < 0

sort persnr welle
by persnr (welle): egen max_height = max(height)
replace height = max_height

drop max_height

* Gewichtsangaben gibt es nur im Jahr 2008, 2009 und 2012

rename PG1290 weight
replace weight = . if weight < 0

gen weight_08_09 = weight if weight!=. & (year == 2008 | year == 2009)
gen weight_12 = weight if weight!=. & year == 2012


bysort persnr (welle): replace weight_08_09 = weight_08_09[_n-1] if weight_08_09==.
bysort persnr (welle): replace weight_12 = weight_12[_n-1] if weight_12==.

gsort persnr -welle
by persnr: replace weight_08_09 = weight_08_09[_n-1] if weight_08_09==.
by persnr: replace weight_12 = weight_12[_n-1] if weight_12==.

sort persnr welle

********************************************************************************
****   Gesundheit, Alkohol und Sport                                ************
********************************************************************************
* Anzahl Arztbesuche in den letzten 3 Monaten
rename PG0100 arztbesuch_anz
replace arztbesuch_anz = . if arztbesuch_anz < 0

* Frage: Dummy Krankenhausbesuchen in letzten 12 Monaten
rename PG0200 krankenhaus_l12
replace krankenhaus_l12 = 0 if krankenhaus_l12 == 2 | krankenhaus_l12 == -3
replace krankenhaus_l12 = . if krankenhaus_l12 < 0

* Frage: Anzahl Krankenhausaufenthalte in den letzten 12 Monaten
rename PG0400 krankenhaus_anz_l12
replace krankenhaus_anz_l12 = 0 if krankenhaus_l12 == 0
replace krankenhaus_anz_l12 = . if krankenhaus_anz_l12 <0

* Frage: anerkannte behinderung_anerkannt
rename PG0500 behinderung_anerkannt
replace behinderung_anerkannt = 0 if behinderung_anerkannt == 2 | behinderung_anerkannt == -3
replace behinderung_anerkannt = . if behinderung_anerkannt < 0


* Frage: schwerwiegende gesundheitl. Einschraenkungen
rename PG0800 gesund_einschr_schwer
replace gesund_einschr_schwer = 0 if gesund_einschr_schwer == 2 | gesund_einschr_schwer == -3
replace gesund_einschr_schwer = 1 if behinderung_anerkannt == 1 | behinderung_anerkannt == 3
replace gesund_einschr_schwer = . if gesund_einschr_schwer < 0

replace behinderung_anerkannt = 0 if behinderung_anerkannt == 3

* Frage: Art der schwerwiegenden gesundheitl. Einschraenkung
rename PG0900a beh_koerperlich
replace beh_koerperlich = 0 if beh_koerperlich == 2 | beh_koerperlich == -3
replace beh_koerperlich = . if beh_koerperlich <0

rename PG0900b beh_seh_hoer
replace beh_seh_hoer = 0 if beh_seh_hoer == 2 | beh_seh_hoer ==  -3
replace beh_seh_hoer = . if beh_seh_hoer <0

rename PG0900c beh_anfallsl
replace beh_anfallsl = 0 if beh_anfallsl == 2 | beh_anfallsl == -3
replace beh_anfallsl = . if beh_anfallsl <0

rename PG0900d beh_innen
replace beh_innen = 0 if beh_innen == 2 | beh_innen == -3
replace beh_innen = . if beh_innen <0

rename PG0900e beh_psychisch
replace beh_psychisch = 0 if beh_psychisch == 2 | beh_psychisch == -3
replace beh_psychisch = . if beh_psychisch <0

rename PG0900f beh_sonst
replace beh_sonst = 0 if beh_sonst == 2 | beh_sonst == -3
replace beh_sonst = . if beh_sonst <0


* Frage: seelischen Probleme in letzten 4 Wochen
rename PG1100 seele
replace seele = . if seele < 0

gen seele_nicht = (seele == 1) if seele != .
label var seele_nicht "No mental problems"
gen seele_wenig = (seele == 2) if seele != .
label var seele_wenig "Few mental problems"
gen seele_mittel = (seele == 3) if seele != .
label var seele_mittel "Medium mental problems"
gen seele_viel = (seele == 4) if seele != .
label var seele_viel "High mental problems"
gen seele_sehr = (seele == 5) if seele != .
label var seele_sehr "Strong mental problems"

* Frage subjektive Einschaetzung des Gesundheitszustands
rename PG1200 gesund_subjectiv
replace gesund_subjectiv = . if gesund_subjectiv < 0

* andere Gesundheitsfragen werden in den meisten Wellen nicht erhoben.

* Frage Sport
rename PG1235 sports
replace sports = . if sports < 0

replace sports = PA0950h if sports == . & PA0950h > 0

gen sports_nie = (sports == 5) if sports != .
label var sports_nie "No sport"
gen sports_selten = (sports == 4) if sports != .
label var sports_selten "Few sport"
gen sports_1weekly = (sports == 3) if sports != .
label var sports_1weekly "Once a week sport"
gen sports_mweekly = (sports == 2) if sports != .
label var sports_mweekly "More than once a week sport"
gen sports_daily = (sports == 1) if sports != .
label var sports_daily "Daily sport"



* Frage Alkohol
rename PG1240a alkohol
replace alkohol = . if alkohol < 0

gen alkohol_nie = (alkohol == 5) if alkohol != .
label var alkohol_nie "No alkohol"
gen alkohol_selten = (alkohol == 4) if alkohol != .
label var alkohol_selten "Sometimes alkohol"
gen alkohol_1weekly = (alkohol == 3) if alkohol != .
label var alkohol_1weekly "Once a week alkohol"
gen alkohol_mweekly = (alkohol == 2) if alkohol != .
label var alkohol_mweekly "More than once a week alkohol"
gen alkohol_daily = (alkohol == 1) if alkohol != .
label var alkohol_daily "Daily alkohol"


* Frage spirituosen
rename PG1240b spirituosen
replace spirituosen = . if spirituosen < 0

gen spirituosen_nie = (spirituosen == 5) if spirituosen != .
label var spirituosen_nie "No liquor"
gen spirituosen_selten = (spirituosen == 4) if spirituosen != .
label var spirituosen_selten "Sometimes liquor"
gen spirituosen_1weekly = (spirituosen == 3) if spirituosen != .
label var spirituosen_1weekly "Once a week liquor"
gen spirituosen_mweekly = (spirituosen == 2) if spirituosen != .
label var spirituosen_mweekly "More than once a week liquor"
gen spirituosen_daily = (spirituosen == 1) if spirituosen != .
label var spirituosen_daily "daily liquor"

* Frage rauchen

rename PG1270 anz_zigaretten_proTag
replace anz_zigaretten_proTag = 0 if anz_zigaretten_proTag == -3 | anz_zigaretten_proTag == -5
replace anz_zigaretten_proTag = 99 if anz_zigaretten_proTag == -6
replace anz_zigaretten_proTag = . if anz_zigaretten_proTag < 0

rename PG1255 raucher
replace raucher = 0 if raucher == -5
replace raucher = . if raucher < 0
replace raucher = 0 if raucher == 2
replace raucher = 0 if anz_zigaretten_proTag == 0
replace raucher = 1 if anz_zigaretten_proTag > 0 & anz_zigaretten_proTag != .


rename PG1245 raucher_jemals
replace raucher_jemals = 0 if raucher_jemals == -3
replace raucher_jemals = . if raucher_jemals < 0
replace raucher_jemals = 0 if raucher_jemals == 2
replace raucher_jemals = 1 if raucher_jemals ==. & raucher == 1

sort persnr welle
by persnr (welle): egen max_raucher_jemals = max(raucher_jemals)

replace raucher_jemals = max_raucher_jemals
drop max_raucher_jemals


* Frage Krankenversicherung
rename PG1301 krankenvers
replace krankenvers = . if krankenvers < 0

gen gesetzlichversichert = (krankenvers==1) if krankenvers!=.
label var gesetzlichversichert "Legal insurance"
gen privatversichert = (krankenvers==2 | krankenvers==3) if krankenvers!=.
label var privatversichert "Privat insurance"
gen sonstigversichert = (krankenvers==4 | krankenvers==5) if krankenvers!=.
label var sonstigversichert "Else insurance"
*lpo: die 6.Kategorie lautet "nicht versichert"
gen nichtversichert = (krankenvers==6) if krankenvers!=.
label var nichtversichert "no insurance"


********************************************************************************
****   Koerper und Psyche                                  **********************
********************************************************************************
rename pcs body_scala
replace body_scala = . if body_scala < 0

rename mcs psyche_scala
replace psyche_scala = . if psyche_scala < 0



********************************************************************************
****   Religion                                         **********************
********************************************************************************

rename PD0200 religion
replace religion = . if religion < 0

replace religion = 0 if religion == 2

replace PD0300 = . if PD0300 < 0

gen religion_rk = (PD0300 == 1) if PD0300 != .
label var religion_rk "Roman Catholic"
gen religion_ev = (PD0300 == 2) if PD0300 != .
label var religion_ev "Protestant"
gen religion_ox = (PD0300 == 3) if PD0300 != .
label var religion_ox "Orthodox"
gen religion_is = (PD0300 == 4) if PD0300 != .
label var religion_is "Islamic"
gen religion_ac = (PD0300 == 5) if PD0300 != .
label var religion_ac "Else Catholic"
gen religion_anc = (PD0300 == 6) if PD0300 != .
label var religion_anc "Else non-Catholic"

foreach var in religion_rk religion_ev religion_ox religion_ac religion_anc religion_is {
replace `var' = 0 if `var' == . & religion == 0
}

********************************************************************************
****   Partner in HH                                      **********************
********************************************************************************
gen partner = 1 if epartner == 1 | apartner == 1
replace partner = 0 if epartner == 0 & apartner == 0


********************************************************************************
****   Familienstand                                   **********************
********************************************************************************
replace famstand = 1 if famstand == -3
replace famstand = . if famstand < 0

gen famstand_ledig = (famstand == 1) if famstand!=.
label var famstand_ledig "Single"

gen famstand_verheiratet = (famstand == 2) if famstand!=.
label var famstand_verheiratet "Married"

gen famstand_sonst = (famstand == 3 | famstand == 4 | famstand == 5 )  if famstand!=.
label var famstand_sonst "Married - separated"

********************************************************************************
****   Kinder                                            **********************
********************************************************************************
rename kindzges anzahl_kindHH
replace anzahl_kindHH = 0 if anzahl_kindHH == -3
replace anzahl_kindHH = . if anzahl_kindHH < 0

* Auffüllen falls missing und welle - 1 == welle + 1

bysort persnr (welle): replace anzahl_kindHH = anzahl_kindHH[_n+1] if anzahl_kindHH[_n+1] == 0 & anzahl_kindHH == .
bysort persnr (welle): replace anzahl_kindHH = anzahl_kindHH[_n-1] if anzahl_kindHH[_n-1] != . & anzahl_kindHH == . 

********************************************************************************
****   Bildung                                           **********************
********************************************************************************

* Bei der Schulbildung waren manche Kategorien noch nicht richtig benannt
replace schul2 = . if schul2 < 0
replace schul2 = . if schul2 == 8 | schul2 == 9

gen SA_schueler = (schul2 == 1) if schul2 != .
label var SA_schueler "Student"
gen SA_keiner = (schul2 == 2) if schul2 != .
label var SA_keiner "No school degree"
gen SA_sonder_hauptschule = (schul2 == 3 |schul2 == 4) if schul2 != .
label var SA_sonder_hauptschule "Secondary school"
gen SA_realschule = (schul2 == 5) if schul2 != .
label var SA_realschule "Intermediate school"
gen SA_gymnasium = (schul2 == 6 | schul2 == 7) if schul2 != .
label var SA_gymnasium "High school"

rename schulabj year_schule
replace year_schule = . if year_schule < 0

replace beruf2 = . if beruf2 < 0 | beruf2 == 12 | beruf2 == 13
gen BA_keine = (beruf2 == 1 | beruf2 == 2) if beruf2 != .
gen BA_lehre = (beruf2 == 3 | beruf2 == 4 | beruf2 == 5 | beruf2 == 6) if beruf2 != .
gen BA_meister = (beruf2 == 7 | beruf2 == 8 ) if beruf2 != .
gen BA_akademisch = (beruf2 == 9 | beruf2 == 10 | beruf2 == 11 ) if beruf2 != .

replace SA_gymnasium = 1 if BA_akademisch == 1 & (SA_gymnasium == . | schul2 == 8 | schul2 == 9)

*** Bildungsjahre
rename bilzeit years_educ
replace years_educ = . if years_educ < 0

********************************************************************************
****   Bildung  der Eltern                                  **********************
********************************************************************************
* degree Mutter
replace mberuf2 = . if mberuf2 < 0 | mberuf2 == 12 | mberuf2 == 13
gen BA_M_keine = (mberuf2 == 1 | mberuf2 == 2) if mberuf2 != .
gen BA_M_lehre = (mberuf2 == 3 | mberuf2 == 4 | mberuf2 == 5 | mberuf2 == 6) if mberuf2 != .
gen BA_M_meister = (mberuf2 == 7 | mberuf2 == 8 ) if mberuf2 != .
gen BA_M_akademisch = (mberuf2 == 9 | mberuf2 == 10 | mberuf2 == 11 ) if mberuf2 != .


*** Bildungsjahre der Mutter
rename mbilzeit years_educ_mother
replace years_educ_mother = . if years_educ_mother < 0

* degree Vater
replace vberuf2 = . if vberuf2 < 0 | vberuf2 == 12 | vberuf2 == 13
gen BA_V_keine = (vberuf2 == 1 | vberuf2 == 2) if vberuf2 != .
gen BA_V_lehre = (vberuf2 == 3 | vberuf2 == 4 | vberuf2 == 5 | vberuf2 == 6) if vberuf2 != .
gen BA_V_meister = (vberuf2 == 7 | vberuf2 == 8 ) if vberuf2 != .
gen BA_V_akademisch = (vberuf2 == 9 | vberuf2 == 10 | vberuf2 == 11 ) if vberuf2 != .

*** Bildungsjahre des Vater
rename vbilzeit years_educ_father
replace years_educ_father = . if years_educ_father < 0

********************************************************************************
****   Staatsangehoerigkeit/Migration                         **********************
********************************************************************************
rename ostaatan nationality
replace nationality = . if nationality < 0

gen german = (nationality == 1) if nationality !=.
label var german "German"
gen turkey = (nationality == 2)
label var turkey "Turkey"
gen west_europe = (nationality == 3 | nationality == 4 | nationality == 5 | nationality == 6 | nationality == 7 | nationality == 8 | nationality == 9) if nationality !=.
label var west_europe "IT, GR, FR, OeST, PG, BE, SK, GB, IR"
gen east_europe = (nationality == 10 | nationality == 11 | nationality == 12 | nationality == 13 | nationality == 19) if nationality !=.
label var east_europe "PL, JU, RU, UN, TS, SL, rest Europe"
gen asia = (nationality == 14 | nationality == 22) if nationality !=.
label var asia "Asia"
gen usa = (nationality == 21) if nationality !=.
label var usa "American"
gen africa = (nationality == 20) if nationality !=.
label var africa "African"
gen nationality_sonst = (nationality == 23) if nationality !=.
label var nationality_sonst "Else nationality"


replace migration = . if migration < 0
tab migration

gen mig_dummy = (migration > 1) if migration != .
replace mig_dummy = 0 if german == 1
replace mig_dummy = 1 if german == 0
label var mig_dummy "Immigrant"

gen mig_first = (migration == 2) if migration != .
replace mig_first = 0 if german == 1 & mig_first == .
label var mig_first "First generation"

gen mig_second = (migration == 3) if migration != .
replace mig_second = 0 if german == 1 & mig_second == .
label var mig_second "Second generation"

gen mig_third = (migration == 4) if migration != .
replace mig_third = 0 if german == 1 & mig_third == .
label var mig_third "Third generation"


********************************************************************************
****   Kompetenzen                                         *********************
********************************************************************************
* 4-er Skala von trifft voll und ganz zu bis trifft ueberhaupt nicht zu

rename PEO0100a kompetenz_1_old
replace kompetenz_1_old = . if kompetenz_1_old < 0

rename PEO0100b kompetenz_2_old
replace kompetenz_2_old = . if kompetenz_2_old < 0

rename PEO0100c kompetenz_3_old
replace kompetenz_3_old = . if kompetenz_3_old < 0

rename PEO0100d kompetenz_4_old
replace kompetenz_4_old = . if kompetenz_4_old < 0

rename PEO0100e kompetenz_5_old
replace kompetenz_5_old = . if kompetenz_5_old < 0

* Umkodieren der Skala von 1: trifft ueberhaupt nicht zu bis 4: trifft voll und ganz zu

forval i = 1/5 {
gen kompetenz_`i' = 1 if kompetenz_`i'_old == 4
replace kompetenz_`i' = 2 if kompetenz_`i'_old == 3
replace kompetenz_`i' = 3 if kompetenz_`i'_old == 2
replace kompetenz_`i' = 4 if kompetenz_`i'_old == 1
}

********************************************************************************
****   BIG 5                                               *********************
********************************************************************************
foreach var in PEO1400a PEO1400b PEO1400c PEO1400d PEO1400e PEO1400f PEO1400g PEO1400h PEO1400i PEO1400j PEO1400k PEO1400l PEO1400m PEO1400n PEO1400o PEO1400p PEO1400q PEO1400r PEO1400s PEO1400t PEO1400u{
replace `var' = . if `var' < 0
}

sort persnr welle
foreach var in PEO1400a PEO1400b PEO1400c PEO1400d PEO1400e PEO1400f PEO1400g PEO1400h PEO1400i PEO1400j PEO1400k PEO1400l PEO1400m PEO1400n PEO1400o PEO1400p PEO1400q PEO1400r PEO1400s PEO1400t PEO1400u{
by persnr (welle): egen max_`var' = max(`var')
}

foreach var in PEO1400a PEO1400b PEO1400c PEO1400d PEO1400e PEO1400f PEO1400g PEO1400h PEO1400i PEO1400j PEO1400k PEO1400l PEO1400m PEO1400n PEO1400o PEO1400p PEO1400q PEO1400r PEO1400s PEO1400t PEO1400u{
replace `var' = max_`var'
}

rename PEO1400a extraversion1
rename PEO1400b tolerance1
rename PEO1400c conscientiousness1
rename PEO1400d neuroticism1
rename PEO1400e openess1

rename PEO1400f extraversion2
rename PEO1400g tolerance2
rename PEO1400h conscientiousness2
rename PEO1400i neuroticism2
rename PEO1400j openess2

rename PEO1400k extraversion3
rename PEO1400l tolerance3
rename PEO1400m conscientiousness3
rename PEO1400n neuroticism3
rename PEO1400o openess3

rename PEO1400p extraversion4
rename PEO1400q tolerance4
rename PEO1400r conscientiousness4
rename PEO1400s neuroticism4
rename PEO1400t openess4

rename PEO1400u openess5

gen extraversion = -extraversion1 + extraversion2 -extraversion3 + extraversion4
gen tolerance    = -tolerance1 + tolerance2 -tolerance3 -tolerance4
gen conscientiousness = conscientiousness1 - conscientiousness2 +conscientiousness3 + conscientiousness4
gen neuroticism = neuroticism1 - neuroticism2 + neuroticism3 + neuroticism4
gen openess = openess1 + openess2 + openess3 + openess4 - openess5

label var extraversion "B5 Extraversion"
label var  tolerance "B5 Tolerance"
label var conscientiousness "B5 Conscientiousness"
label var neuroticism "B5 Neuroticism"
label var openess "B5 Openess"


********************************************************************************
****  Erinnerungsvermoegen                                **********************
********************************************************************************
foreach var in PME0200a PME0200b PME0200c PME0200d PME0200e PME0200f PME0200g PME0200h PME0200i PME0200j PME0300a PME0300b PME0300c PME0300d PME0300e PME0300f PME0300g PME0300h PME0300i PME0300j{
replace `var' = 0 if `var' == -6
}

foreach var in PME0200a PME0200b PME0200c PME0200d PME0200e PME0200f PME0200g PME0200h PME0200i PME0200j PME0300a PME0300b PME0300c PME0300d PME0300e PME0300f PME0300g PME0300h PME0300i PME0300j{
gen `var'_verweigert = (`var' == -5)
}

foreach var in PME0200a PME0200b PME0200c PME0200d PME0200e PME0200f PME0200g PME0200h PME0200i PME0200j PME0300a PME0300b PME0300c PME0300d PME0300e PME0300f PME0300g PME0300h PME0300i PME0300j{
replace `var' = . if `var' < 0
}

foreach var in PME0200a PME0200b PME0200c PME0200d PME0200e PME0200f PME0200g PME0200h PME0200i PME0200j PME0300a PME0300b PME0300c PME0300d PME0300e PME0300f PME0300g PME0300h PME0300i PME0300j{
replace `var' = 0 if `var' == 2
}

gen sum_genanntes_wort = PME0200a + PME0200b + PME0200c + PME0200d + PME0200e + PME0200f + PME0200g + PME0200h + PME0200i + PME0200j
gen sum_erinnertes_wort = PME0300a + PME0300b + PME0300c + PME0300d + PME0300e + PME0300f + PME0300g + PME0300h + PME0300i + PME0300j


gen genanntes_wort_share = sum_genanntes_wort/10
label var genanntes_wort_share "Cognition 1 - named words"
gen erinnertes_wort_share = sum_erinnertes_wort/10
label var erinnertes_wort_share "Cognition 2 - remembered words"

sort persnr welle
by persnr (welle): egen max_genanntes_wort_share=max(genanntes_wort_share)
replace genanntes_wort_share = max_genanntes_wort_share

by persnr (welle): egen max_erinnertes_wort_share=max(erinnertes_wort_share)
replace erinnertes_wort_share = max_erinnertes_wort_share

gen genanntes_wort_share_verw = PME0200j_verweigert
label var genanntes_wort_share_verw "Cognition 1 - verweigert"

gen erinnertes_wort_share_verw = PME0300j_verweigert
label var erinnertes_wort_share_verw "Cognition 2 - verweigert"

gen genanntes_wort_share_mis = (genanntes_wort_share == .)
replace genanntes_wort_share_mis = 0 if genanntes_wort_share_verw == 1
label var genanntes_wort_share_mis "Cognition 1 - missing"

gen erinnertes_wort_share_mis = (erinnertes_wort_share == .)
replace erinnertes_wort_share_mis = 0 if erinnertes_wort_share_verw == 1
label var erinnertes_wort_share_mis "Cognition 2 - missing"

gen genanntes_wort_share_medium = (genanntes_wort_share >= .6 & genanntes_wort_share <= .8) if genanntes_wort_share != .
label var genanntes_wort_share_medium "Cognition 1 - medium"
gen genanntes_wort_share_high = (genanntes_wort_share > .8) if genanntes_wort_share != .
label var genanntes_wort_share_high "Cognition 1 - high"

gen erinnertes_wort_share_medium = (erinnertes_wort_share >= .5 & erinnertes_wort_share <= .7) if erinnertes_wort_share != .
label var erinnertes_wort_share_medium "Cognition 2 - medium"
gen erinnertes_wort_share_high = (erinnertes_wort_share > .7) if erinnertes_wort_share != .
label var erinnertes_wort_share_high "Cognition 2 - high"

gen genanntes_wort_share2 = genanntes_wort_share*genanntes_wort_share
gen erinnertes_wort_share2 = erinnertes_wort_share*erinnertes_wort_share



********************************************************************************
*Soziale Teilhabe***************************************************************
********************************************************************************
* Dazugehoerigkeitsgefuehl steig mit Skala (1-10)
rename PA0800 soz_teil_ges
replace soz_teil_ges = . if soz_teil_ges<0

* oben/unten steig mit Skala (1-10)
rename PA0900 soz_pos
replace soz_pos = . if soz_pos <0


********************************************************************************
*Zufriedenheit******************************************************************
********************************************************************************
* Zufriedenheit steig mit Skala (1-10)

* Zufriedenheit mit Gesundheit
rename  PA0100 zufr_gesundheit
replace zufr_gesundheit = . if zufr_gesundheit<0

* Zufriedenheit mit Wohnung
rename  PA0200 zufr_wohnung
replace zufr_wohnung = . if zufr_wohnung<0

* Zufriedenheit mit Lebensstandard
rename  PA0300 zufr_lebensstandard
replace zufr_lebensstandard = . if zufr_lebensstandard<0


********************************************************************************
*Generelle Lebenszufriedenheit**************************************************
********************************************************************************
* Zufriedenheit steigt mit Skala (1-10)

rename PA1000 zufr_leben
replace zufr_leben = . if zufr_leben<0

********************************************************************************
*Engagement*********************************************************************
********************************************************************************
rename PSK0400a eng_gewerkschaft
rename PSK0400b eng_partei
rename PSK0400c eng_kirche
rename PSK0400d eng_verein
rename PSK0400e eng_sonst

replace eng_gewerkschaft = 0 if eng_gewerkschaft ==2 | eng_gewerkschaft == -5
replace eng_gewerkschaft = . if eng_gewerkschaft <0

replace eng_partei = 0 if eng_partei ==2 | eng_partei == -5
replace eng_partei = . if eng_partei <0

replace eng_kirche = 0 if eng_kirche ==2 | eng_kirche == -5
replace eng_kirche = . if eng_kirche <0

replace eng_verein = 0 if eng_verein ==2 | eng_verein == -5
replace eng_verein = . if eng_verein <0

replace eng_sonst = 0 if eng_sonst ==2 | eng_sonst == -5
replace eng_sonst = . if eng_sonst <0

********************************************************************************
*Enge Freunde*******************************************************************
********************************************************************************
rename PSK0100 engefreunde
replace engefreunde = . if engefreunde<0
replace engefreunde = 0 if engefreunde==2

rename PSK0200 anzahl_engefreunde
replace anzahl_engefreunde = . if anzahl_engefreunde<0
replace anzahl_engefreunde = 0 if engefreunde==0

********************************************************************************
*Haufigkeit Konflikte***********************************************************
********************************************************************************
* 5-er Skala: 1: sehr haeufig - 5: nie
rename  PSK0300 konflikte_haeufigkeit
replace konflikte_haeufigkeit = . if konflikte_haeufigkeit < 0


********************************************************************************
**** Auffuellen mit plausiblen Werten                      **********************
********************************************************************************
sort persnr welle

* Soziodemo
foreach var in religion religion_rk religion_ev religion_ox religion_is religion_ac religion_anc SA_schueler SA_sonder_hauptschule SA_realschule SA_gymnasium /*
*/BA_keine BA_lehre BA_meister BA_akademisch BA_M_keine BA_M_lehre BA_M_meister BA_M_akademisch BA_V_keine BA_V_lehre BA_V_meister BA_V_akademisch /*
*/german turkey west_europe east_europe usa africa nationality_sonst mig_dummy mig_first mig_second mig_third {
by persnr (welle): replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=.
}


gsort persnr -welle

* Soziodemo
foreach var in religion religion_rk religion_ev religion_ox religion_is religion_ac religion_anc /*
*/BA_keine BA_lehre BA_meister BA_akademisch BA_M_keine BA_M_lehre BA_M_meister BA_M_akademisch BA_V_keine BA_V_lehre BA_V_meister BA_V_akademisch /*
*/german turkey west_europe east_europe usa africa nationality_sonst mig_dummy mig_first mig_second mig_third {
by persnr: replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=.
}


sort persnr welle


********************************************************************************
****  loeschen von Variablen                               **********************
********************************************************************************

*drop PD* PR* PA* PS* PB* PE* PM* PG* PP* PS* PE* PQ* PT* PL* max_*
drop PD* PA* PS* PB* PE* PM* PG* PP* PS* PE* PT* PL* max_*

drop pintmod- palter

drop RegP0100- epartner

drop halg2s05- schul2

drop berabj casmin

drop mstib- vberuf1

drop vstib- ogebland

drop ozulanda- ozulandf



sort persnr welle

* save data

save "$data/soziodemo.dta", replace

********************************************************************************

log close





