cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo02_1_Prep_job_search.log", replace

* Content: Preparation PASS - Job search

clear all
capture set more off // damit das Programm durchlaeuft

use "$orig/PENDDAT.dta", clear

********************************************************************************
****  Date                                         **********************
********************************************************************************

rename pnr persnr
rename pintjahr year
rename pintmon month
rename pinttag day
rename pintdat date

gen edate = mdy(month, day, year)

format edate %d
format date %d

drop date

rename edate date
label var date "Datum"

order persnr- day date


********************************************************************************
****   Arbeitssuche von Erwerbstaetigen Personen           **********************
********************************************************************************
* Arbeitssuche nach 2 Kategorien unterschieden
rename PAS0100 suche_erw
replace suche_erw  = . if suche_erw  < 0
tab suche_erw

* Arbeitssuche ja/nein (Dummy)
gen suche_erw_d = ((suche_erw == 1 | suche_erw == 2 | suche_erw == 4) ) & suche_erw !=.
replace suche_erw_d = . if suche_erw == .
label var suche_erw_d "Job search employed"
tab suche_erw_d

* Dauer der Arbeitssuche bis zum Zeitpunkt des Interviews
rename PAS0200a suche_erw_month
rename PAS0200b suche_erw_year

	tab suche_erw_month
	replace suche_erw_month = . if suche_erw_month < 0
	replace suche_erw_year = . if suche_erw_year < 0

	* replace Quartalsangaben zum ersten Quartalsmonat
	replace suche_erw_month = 1 if suche_erw_month == 21
	replace suche_erw_month = 4 if suche_erw_month == 24
	replace suche_erw_month = 7 if suche_erw_month == 27
	replace suche_erw_month = 10 if suche_erw_month == 30
	replace suche_erw_month = 12 if suche_erw_month == 32


gen suche_erw_date = mdy(suche_erw_month, 1, suche_erw_year)
label var suche_erw_date "Datum der Erwerbssuche"

* lpo: Format f??atum
format suche_erw_date %d

gen suche_erw_dauer = date - suche_erw_date
label var suche_erw_dauer "Dauer der Arbeitsplatzsuche bis zum Interview"


* Gruende fuer die Arbeitsplatzsuche
foreach var in PAS0300a PAS0300b PAS0300c PAS0300d PAS0300e PAS0300f PAS0300g PAS0300h{
replace `var' = . if `var' < 0
}

foreach var in PAS0300a PAS0300b PAS0300c PAS0300d PAS0300e PAS0300f PAS0300g PAS0300h{
replace `var' = 0 if `var' == 2
}

rename PAS0300a suche_erw_geink
rename PAS0300b suche_erw_gpendel
rename PAS0300c suche_erw_gjobend
rename PAS0300d suche_erw_gzeit
rename PAS0300e suche_erw_gsicherheit
rename PAS0300f suche_erw_glohn
rename PAS0300g suche_erw_gbeding
rename PAS0300h suche_erw_gteatigk

sum such*


********************************************************************************
****   Arbeitssuche von Nicht-Erwerbstaetigen Personen     **********************
********************************************************************************
rename PAS0400 suche
label var suche "Job search unemployed"

replace suche = . if suche < 0
replace suche = 0 if suche == 2
tab suche
tab suche if year < 2010


* Dauer der Arbeitssuche bis zum Zeitpunkt des Interviews
rename PAS0500a suche_month
rename PAS0500b suche_year

	tab suche_month, nol
	replace suche_month = . if suche_month < 0
	replace suche_year = . if suche_year < 0

	* replace Quartalsangaben zum ersten Quartalsmonat
	replace suche_month = 1 if suche_month == 21
	replace suche_month = 4 if suche_month == 24
	replace suche_month = 7 if suche_month == 27
	replace suche_month = 10 if suche_month == 30
	replace suche_month = 12 if suche_month == 32


gen suche_date = mdy(suche_month, 1, suche_year)
label var suche_date "Datum Erwerbssuche von Nicht-Erwerbst."

* lpo: Format fuer datum
format suche_date %d

gen suche_dauer = date - suche_date
label var suche_dauer "Dauer der Arbeitsplatzsuche bis zum Interview"
sum suche_dauer

* lpo: einmal betr? die Suchdauer -38. Ich setze diesen Wert auf missing
replace suche_dauer = . if suche_dauer < 0

* Kann eine moegliche Erwerbstaetigkeit innerhalb der naechsten 2 Wochen angenommen werden?
rename PAS0600 suche_annahme
replace suche_annahme = . if suche_annahme < 0
replace suche_annahme = 0 if suche_annahme == 2
tab suche_annahme

* Gruende fuer die Nicht-Annahme
foreach var in PAS0700a PAS0700b PAS0700c PAS0700d {
replace `var' = . if `var' < 0
}

foreach var in PAS0700a PAS0700b PAS0700c PAS0700d {
replace `var' = 0 if `var' == 2
}

rename PAS0700a suche_annahme_gaus
rename PAS0700b suche_annahme_gpflege
rename PAS0700c suche_annahme_ggesund
rename PAS0700d suche_annahme_gsonst

	*** fuer die Jahre 2011-2013 ist variable eine andere
	foreach var in PAS0701a PAS0701b PAS0701c PAS0701d {
	replace `var' = . if `var' < 0
	}

	foreach var in PAS0701a PAS0701b PAS0701c PAS0701d {
	replace `var' = 0 if `var' == 2
	}

	replace suche_annahme_gaus = PAS0701a if PAS0701a != .
	replace suche_annahme_gpflege = PAS0701b if PAS0701b != .
	replace suche_annahme_ggesund = PAS0701c if PAS0701c != .
	replace suche_annahme_gsonst = PAS0701d if PAS0701d != .

sum suche_annahme_gaus suche_annahme_gpflege suche_annahme_ggesund suche_annahme_gsonst

drop PAS0701a PAS0701b PAS0701c PAS0701d

* Gruende fuer die Nicht-Suche
foreach var in PAS0800a PAS0800b PAS0800c PAS0800d PAS0800e PAS0800f PAS0800g PAS0800h {
replace `var' = . if `var' < 0
}

foreach var in PAS0800a PAS0800b PAS0800c PAS0800d PAS0800e PAS0800f PAS0800g PAS0800h {
replace `var' = 0 if `var' == 2
}

rename PAS0800a suche_nichteink
rename PAS0800b suche_nichtfina
rename PAS0800c suche_nichtnewjob
rename PAS0800d suche_nichtgesund
rename PAS0800e suche_nichtkindpflege
rename PAS0800f suche_nichtkeinestelle
rename PAS0800g suche_nichtaufgabe
rename PAS0800h suche_nichtrente

	* fuer die Jahre 2011-2013 ist die variable eine andere PAS0850a-k
	foreach var in PAS0850a PAS0850b PAS0850c PAS0850d PAS0850e PAS0850f PAS0850g PAS0850h PAS0850i PAS0850j PAS0850k {
	replace `var' = . if `var' < 0
	}
	foreach var in PAS0850a PAS0850b PAS0850c PAS0850d PAS0850e PAS0850f PAS0850g PAS0850h PAS0850i PAS0850j PAS0850k {
	replace `var' = 0 if `var' == 2
	}
	replace suche_nichteink = PAS0850a if PAS0850a != .
	replace suche_nichtfina = PAS0850b if PAS0850b != .
	replace suche_nichtnewjob = PAS0850c if PAS0850c != .
	replace suche_nichtgesund = PAS0850d if PAS0850d != .
	replace suche_nichtkindpflege = PAS0850e if PAS0850e != .
	replace suche_nichtkeinestelle = PAS0850f if PAS0850f != .
	replace suche_nichtaufgabe = PAS0850g if PAS0850g != .
	replace suche_nichtrente = PAS0850h if PAS0850h != .

	rename PAS0850i suche_nichtausb
	rename PAS0850j suche_nichtmassn
	rename PAS0850k suche_nichtstelle

	drop PAS0850a PAS0850b PAS0850c PAS0850d PAS0850e PAS0850f PAS0850g PAS0850h

********************************************************************************
****   Art der Arbeitssuche - ALLE Suchenden              **********************
********************************************************************************
* Suchkanaele
foreach var in PAS0900a PAS0900b PAS0900c PAS0900d PAS0900e PAS0900f PAS0900g PAS0900h {
replace `var' = . if `var' < 0
}
foreach var in PAS0900a PAS0900b PAS0900c PAS0900d PAS0900e PAS0900f PAS0900g PAS0900h {
replace `var' = 0 if `var' == 2
}

rename PAS0900a suche_zeitung
rename PAS0900b suche_onlineBA
rename PAS0900c suche_onlinesonst
rename PAS0900d suche_bekannte
rename PAS0900e suche_JC
rename PAS0900f suche_priVermittler
rename PAS0900g suche_sonst
rename PAS0900h suche_nichts

foreach var in PAS0901a PAS0901b PAS0901c PAS0901d PAS0901e PAS0901f PAS0901g PAS0901h PAS0901i {
replace `var' = . if `var' < 0
}
foreach var in PAS0901a PAS0901b PAS0901c PAS0901d PAS0901e PAS0901f PAS0901g PAS0901h PAS0901i {
replace `var' = 0 if `var' == 2
}

replace suche_zeitung = PAS0901a if PAS0901a !=.
replace suche_onlineBA = PAS0901b if PAS0901b !=.
replace suche_onlinesonst = PAS0901c if PAS0901c !=.
replace suche_bekannte = PAS0901d if PAS0901d !=.
replace suche_JC = PAS0901e if PAS0901e !=.
replace suche_priVermittler = PAS0901f if PAS0901f !=.
replace suche_sonst = PAS0901g if PAS0901g !=.
replace suche_nichts = PAS0901h if PAS0901h !=.

rename PAS0901i suche_initiative
replace suche_initiative = 0 if suche_initiative == . & suche_zeitung !=.


* generiere missing falls jemands nichts davon angibt (siehe Kategorie sonst)
foreach var in suche_zeitung suche_onlineBA suche_onlinesonst suche_bekannte suche_JC suche_priVermittler suche_sonst suche_initiative {
replace `var' = . if suche_nichts == 1 & `var' == 0
}

gen suche_online = suche_onlinesonst
replace suche_online = suche_onlineBA if suche_onlineBA == 1
label var suche_online "Suche Online - BA und sonstiges online"


* Summe der Suche
gen suche_sum = suche_zeitung + suche_onlineBA + suche_onlinesonst + suche_bekannte + suche_JC + suche_priVermittler + suche_sonst + suche_initiative
sum suche_sum
label var suche_sum "Sum of job search"

drop PAS0901a PAS0901b PAS0901c PAS0901d PAS0901e PAS0901f PAS0901g PAS0901h

* Eigeninitiative z.B auf Stellen geantwortet, Anzeigen aufgegeben,....
foreach var in PAS1000a PAS1000b PAS1000c PAS1000d {
replace `var' = . if `var' < 0
}

rename PAS1000a suche_anzeigen_f
rename PAS1000b suche_anzauf_f
rename PAS1000c suche_bet_gefragt_f
rename PAS1000d suche_initiative_f

*lpo: damit missings ber??ichtigt werden, fehlte immer noch suche_anzeigen_f !=.,...

gen suche_anzeigen_d = 1 if suche_anzeigen_f > 0 & suche_anzeigen_f !=.
replace suche_anzeigen_d = 0 if suche_anzeigen_f == 0
label var suche_anzeigen_d "Job ad responded"

gen suche_anzauf_d = 1 if suche_anzauf_f > 0 & suche_anzauf_f !=.
replace suche_anzauf_d = 0 if suche_anzauf_f == 0
label var suche_anzauf_d "Posted an ad"

gen suche_bet_gefragt_d = 1 if suche_bet_gefragt_f > 0 & suche_bet_gefragt_f !=.
replace suche_bet_gefragt_d = 0 if suche_bet_gefragt_f == 0
label var suche_bet_gefragt_d "Firm directly asked"

gen suche_initiative_d = 1 if suche_initiative_f > 0 & suche_initiative_f!=.
replace suche_initiative_d = 0 if suche_initiative_f == 0
label var suche_initiative_d "Speculative application"

********************************************************************************
****   Anzahl Bewerbungen letzten 4 Wochen                  **********************
********************************************************************************
* auf entfernte Stelle
rename PAS1100 anz_bewerbung_entfernt
replace anz_bewerbung_entfernt = . if anz_bewerbung_entfernt  < 0

* mind. 100 km entfernt
rename PAS1110 anz_bewerbung_100km
replace anz_bewerbung_100km = . if anz_bewerbung_100km < 0

gen anz_bewerbung_entfernt_ges = anz_bewerbung_entfernt
replace anz_bewerbung_entfernt_ges = anz_bewerbung_100km if anz_bewerbung_entfernt_ges == . & anz_bewerbung_100km!=.
label var anz_bewerbung_entfernt_ges "application far away"

* Bewerbungsgesprche
rename PAS1200 anz_bewerbung_gespraech
replace anz_bewerbung_gespraech = . if anz_bewerbung_gespraech < 0


********************************************************************************
****   Umfang der Taetigkeit - Voll/Teilzeit                  **********************
********************************************************************************
rename PAS1300 umfang_taetigkeit
replace umfang_taetigkeit = . if umfang_taetigkeit < 0

* lpo: hier w?? ich dummies generieren:

gen suche_vz = (umfang_taetigkeit == 1) if umfang_taetigkeit!=.
gen suche_min_tz = (umfang_taetigkeit == 2) if umfang_taetigkeit!=.
gen suche_max_tz = (umfang_taetigkeit == 3) if umfang_taetigkeit!=.

********************************************************************************
****   Akzeptable Erschwernis                             **********************
********************************************************************************
* langer Arbeitsweg
* lpo: umbenennung der Variablen
rename PAS1400a erschwernis_arbeitsweg
replace erschwernis_arbeitsweg = . if erschwernis_arbeitsweg < 0

rename PAS1400b erschwernis_geringesEink
replace erschwernis_geringesEink = . if erschwernis_geringesEink < 0

rename PAS1400c erschwernis_arbeitszeit
replace erschwernis_arbeitszeit = . if erschwernis_arbeitszeit < 0

rename PAS1400d erschwernis_skillmismatch
replace erschwernis_skillmismatch = . if erschwernis_skillmismatch < 0

rename PAS1400e erschwernis_belastung
replace erschwernis_belastung = . if erschwernis_belastung < 0

rename PAS1400f erschwernis_wohnortwechsel
replace erschwernis_wohnortwechsel = . if erschwernis_wohnortwechsel < 0

rename PAS1400g erschwernis_fernbeziehung
replace erschwernis_fernbeziehung = . if erschwernis_fernbeziehung < 0

********************************************************************************
****  jemals gesucht? Nicht-Suchende                             ***************
********************************************************************************

rename PAS1500 suche_jemals
replace suche_jemals = . if suche_jemals < 0

* lpo: 0/1 Variable
replace suche_jemals = 0 if suche_jemals==2

********************************************************************************
****  Art der gesuchten Taetigkeit                             ******************
********************************************************************************
* suchende (bestimmt, jede, eine Reihe von Taetigkeit)
rename PAS1600 art_taetigkeit_suchende
replace art_taetigkeit_suchende = . if art_taetigkeit_suchende < 0

* lpo: Generieren von Dummies
gen suche_bestimmte_taetigkeit = (art_taetigkeit_suchende == 1) if art_taetigkeit_suchende !=.
gen suche_auswahl_taetigkeit = (art_taetigkeit_suchende == 2) if art_taetigkeit_suchende !=.
gen suche_jede_taetigkeit = (art_taetigkeit_suchende == 3) if art_taetigkeit_suchende !=.

* nicht-suchende
rename PAS1700 art_letzte_taetigkeit_nichtsuche
replace art_letzte_taetigkeit_nichtsuche = . if art_letzte_taetigkeit_nichtsuche < 0

* lpo: Generieren von Dummies
gen letztesuche_bestimmte_taetigkeit = (art_letzte_taetigkeit_nichtsuche== 1) if art_letzte_taetigkeit_nichtsuche!=.
gen letztesuche_auswahl_taetigkeit = (art_letzte_taetigkeit_nichtsuche== 2) if art_letzte_taetigkeit_nichtsuche!=.
gen letztesuche_jede_taetigkeit = (art_letzte_taetigkeit_nichtsuche== 3) if art_letzte_taetigkeit_nichtsuche!=.
gen letztesuche_keine_erinnerung = (art_letzte_taetigkeit_nichtsuche== 4) if art_letzte_taetigkeit_nichtsuche!=.

********************************************************************************
****  Kontakt zu Jobcenter                                    ******************
********************************************************************************

rename  PTK0200 JC_kontakt_anz
replace JC_kontakt_anz =. if JC_kontakt_anz < 0

rename PTK0400 JC_ausf_beratung
replace JC_ausf_beratung = . if JC_ausf_beratung < 0
replace JC_ausf_beratung = 0 if JC_ausf_beratung == 2

rename PTK0500 JC_ausf_beratung_anz
replace JC_ausf_beratung_anz = . if JC_ausf_beratung_anz < 0

* Unterstuetzung durch Jobcenter
rename PTK0900a JC_support_eignung
replace JC_support_eignung = . if JC_support_eignung < 0
replace JC_support_eignung = 0 if JC_support_eignung == 2

rename PTK0900b JC_support_eignung_wichtig
replace JC_support_eignung_wichtig = . if JC_support_eignung_wichtig < 0
replace JC_support_eignung_wichtig = 0 if JC_support_eignung_wichtig == 2

rename PTK1000a JC_support_pers_prob
replace JC_support_pers_prob = . if JC_support_pers_prob < 0
replace JC_support_pers_prob = 0 if JC_support_pers_prob == 2

rename PTK1000b JC_support_pers_prob_wichtig
replace JC_support_pers_prob_wichtig = . if JC_support_pers_prob_wichtig < 0
replace JC_support_pers_prob_wichtig = 0 if JC_support_pers_prob_wichtig == 2

rename PTK1100a JC_support_kinderbetr
replace JC_support_kinderbetr = . if JC_support_kinderbetr < 0
replace JC_support_kinderbetr = 0 if JC_support_kinderbetr == 2

rename PTK1100b JC_support_kinderbetr_wichtig
replace JC_support_kinderbetr_wichtig = . if JC_support_kinderbetr_wichtig < 0
replace JC_support_kinderbetr_wichtig = 0 if JC_support_kinderbetr_wichtig == 2

rename PTK1200 JC_eigl_vereinbar
replace JC_eigl_vereinbar = . if JC_eigl_vereinbar < 0
replace JC_eigl_vereinbar = 0 if JC_eigl_vereinbar == 2

* Erfahrung mit Jobcenter

* PTK1600a: mitarbeiter machen zu viele Vorschriften
* PTK1600b: man will mir wirklich helfen
* PTK1600c: beratung verbessert meine situation
* PTK1600d: unterstuetzt mich, wieder arbeit zu bekommen
* PTK1600e: nur forderungen, keine unterstuetzung
* PTK1600f: vertraue den Mitarbeitern
* PTK1600g: meine Vorstellungen werden beruecksichtigt
* PTK1600h: mitarbeiter freundlich und hilfsbereit

* 4-er Skala: 1: stimme voll und ganz zu und 4: stimme ueberhaupt nicht zu
* umcodiert: 2: stimme voll und ganz zu und -2: stimme ueberhaupt nicht zu


foreach var in PTK1600b PTK1600c PTK1600d PTK1600f PTK1600g PTK1600h {
replace `var' = . if `var' < 0
replace `var' = 2 if `var' == 1
replace `var' = 1 if `var' == 2
replace `var' = -1 if `var' == 3
replace `var' = -2 if `var' == 4
}

foreach var in PTK1600a PTK1600e {
replace `var' = . if `var' < 0
replace `var' = -2 if `var' == 1
replace `var' = -1 if `var' == 2
replace `var' = 1 if `var' == 3
replace `var' = 2 if `var' == 4
}


gen JC_mitarbeiter_bewertung = PTK1600a + PTK1600b + PTK1600c + PTK1600d + PTK1600e + PTK1600f + PTK1600g + PTK1600h

********************************************************************************
****  loeschen und speichern                               **********************
********************************************************************************

*drop PD* PR* PA* PS* PB* PE* PM* PG* PP* PS* PE* PQ* PT* PL*
drop PD* PA* PS* PB* PE* PM* PG* PP* PS* PE* PT* PL*

*drop RegP0100 panel pintmod psprache pintnum fb_vers nachbef altbefr zpsex zpalthh palter hhgr vhh mhh apartner epartner famstand ekin1517 ekinu18 ekin614 ekinu15 ekind kindzges kindzihh halg2s05 halg2s06 schul1 schul2 schulabj beruf1 beruf2 berabj casmin isced97 bilzeit mschul1 mschul2 mberuf1 iscoeewt mpseewt siopseewt iseieewt egpeewt eseceewt kldbeewt gebhalbj ogebland ostaatan ozulanda ozulandb ozulandc ozulandd ozulande ozulandf migration pcs mcs freiz1 freiz2 freiz3 frwunsch mberuf2 mcasmin misced97 mbilzeit mstib misco mmps msiops misei megp mesec mkldb vschul1 vschul2 vberuf1 vberuf2 vcasmin visced97 vbilzeit vstib visco vmps vsiops visei vegp vesec vkldb aktmassn akt1euro alg1abez netto nettokat brutto bruttokat netges brges azhpt1 azges1 azhpt2 azges2 stibkz stib erwerb etakt alakt statakt befrist isco88 mps siops isei egp esec kldb branche emonlewt ejhrlewt stiblewt iscolewt mpslewt siopslewt iseilewt egplewt eseclewt kldblewt begmeewt begjeewt stibeewt

drop RegP0100- frwunsch

sort persnr welle

* save data

save "$data/arbeitssuche.dta", replace

********************************************************************************

log close




