cap log close


********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo03_1_Prep_labor_market.log", replace

* Content: Preparation PASS - Labor market

clear all
capture set more off 

use "$orig/PENDDAT.dta", clear




********************************************************************************
****  Date                                         **********************
********************************************************************************

rename pnr persnr
rename pintjahr year
rename pintmon month
rename pinttag day
rename pintdat date

gen edate = mdy(month, day, year)

format edate %d
format date %d

drop date

rename edate date
label var date "Datum"

order persnr- day date

********************************************************************************

* In Ausbildung
gen d_ausb = 1 if PB0100 == 1 | PB0100 == 2 | PB0100 == 3
replace d_ausb = 0 if PB0100 == -3 | PB0100 == 4 



********************************************************************************
****   espell, uspell, nspell, mspell                      **********************
********************************************************************************
********************************************************************************
****   erwerb, 1. Welle                                    **********************
********************************************************************************

replace erwerb = . if erwerb < 0

/*nicht beachtet wird: Rentner, Zivi, Schule/Ausbildung*/
gen espell = 1 if erwerb == 1
replace espell = 0 if erwerb == 2 | erwerb == 3 | erwerb == 5 | erwerb == 6 | erwerb == 11

gen uspell = 1 if erwerb == 2
replace uspell = 0 if uspell != 1 & (espell == 0 | espell == 1)

gen nspell = 1 if espell == 0 & uspell == 0 & erwerb != 3
replace nspell = 0 if nspell != 1 & (espell == 0 | espell == 1)

gen mspell = 1 if erwerb == 3
replace mspell = 0 if mspell != 1 & (espell == 0 | espell == 1)


********************************************************************************
****   statakt, ab 2. Welle                               **********************
********************************************************************************

replace statakt = . if statakt < 0

replace espell = 1 if statakt == 1
replace espell = 0 if statakt == 2 | statakt == 6 | statakt == 7 | statakt == 11

replace uspell = 1 if statakt == 2 | statakt == 10
replace uspell = 0 if uspell != 1 & (espell == 0 | espell == 1)

replace nspell = 1 if statakt == 6 | statakt == 7 | statakt == 11
replace nspell = 0 if nspell != 1 & (espell == 0 | espell == 1)

replace mspell = 0 if mspell != 1 & (espell == 0 | espell == 1)

********************************************************************************
****   Generiere Variable - spelltyp                      **********************
********************************************************************************
* bio spells in biospell.dta
* 1 = Erwerbstaetig m. Eink.> 400 Euro/Monat
* 2 = Arbeitslos gemeldet/Massnahmenteiln.
* 3 = Arb.los, n. gemeldet (ab W4 aus off. A.
* 4 =             Ausbildung/Lehre/Studium
* 5 =                Wehr-/Zivildienst/etc.
* 6 =                     Hausfrau/Hausmann
* 7 = Mutterschutz/Erzieh.urlaub/Elternzeit
* 8 =       Rentner/Pensionaer/Vorruhestand
* 9 =                 Etwas anderes gemacht
* 10 =         Schueler (bis W3 aus off. A.)
* 11 = Hauptstatus unklar (aus off. Angaben)
* 12 = Krank/beruf.unf./erw.unf./beh.(off. A.)
* 13 = Selbst./mithelf. Fam.angeh. (off. A.)

gen spelltyp = .
replace spelltyp = 1 if statakt == 1
replace spelltyp = 2 if statakt == 2
replace spelltyp = 3 if statakt == 10
replace spelltyp = 4 if statakt == 4
replace spelltyp = 5 if statakt == 5
replace spelltyp = 6 if statakt == 6
replace spelltyp = 7 if statakt == 7
replace spelltyp = 8 if statakt == 8
replace spelltyp = 10 if statakt == 3
replace spelltyp = 11 if statakt == 9
replace spelltyp = 12 if statakt == 11
replace spelltyp = 13 if statakt == 12

* aus welle 1
replace spelltyp = 1 if erwerb == 1
replace spelltyp = 2 if erwerb == 3
replace spelltyp = 2 if erwerb == 2
replace spelltyp = 4 if erwerb == 8 | erwerb == 10
replace spelltyp = 5 if erwerb == 7
replace spelltyp = 6 if erwerb == 5
replace spelltyp = 7 if erwerb == 6
replace spelltyp = 8 if erwerb == 4
replace spelltyp = 10 if erwerb == 9
replace spelltyp = 11 if erwerb == 12
replace spelltyp = 12 if erwerb == 11


********************************************************************************
****   Massnahmenteilnahme                                    **********************
********************************************************************************
* massnahmen
replace aktmassn = . if aktmassn < 0
tab aktmassn, nol

replace mspell = 1 if aktmassn == 1

* inklusive 1-Euro-Jobs
replace akt1euro = . if akt1euro < 0
replace akt1euro = 0 if akt1euro == 2

replace mspell = 1 if akt1euro == 1
replace mspell = 0 if mspell != 1 & (espell == 0 | espell == 1)

replace espell = 0 if mspell == 1
replace uspell = 1 if mspell == 1

replace spelltyp = 2 if mspell == 1

********************************************************************************
**** Aktuell beschäftigt?*******************************************************
********************************************************************************
replace espell = 1 if etakt == 1
replace espell = 0 if etakt == 0

********************************************************************************
****   alg1abez                                                **********************
********************************************************************************
* ALG Bezug?
replace alg1abez =. if alg1abez < 0
replace uspell = 1 if alg1abez == 1 & uspell != 1


********************************************************************************
****   alakt                                                **********************
********************************************************************************
* aktuell arbeitslos gemeldet
replace alakt = . if alakt < 0
replace alakt = 0 if alakt == 2
replace uspell = 1 if alakt == 1 
replace uspell = 0 if alakt == 0 & uspell != 1

replace spelltyp = 3 if alakt == 1 & spelltyp != 2

********************************************************************************
****   jetzige Stellung im Beruf                               **********************
********************************************************************************
replace stibkz = . if stibkz < 0
replace brutto = . if brutto < 0
replace netto  = . if netto  < 0

* espell falls bluecollar, whitcollar or self-employed
replace espell = 1 if stibkz >= 1 & stibkz <= 7 & ((brutto > 0 & brutto != .) | (netto > 0 & netto != .))  
* nspell falls mithelfender Familienangehoeriger
replace nspell = 1 if stibkz == 8
* uspell anpassen
*replace uspell = 0 if stibkz != .
replace stibkz = . if stibkz == 8

********************************************************************************
* Seit wann jetzige Taetigkeit?
rename PET2390 emonjewt
rename PET2400 ejhrjewt


replace espell = 1 if ejhrjewt > 0 & ejhrjewt != . 
replace espell = 0 if ejhrjewt == -3 & espell == .

foreach var in emonjewt ejhrjewt{
replace `var' = . if `var' < 0
}

tab emonjewt, nol

	replace emonjewt = 1 if emonjewt == 21
	replace emonjewt = 4 if emonjewt == 24
	replace emonjewt = 7 if emonjewt == 27
	replace emonjewt = 10 if emonjewt == 30
	replace emonjewt = 12 if emonjewt == 32

gen jewtdate = mdy(emonjewt, 1, ejhrjewt)
format jewtdate %d
label var jewtdate "Datum der jetzigen Erwerbstaetigkeit"


********************************************************************************
****   letzte Erwerbstaetigkeit                            **********************
********************************************************************************
foreach var in emonlewt ejhrlewt{
replace `var' = . if `var' < 0
}

* generiere Datum der letzten Erwerbstaetigkeit
* Annahme: Fall Monat nicht genannt - setze Dezember ein (am haeufigsten unter den geannten)
tab emonlewt, nol

	replace emonlewt = 1 if emonlewt == 21
	replace emonlewt = 4 if emonlewt == 24
	replace emonlewt = 7 if emonlewt == 27
	replace emonlewt = 10 if emonlewt == 30
	replace emonlewt = 12 if emonlewt == 32

	replace emonlewt = 12 if emonlewt == . & ejhrlewt != .

gen ldate = mdy(emonlewt, 1, ejhrlewt)
format ldate %d
label var ldate "Datum der letzten Erwerbstaetigkeit"

* falls Person in t-1 espell = 0 hat und missing information bei letzter Taetigkeit - auffuellen
sort persnr welle
by persnr (welle): replace ldate = ldate[_n-1] if ldate[_n-1] != . & ldate ==. & espell != 1

gsort persnr -welle
by persnr: replace ldate = ldate[_n-1] if ldate[_n-1] != . &  ldate ==. & espell != 1

sort persnr welle

* nicht Erwerbstaetig seit:
gen not_employed_since = date - ldate
replace not_employed_since = . if not_employed_since < 0
replace not_employed_since = 0 if espell == 1

********************************************************************************
****   auffuellen                                             **********************
********************************************************************************
replace espell = 0 if espell == . & (uspell == 1 | nspell == 1)
replace uspell = 0 if uspell == . & (espell == 1 | nspell == 1)
replace nspell = 0 if nspell == . & (espell == 1 | uspell == 1)
replace mspell = 0 if mspell == . & (espell == 1 | espell == 0)

label var espell "Employed"
label var uspell "Unemployed"
label var nspell "Non-employed"
label var mspell "Program"

********************************************************************************
****  Brutto/Netto Lohn                                 **********************
********************************************************************************
* Haupterwerbstaetigkeit
replace netto = . if netto < 0
replace brutto = . if brutto < 0

* Einkommen insgesamt
replace netges = . if netges < 0
replace brges = . if brges < 0

* replace Lohn falls missing
gen brutto_gen = brutto
replace brutto_gen = brges if brutto == . & brges != .
label var brutto_gen "Gross wage"

gen netto_gen = netto
replace netto_gen = netges if netto == . & netges !=.
label var netto_gen "Net wage"

* Anpassung espell, uspell und nspell
*replace nspell = 0 if nspell == 1 & espell == 1
*replace nspell = 0 if uspell == 1 & nspell == 1
*replace uspell = 0 if uspell == 1 & espell == 1  
*replace espell = 0 if uspell == 1 & espell == 1


* Annahme: Personen in ABM = uspell
*replace espell = 0 if mspell == 1
*replace uspell = 1 if mspell == 1
*replace nspell = 0 if mspell == 1
********************************************************************************
****  Arbeitszeiten                                       **********************
********************************************************************************
foreach var in azhpt1 azges1 azhpt2 azges2{
replace `var' = . if `var' < 0
}

* auffuellen mit gesamten Arbeitszeiten
gen arbeitszeit_gen = azhpt1
replace arbeitszeit_gen = azges1 if arbeitszeit_gen == . & azges1 != .
label var arbeitszeit_gen "Contractual Working hours"

gen arbeitszeit_real_gen = azhpt2
replace arbeitszeit_real_gen = azges2 if arbeitszeit_real_gen == . & azges2 != .
label var arbeitszeit_real_gen "Real working hours"

********************************************************************************
****  Lohn pro Stunde                                     **********************
********************************************************************************

gen netto_stunde_vertrag = netto_gen/arbeitszeit_gen
label var netto_stunde_vertrag "Net wage per h - contract"
gen brutto_stunde_vertrag = brutto_gen/arbeitszeit_gen
label var brutto_stunde_vertrag "Gross wage per h - contract"

gen netto_stunde_real = netto_gen/arbeitszeit_real_gen
label var netto_stunde_real "Net wage per h - real"
gen brutto_stunde_real = brutto_gen/arbeitszeit_real_gen
label var brutto_stunde_real "Gross wage per h - real"


********************************************************************************
****  Branche                                             **********************
********************************************************************************
gen branche = branche1
replace branche = . if branche < 0

gen sector1 = (branche >= 1 & branche < 10) if branche != .
gen sector2 = (branche >= 10 & branche < 20) if branche != .
gen sector3 = (branche >= 20 & branche < 30) if branche != .
gen sector4 = (branche >= 30 & branche < 40) if branche != .
gen sector5 = (branche >= 40 & branche < 50) if branche != .
gen sector6 = (branche >= 50 & branche < 60) if branche != .
gen sector7 = (branche >= 60 & branche < 70) if branche != .
gen sector8 = (branche >= 70 & branche < 80) if branche != .
gen sector9 = (branche >= 80 & branche < 90) if branche != .
gen sector10 = (branche >= 90 & branche < 100) if branche != .


label var sector1 "Agrar"
label var sector2 "Basic resources"
label var sector3 "Machinery"
label var sector4 "Automobile"
label var sector5 "Energy"
label var sector6 "Retail"
label var sector7 "Communication"
label var sector8 "Economic Service"
label var sector9 "Health/Social"
label var sector10 "Else"


********************************************************************************
**** siops                                           **********************
********************************************************************************
gen siops = siops2
replace siops = . if siops < 0

********************************************************************************
****  egp                                                 **********************
********************************************************************************

replace egp = . if egp < 0

tab egp, gen(egp)

********************************************************************************
****  Befristung                                          **********************
********************************************************************************

replace befrist = . if befrist < 0
replace befrist = 0 if befrist == 2

********************************************************************************
****  Stellung im Beruf                                   **********************
********************************************************************************
*rename stibkz occupation

* Generieren von dummies
gen bluecoll = (stibkz== 1) if stibkz!=.
gen whitecoll = (stibkz== 2 | stibkz== 4 ) if stibkz!=.
gen selfemployed = (stibkz >= 5 & stibkz <= 7) if stibkz!=.

label var bluecoll "blue-collar worker"
label var whitecoll "white-collar worker"
label var selfemployed "white-collar worker"

********************************************************************************
**** Betriebsgroesse                                        **********************
********************************************************************************

rename PET3000 firm_size

replace firm_size = . if firm_size < 0

* firm size
gen firm_size_mis = (firm_size == .)

gen firm_size10 = (firm_size < 10)
gen firm_size10_50 = (firm_size >= 10 & firm_size < 50)
gen firm_size50_250 = (firm_size >= 50 & firm_size < 250)
gen firm_size250_500 = (firm_size >= 250 & firm_size < 500)
gen firm_size500 = (firm_size >= 500 & firm_size != .)

label var firm_size10 "Firm size <10"
label var firm_size10_50 "Firm size 10-50"
label var firm_size50_250 "Firm size 50-250"
label var firm_size250_500 "Firm size 250-500"
label var firm_size500 "Firm size >500"
label var firm_size_mis "Firm size is missing"



********************************************************************************
****  Stellung im Beruf letzte Taetigkeit                  **********************
********************************************************************************
* Dies entspricht der aktuellen Stellung falls employed

replace stiblewt = . if stiblewt < 0
replace stiblewt = stib if espell == 1 & stib != .
bysort persnr (welle): replace stiblewt = stiblewt[_n-1] if espell != 1 & stiblewt[_n-1] != . & stiblewt == .
*rename stiblewt occupation_last

gen selbststaendig_lewt = (stiblewt == 15 | stiblewt==16 | stiblewt == 17 | stiblewt == 21 | stiblewt == 22 | stiblewt == 23 | stiblewt == 24)
gen oeDienst_lewt = ((stiblewt == 40 | stiblewt == 41 | stiblewt==42 | stiblewt == 43))
gen angestellter_lewt = (stiblewt == 51 | stiblewt == 52 | stiblewt==53 | stiblewt == 54)
gen arbeiter_lewt = (stiblewt == 10 | stiblewt == 11 | stiblewt==12 | stiblewt == 13 | stiblewt == 60 | stiblewt == 61 | stiblewt==62)
gen meister_lewt = (stiblewt == 63 | stiblewt == 64)
gen missing_occ_lewt = (stiblewt == .)

label var selbststaendig_lewt "lewt: self-employed"
label var oeDienst_lewt "lewt: public"
label var angestellter_lewt "lewt: white-collar"
label var arbeiter_lewt "lewt: blue-collar"
label var meister_lewt "lewt: foremen"
label var missing_occ_lewt "lewt: missing"

* Generieren von dummies
gen bluecoll_lewt =  1 if (arbeiter_lewt == 1 | meister_lewt == 1) & stiblewt!=.
replace bluecoll_lewt = 0 if (arbeiter_lewt == 0 & meister_lewt == 0) & stiblewt!=.

gen whitecoll_lewt = 1 if (oeDienst_lewt == 1 | angestellter_lewt == 1) & stiblewt!=.
replace whitecoll_lewt = 0 if (oeDienst_lewt == 0 & angestellter_lewt == 0) & stiblewt!=.

label var bluecoll_lewt "lewt: blue-collar worker"
label var whitecoll_lewt "lewt: white-collar worker"

********************************************************************************
****  Stellung im Beruf erste Taetigkeit                   **********************
********************************************************************************
replace stibeewt = . if stibeewt < 0
*rename stibeewt occupation_first

* missings pro Person auffuellen

sort persnr welle
by persnr (welle): replace stibeewt = stibeewt[_n-1] if stibeewt == . & stibeewt[_n-1] !=.

gsort persnr -welle
by persnr : replace stibeewt = stibeewt[_n-1] if stibeewt == . & stibeewt[_n-1] !=.

gen selbststaendig_eewt = (stibeewt == 15 | stibeewt==16 | stibeewt == 17 | stibeewt == 21 | stibeewt == 22 | stibeewt == 23 | stibeewt == 24)
gen oeDienst_eewt = (stibeewt == 40 | stibeewt == 41 | stibeewt==42 | stibeewt == 43)
gen angestellter_eewt = (stibeewt == 51 | stibeewt == 52 | stibeewt==53 | stibeewt == 54)
gen arbeiter_eewt = (stibeewt == 10 | stibeewt == 11 | stibeewt==12 | stibeewt == 13 |stibeewt == 60 | stibeewt == 61 | stibeewt==62)
gen meister_eewt = (stibeewt == 63 | stibeewt == 64)
gen missing_occ_eewt = (stibeewt == .)

label var selbststaendig_eewt "eewt: self-employed"
label var oeDienst_eewt "eewt: public"
label var angestellter_eewt "eewt: white-collar"
label var arbeiter_eewt "eewt: blue-collar"
label var meister_eewt "eewt: foremen"
label var missing_occ_eewt "eewt: missing"

* Generieren von dummies
gen bluecoll_eewt =  1 if (arbeiter_eewt == 1 | meister_eewt == 1) & stibeewt!=.
replace bluecoll_eewt = 0 if (arbeiter_eewt == 0 & meister_eewt == 0) & stibeewt!=.

gen whitecoll_eewt = 1 if (oeDienst_eewt == 1 | angestellter_eewt == 1) & stibeewt!=.
replace whitecoll_eewt = 0 if (oeDienst_eewt == 0 & angestellter_eewt == 0) & stibeewt!=.

* missings pro Person auffuellen

label var bluecoll_eewt "eewt: blue-collar worker"
label var whitecoll_eewt "eewt: white-collar worker"

sort persnr welle

********************************************************************************
****  potential experience                           **********************
********************************************************************************
* basierend auf Angaben zum ersten Erwerbsstatus
foreach var in begmeewt begjeewt{
replace `var' = . if `var' < 0
}

* generiere Datum der ersten Erwerbstaetigkeit
* Annahme: Fall Monat nicht genannt - setze Dezember ein (am haeufigsten unter den geannten)
tab begmeewt, nol

	replace begmeewt = 1 if begmeewt == 21
	replace begmeewt = 4 if begmeewt == 24
	replace begmeewt = 7 if begmeewt == 27
	replace begmeewt = 10 if begmeewt == 30
	replace begmeewt = 12 if begmeewt == 32

	replace begmeewt = 9 if begmeewt == . & begjeewt != .

gen date_eewt = mdy(begmeewt, 1, begjeewt)
format date_eewt %d
label var date_eewt "Datum der ersten Beschaeftigung"

* missings pro Person auff??n
sort persnr welle
by persnr (welle): replace date_eewt = date_eewt[_n-1] if date_eewt[_n-1] != . & date_eewt ==.

gsort persnr -welle
by persnr: replace date_eewt = date_eewt[_n-1] if date_eewt[_n-1] != . &  date_eewt ==.

sort persnr welle

* potenziell Arbeitserfahrung seit:
gen exp = date - date_eewt
replace exp = . if exp < 0
label var exp "Potential experience"

* lpo: Variable pro Jahr
gen exp_years = round(exp/365,.2)
label var exp_years "Experience in years"

gen expsq = exp^2
label var expsq "Potential experience sq"
gen exp_years_sq = exp_years^2
label var exp_years_sq "Experience in years sq"

********************************************************************************
****  Erwarteter Lohn                                 **********************
********************************************************************************
* erwarteter Nettolohn
rename PAS1800 nettolohn_erwartet
replace nettolohn_erwartet = . if nettolohn_erwartet < 0

* erwartete Arbeitszeit
rename PAS1900 lohn_arbeitszeit_erwartet
replace lohn_arbeitszeit_erwartet = . if lohn_arbeitszeit_erwartet < 0

*replace lohn_arbeitszeit_erwartet = 40 if lohn_arbeitszeit_erwartet > 40 & lohn_arbeitszeit_erwartet!=.

gen nettolohn_stunde_erwartet = nettolohn_erwartet/lohn_arbeitszeit_erwartet
label var nettolohn_stunde_erwartet "Expected net wage per h"

* geringerer Nettolohn akzeptabel?
rename PAS2000 nettolohn_geringer
replace nettolohn_geringer = . if nettolohn_geringer < 0

* mindest Nettolohn
rename PAS2100 nettolohn_min
replace nettolohn_min = . if nettolohn_min < 0

replace nettolohn_min = PAS2200 if PAS2200 > 0

drop PAS2200

* Arbeitszeit fuer lohn_min
rename PAS2300 lohn_min_arbeitszeit
replace lohn_min_arbeitszeit = . if lohn_min_arbeitszeit < 0

*replace lohn_min_arbeitszeit = 40 if lohn_min_arbeitszeit > 40 & lohn_min_arbeitszeit != .

gen nettolohn_min_stunde = nettolohn_min/lohn_min_arbeitszeit
label var nettolohn_min_stunde "Minimum net wage per h"


********************************************************************************
****  work attitude                                        *********************
********************************************************************************
foreach var in PEO0200a PEO0200b PEO0200c PEO0200d{
replace `var' = . if `var' < 0
}


* 4-er Skala: 1: stimme voll und ganz zu und 4: stimme ueberhaupt nicht zu
* umcodiert:  4: stimme voll und ganz zu und 1: stimme ueberhaupt nicht zu

gen work_attitude_1 = PEO0200a /*Arbeitsorientierungen: Arbeit nur ein Mittel, um Geld zu verdienen*/

gen work_attitude_1_orig = 4 if PEO0200a == 1 /*Arbeitsorientierungen: Arbeit nur ein Mittel, um Geld zu verdienen*/
replace work_attitude_1_orig = 3 if PEO0200a == 2
replace work_attitude_1_orig = 2 if PEO0200a == 3
replace work_attitude_1_orig = 1 if PEO0200a == 4

gen work_attitude_2 = 4 if PEO0200b == 1 /*Arbeitsorientierungen: Arbeit ist das Wichtigste im Leben*/
replace work_attitude_2 = 3 if PEO0200b == 2
replace work_attitude_2 = 2 if PEO0200b == 3
replace work_attitude_2 = 1 if PEO0200b == 4

gen work_attitude_3 = 4 if PEO0200c == 1 /*Arbeitsorientierungen: Arbeit gibt einem das Gefuehl, dazuzugehoeren*/
replace work_attitude_3 = 3 if PEO0200c == 2
replace work_attitude_3 = 2 if PEO0200c == 3
replace work_attitude_3 = 1 if PEO0200c == 4

gen work_attitude_4 = 4 if PEO0200d == 1 /*Arbeitsorientierungen: Arbeit , auch ohne Angewiesenheit auf Lohn*/
replace work_attitude_4 = 3 if PEO0200d == 2
replace work_attitude_4 = 2 if PEO0200d == 3
replace work_attitude_4 = 1 if PEO0200d == 4


********************************************************************************
**** Auffuellen mit plausiblen Werten                      **********************
********************************************************************************
sort persnr welle

* Soziodemo
foreach var in work_attitude_1_orig work_attitude_2 work_attitude_3 work_attitude_4 {
by persnr (welle): replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=.
}


gsort persnr -welle

* Soziodemo
foreach var in work_attitude_1_orig work_attitude_2 work_attitude_3 work_attitude_4 {
by persnr: replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=.
}


sort persnr welle

********************************************************************************
**** Haefigkeit Arbeitgeberwechsel                        **********************
********************************************************************************
rename PET4000 AG_wechsel

replace AG_wechsel = . if AG_wechsel < 0

* Auffuellen, wenn AG-wechsel == 0
gsort persnr -welle
bysort persnr: replace AG_wechsel = AG_wechsel[_n-1] if AG_wechsel[_n-1] == 0

sort persnr welle

********************************************************************************
**** lpo: Variablen fuer Arbeitslosigkeitshistorie              *********************
********************************************************************************
* Jemals arbeitslos gemeldet?
* Nur bei erster Befragung
rename PA0435 uspell_jemals
replace uspell_jemals = 1 if uspell == 1
replace uspell_jemals  = 1 if uspell_jemals == -3 & altbefr == 2
replace  uspell_jemals = . if  uspell_jemals < 0
replace  uspell_jemals = 0 if  uspell_jemals==2


* Anzahl Arbeitslosenmeldungen
rename PA0440 anz_uspells
replace anz_uspells = 0 if uspell_jemals == 0
replace anz_uspells = . if anz_uspells < 0


* Dauer der Arbeitslosigkeit insgesamt
rename PA0445 dauer_uspell_ges
replace dauer_uspell_ges = 0 if uspell_jemals == 0
replace dauer_uspell_ges = . if dauer_uspell_ges < 0

* Jahre in Monate umrechnen
replace PA0450 = 0 if uspell_jemals == 0
replace PA0450 = . if PA0450 <0
replace PA0450 = PA0450*12

replace dauer_uspell_ges = dauer_uspell_ges + PA0450


* Dauer der laengsten Arbeitslosigkeit
rename PA0455 dauer_uspell_last
replace dauer_uspell_last = 0 if dauer_uspell_last == -3
replace dauer_uspell_last = . if dauer_uspell_last < 0

* Jahre in Monate umrechnen
replace PA0460 = 0 if PA0460 == -3
replace PA0460 = . if PA0460 <0
replace PA0460 = PA0460*12

replace dauer_uspell_last = dauer_uspell_last + PA0460


* auffuellen von missings


* Hier mit Maximum arbeiten

by persnr: egen uspell_jemals_max = max(uspell_jemals)
replace uspell_jemals = uspell_jemals_max

by persnr: egen anz_uspells_max = max(anz_uspells)
replace anz_uspells = anz_uspells_max

by persnr: egen dauer_uspell_ges_max = max(dauer_uspell_ges)
replace dauer_uspell_ges = dauer_uspell_ges_max

drop uspell_jemals_max anz_uspells_max dauer_uspell_ges_max

sort persnr welle
********************************************************************************
**** loeschen und speichern                                **********************
********************************************************************************

*drop PD* PR* PA* PS* PB* PE* PM* PG* PP* PS* PE* PQ* PT* PL*
drop PD* PA* PS* PB* PE* PM* PG* PP* PS* PE* PT* PL*

drop pintmod - altbefr

drop zpsex- hhgr  RegP0100- vkldb2010 etakt- statakt emonlewt- frwunsch

sort persnr welle

* save data

save "$data/arbeitsmarkt.dta", replace

********************************************************************************

log close









