cap log close
********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo04_1_Prep_household.log", replace

* Content: Preparation PASS - Household characteristics

clear all
capture set more off 

use "$orig/HHENDDAT.dta", clear


rename HD0200a pers1_alter


********************************************************************************
****   Bundesland                                         **********************
********************************************************************************
rename bundesld bland
replace bland = . if bland < 0

gen  d_ostdeutschland = 0
replace d_ostdeutschland = 1 if bland >= 11 & bland != .
replace d_ostdeutschland = . if bland == .


********************************************************************************
****   Wohnform                                         **********************
********************************************************************************
foreach var in HW0200 HW0300 HW0400{
replace `var' = . if `var' < 0
}

gen wohngemeinschaft = (HW0200 == 1) if HW0200 != .
label var wohngemeinschaft "Flat-sharing"
gen wohnheim = (HW0200 == 2) if HW0200 != .
label var wohnheim "Dormitory"

gen eigentum = (HW0300 == 3) if HW0300 != .
replace eigentum = 0 if wohngemeinschaft == 1 | wohnheim == 1

label var eigentum "Home owner"
gen mieter = (HW0300 != 3) if HW0300 != .
label var mieter "Rent"



* Wohnflaeche
replace wohnfl = . if wohnfl < 0

* auffuellen von Wohnflaeche basierend auf Umzugasvariable
replace umzug = . if umzug < 0
replace umzug = 0 if umzug==2
tab umzug, nol

sort hnr welle
by hnr (welle): replace wohnfl = wohnfl[_n-1] if wohnfl == . & wohnfl[_n-1]!=. & umzug == 0

gsort hnr -welle
by hnr: replace wohnfl = wohnfl[_n-1] if wohnfl == . & wohnfl[_n-1]!=. & umzug == 0 & umzug[_n-1]==0 & umzug[_n+1]==0

sort hnr welle

* Auffuellen von eigentum

sort hnr welle
by hnr (welle): replace eigentum = eigentum[_n-1] if eigentum == . & eigentum[_n-1]!=.



********************************************************************************
****   Deprivation                                        **********************
********************************************************************************
rename HLS0100a dep_anz_zimmer
replace dep_anz_zimmer = . if dep_anz_zimmer < 0 
replace dep_anz_zimmer = 0 if dep_anz_zimmer == 2

gen dep_anz_zimmer_nfgrund = 0 if HLS0100b == 1
replace dep_anz_zimmer_nfgrund = 1 if HLS0100b == 2
replace dep_anz_zimmer_nfgrund = 1 if HLS0100b == -1 | HLS0100b == -2
label var dep_anz_zimmer_nfgrund "nfgrund: financial"

rename HLS0100b dep_anz_zimmer_fgrund
replace dep_anz_zimmer_fgrund = . if dep_anz_zimmer_fgrund < 0
replace dep_anz_zimmer_fgrund = 0 if dep_anz_zimmer_fgrund == 2
replace dep_anz_zimmer_fgrund = 0 if dep_anz_zimmer == 1
label var dep_anz_zimmer_fgrund "fgrund: financial"

****************************************************************
rename HLS0200a dep_wohnung_feucht
replace dep_wohnung_feucht = . if dep_wohnung_feucht < 0 
replace dep_wohnung_feucht = 0 if dep_wohnung_feucht == 2

gen dep_wohnung_feucht_nfgrund = 0 if HLS0200b == 1
replace dep_wohnung_feucht_nfgrund = 1 if HLS0200b == 2
replace dep_wohnung_feucht_nfgrund = 1 if HLS0200b == -1 | HLS0200b == -2
label var dep_wohnung_feucht_nfgrund "nfgrund: financial"

rename HLS0200b dep_wohnung_feucht_fgrund
replace dep_wohnung_feucht_fgrund = . if dep_wohnung_feucht_fgrund < 0
replace dep_wohnung_feucht_fgrund = 0 if dep_wohnung_feucht_fgrund == 2
replace dep_wohnung_feucht_fgrund = 0 if dep_wohnung_feucht == 1
label var dep_wohnung_feucht_fgrund "fgrund: financial"

************************************************************
rename HLS0300a dep_bad
replace dep_bad = . if dep_bad < 0 
replace dep_bad = 0 if dep_bad == 2

gen dep_bad_nfgrund = 0 if HLS0300b == 1
replace dep_bad_nfgrund = 1 if HLS0300b == 2
replace dep_bad_nfgrund = 1 if HLS0300b == -1 | HLS0300b == -2
label var dep_bad_nfgrund "nfgrund: financial"

rename HLS0300b dep_bad_fgrund
replace dep_bad_fgrund = . if dep_bad_fgrund < 0
replace dep_bad_fgrund = 0 if dep_bad_fgrund == 2
replace dep_bad_fgrund = 0 if dep_bad == 1
label var dep_bad_fgrund "fgrund: financial"

***********************************************************

rename HLS0400a dep_innenklo
replace dep_innenklo = . if dep_innenklo < 0 
replace dep_innenklo = 0 if dep_innenklo == 2


gen dep_innenklo_nfgrund = 0 if HLS0400b == 1
replace dep_innenklo_nfgrund = 1 if HLS0400b == 2
replace dep_innenklo_nfgrund = 1 if HLS0400b == -1 | HLS0400b == -2
label var dep_innenklo_nfgrund "nfgrund: financial"


rename HLS0400b dep_innenklo_fgrund
replace dep_innenklo_fgrund = . if dep_innenklo_fgrund < 0
replace dep_innenklo_fgrund = 0 if dep_innenklo_fgrund == 2
replace dep_innenklo_fgrund = 0 if dep_innenklo == 1
label var dep_innenklo_fgrund "fgrund: financial"

***********************************************************

* HLS0500a Heizung


rename HLS0600a dep_aussen
replace dep_aussen = . if dep_aussen < 0 
replace dep_aussen = 0 if dep_aussen == 2

gen dep_aussen_nfgrund = 0 if HLS0600b == 1
replace dep_aussen_nfgrund = 1 if HLS0600b == 2
replace dep_aussen_nfgrund = 1 if HLS0600b == -1 | HLS0600b == -2
label var dep_aussen_nfgrund "nfgrund: financial"

rename HLS0600b dep_aussen_fgrund
replace dep_aussen_fgrund = . if dep_aussen_fgrund < 0
replace dep_aussen_fgrund = 0 if dep_aussen_fgrund == 2
replace dep_aussen_fgrund = 0 if dep_aussen == 1
label var dep_aussen_fgrund "fgrund: financial"

*************************************************************

rename HLS0700a dep_winterkl
replace dep_winterkl = . if dep_winterkl < 0 
replace dep_winterkl = 0 if dep_winterkl == 2

gen dep_winterkl_nfgrund = 0 if HLS0700b == 1
replace dep_winterkl_nfgrund = 1 if HLS0700b == 2
replace dep_winterkl_nfgrund = 1 if HLS0700b == -1 | HLS0700b == -2
label var dep_winterkl_nfgrund "nfgrund: financial"

rename HLS0700b dep_winterkl_fgrund
replace dep_winterkl_fgrund = . if dep_winterkl_fgrund < 0
replace dep_winterkl_fgrund = 0 if dep_winterkl_fgrund == 2
replace dep_winterkl_fgrund = 0 if dep_winterkl == 1
label var dep_winterkl_fgrund "fgrund: financial"

************************************************************

rename HLS0800a dep_auto
replace dep_auto = . if dep_auto < 0 
replace dep_auto = 0 if dep_auto == 2

gen dep_auto_nfgrund = 0 if HLS0800b == 1
replace dep_auto_nfgrund = 1 if HLS0800b == 2
replace dep_auto_nfgrund = 1 if HLS0800b == -1 | HLS0800b == -2
label var dep_auto_nfgrund "nfgrund: financial"

rename HLS0800b dep_auto_fgrund
replace dep_auto_fgrund = . if dep_auto_fgrund < 0
replace dep_auto_fgrund = 0 if dep_auto_fgrund == 2
replace dep_auto_fgrund = 0 if dep_auto == 1
label var dep_auto_fgrund "fgrund: financial"

***********************************************************

rename HLS0900a dep_fernseher
replace dep_fernseher = . if dep_fernseher < 0 
replace dep_fernseher = 0 if dep_fernseher == 2

gen dep_fernseher_nfgrund = 0 if HLS0900b == 1
replace dep_fernseher_nfgrund = 1 if HLS0900b == 2
replace dep_fernseher_nfgrund = 1 if HLS0900b == -1 | HLS0900b == -2
label var dep_fernseher_nfgrund "nfgrund: financial"

rename HLS0900b dep_fernseher_fgrund
replace dep_fernseher_fgrund = . if dep_fernseher_fgrund < 0
replace dep_fernseher_fgrund = 0 if dep_fernseher_fgrund == 2
replace dep_fernseher_fgrund = 0 if dep_fernseher == 1
label var dep_fernseher_fgrund "fgrund: financial"

***********************************************************

rename HLS1000a dep_dvd
replace dep_dvd = . if dep_dvd < 0 
replace dep_dvd = 0 if dep_dvd == 2

gen dep_dvd_nfgrund = 0 if HLS1000b == 1
replace dep_dvd_nfgrund = 1 if HLS1000b == 2
replace dep_dvd_nfgrund = 1 if HLS1000b == -1 | HLS1000b == -2
label var dep_dvd_nfgrund "nfgrund: financial"

rename HLS1000b dep_dvd_fgrund
replace dep_dvd_fgrund = . if dep_dvd_fgrund < 0
replace dep_dvd_fgrund = 0 if dep_dvd_fgrund == 2
replace dep_dvd_fgrund = 0 if dep_dvd == 1
label var dep_dvd_fgrund "fgrund: financial"

***********************************************************

rename HLS1100a dep_internet
replace dep_internet = . if dep_internet < 0 
replace dep_internet = 0 if dep_internet == 2

gen dep_internet_nfgrund = 0 if HLS1100b == 1
replace dep_internet_nfgrund = 1 if HLS1100b == 2
replace dep_internet_nfgrund = 1 if HLS1100b == -1 | HLS1100b == -2
label var dep_internet_nfgrund "nfgrund: financial"

rename HLS1100b dep_internet_fgrund
replace dep_internet_fgrund = . if dep_internet_fgrund < 0
replace dep_internet_fgrund = 0 if dep_internet_fgrund == 2
replace dep_internet_fgrund = 0 if dep_internet == 1
label var dep_internet_fgrund "fgrund: financial"

***********************************************************

rename HLS1200a dep_waschmaschine
replace dep_waschmaschine = . if dep_waschmaschine < 0 
replace dep_waschmaschine = 0 if dep_waschmaschine == 2

gen dep_waschmaschine_nfgrund = 0 if HLS1200b == 1
replace dep_waschmaschine_nfgrund = 1 if HLS1200b == 2
replace dep_waschmaschine_nfgrund = 1 if HLS1200b == -1 | HLS1200b == -2
label var dep_waschmaschine_nfgrund "nfgrund: financial"

rename HLS1200b dep_waschmaschine_fgrund
replace dep_waschmaschine_fgrund = . if dep_waschmaschine_fgrund < 0
replace dep_waschmaschine_fgrund = 0 if dep_waschmaschine_fgrund == 2
replace dep_waschmaschine_fgrund = 0 if dep_waschmaschine == 1
label var dep_waschmaschine_fgrund "fgrund: financial"

*********************************************************

*  HLS1300: Kuehlschrank

rename HLS1400a dep_kleidung
replace dep_kleidung = . if dep_kleidung < 0 
replace dep_kleidung = 0 if dep_kleidung == 2

gen dep_kleidung_nfgrund = 0 if HLS1400b == 1
replace dep_kleidung_nfgrund = 1 if HLS1400b == 2
replace dep_kleidung_nfgrund = 1 if HLS1400b == -1 | HLS1400b == -2
label var dep_kleidung_nfgrund "nfgrund: financial"

rename HLS1400b dep_kleidung_fgrund
replace dep_kleidung_fgrund = . if dep_kleidung_fgrund < 0
replace dep_kleidung_fgrund = 0 if dep_kleidung_fgrund == 2
replace dep_kleidung_fgrund = 0 if dep_kleidung == 1
label var dep_kleidung_fgrund "fgrund: financial"

**********************************************************

rename HLS1500a dep_warmeMahlzeit
replace dep_warmeMahlzeit = . if dep_warmeMahlzeit < 0 
replace dep_warmeMahlzeit = 0 if dep_warmeMahlzeit == 2

gen dep_warmeMahlzeit_nfgrund = 0 if HLS1500b == 1
replace dep_warmeMahlzeit_nfgrund = 1 if HLS1500b == 2
replace dep_warmeMahlzeit_nfgrund = 1 if HLS1500b == -1 | HLS1500b == -2
label var dep_warmeMahlzeit_nfgrund "nfgrund: financial"

rename HLS1500b dep_warmeMahlzeit_fgrund
replace dep_warmeMahlzeit_fgrund = . if dep_warmeMahlzeit_fgrund < 0
replace dep_warmeMahlzeit_fgrund = 0 if dep_warmeMahlzeit_fgrund == 2
replace dep_warmeMahlzeit_fgrund = 0 if dep_warmeMahlzeit == 1
label var dep_warmeMahlzeit_fgrund "fgrund: financial"

***********************************************************

rename HLS1600a dep_urlaub
replace dep_urlaub = . if dep_urlaub < 0 
replace dep_urlaub = 0 if dep_urlaub == 2

gen dep_urlaub_nfgrund = 0 if HLS1600b == 1
replace dep_urlaub_nfgrund = 1 if HLS1600b == 2
replace dep_urlaub_nfgrund = 1 if HLS1600b == -1 | HLS1600b == -2
label var dep_urlaub_nfgrund "nfgrund: financial"

rename HLS1600b dep_urlaub_fgrund
replace dep_urlaub_fgrund = . if dep_urlaub_fgrund < 0
replace dep_urlaub_fgrund = 0 if dep_urlaub_fgrund == 2
replace dep_urlaub_fgrund = 0 if dep_urlaub == 1
label var dep_urlaub_fgrund "fgrund: financial"

************************************************************

rename HLS1700a dep_freunde_essen
replace dep_freunde_essen = . if dep_freunde_essen < 0 
replace dep_freunde_essen = 0 if dep_freunde_essen == 2

gen dep_freunde_essen_nfgrund = 0 if HLS1700b == 1
replace dep_freunde_essen_nfgrund = 1 if HLS1700b == 2
replace dep_freunde_essen_nfgrund = 1 if HLS1700b == -1 | HLS1700b == -2
label var dep_freunde_essen_nfgrund "nfgrund: financial"

rename HLS1700b dep_freunde_essen_fgrund
replace dep_freunde_essen_fgrund = . if dep_freunde_essen_fgrund < 0
replace dep_freunde_essen_fgrund = 0 if dep_freunde_essen_fgrund == 2
replace dep_freunde_essen_fgrund = 0 if dep_freunde_essen == 1
label var dep_freunde_essen_fgrund "fgrund: financial"

*************************************************************

rename HLS1800a dep_essen_gehen
replace dep_essen_gehen = . if dep_essen_gehen < 0 
replace dep_essen_gehen = 0 if dep_essen_gehen == 2

gen dep_essen_gehen_nfgrund = 0 if HLS1800b == 1
replace dep_essen_gehen_nfgrund = 1 if HLS1800b == 2
replace dep_essen_gehen_nfgrund = 1 if HLS1800b == -1 | HLS1800b == -2
label var dep_essen_gehen_nfgrund "nfgrund: financial"

rename HLS1800b dep_essen_gehen_fgrund
replace dep_essen_gehen_fgrund = . if dep_essen_gehen_fgrund < 0
replace dep_essen_gehen_fgrund = 0 if dep_essen_gehen_fgrund == 2
replace dep_essen_gehen_fgrund = 0 if dep_essen_gehen == 1
label var dep_essen_gehen_fgrund "fgrund: financial"

**************************************************************

rename HLS1900a dep_ausgehen
replace dep_ausgehen = . if dep_ausgehen < 0 
replace dep_ausgehen = 0 if dep_ausgehen == 2

gen dep_ausgehen_nfgrund = 0 if HLS1900b == 1
replace dep_ausgehen_nfgrund = 1 if HLS1900b == 2
replace dep_ausgehen_nfgrund = 1 if HLS1900b == -1 | HLS1900b == -2
label var dep_ausgehen_nfgrund "nfgrund: financial"

rename HLS1900b dep_ausgehen_fgrund
replace dep_ausgehen_fgrund = . if dep_ausgehen_fgrund < 0
replace dep_ausgehen_fgrund = 0 if dep_ausgehen_fgrund == 2
replace dep_ausgehen_fgrund = 0 if dep_ausgehen == 1
label var dep_ausgehen_fgrund "fgrund: financial"

*************************************************************


rename HLS2000a dep_sparen
replace dep_sparen = . if dep_sparen < 0 
replace dep_sparen = 0 if dep_sparen == 2

gen dep_sparen_nfgrund = 0 if HLS2000b == 1
replace dep_sparen_nfgrund = 1 if HLS2000b == 2
replace dep_sparen_nfgrund = 1 if HLS2000b == -1 | HLS2000b == -2
label var dep_sparen_nfgrund "nfgrund: financial"

rename HLS2000b dep_sparen_fgrund
replace dep_sparen_fgrund = . if dep_sparen_fgrund < 0
replace dep_sparen_fgrund = 0 if dep_sparen_fgrund == 2
replace dep_sparen_fgrund = 0 if dep_sparen == 1
label var dep_sparen_fgrund "fgrund: financial"

*************************************************************


rename HLS2100a dep_moebel
replace dep_moebel = . if dep_moebel < 0 
replace dep_moebel = 0 if dep_moebel == 2

gen dep_moebel_nfgrund = 0 if HLS2100b == 1
replace dep_moebel_nfgrund = 1 if HLS2100b == 2
replace dep_moebel_nfgrund = 1 if HLS2100b == -1 | HLS2100b == -2
label var dep_moebel_nfgrund "nfgrund: financial"

rename HLS2100b dep_moebel_fgrund
replace dep_moebel_fgrund = . if dep_moebel_fgrund < 0
replace dep_moebel_fgrund = 0 if dep_moebel_fgrund == 2
replace dep_moebel_fgrund = 0 if dep_moebel == 1
label var dep_moebel_fgrund "fgrund: financial"

***************************************************************


rename HLS2200a dep_unerw_ausgaben
replace dep_unerw_ausgaben = . if dep_unerw_ausgaben < 0 
replace dep_unerw_ausgaben = 0 if dep_unerw_ausgaben == 2

gen dep_unerw_ausgaben_nfgrund = 0 if HLS2200b == 1
replace dep_unerw_ausgaben_nfgrund = 1 if HLS2200b == 2
replace dep_unerw_ausgaben_nfgrund = 1 if HLS2200b == -1 | HLS2200b == -2
label var dep_unerw_ausgaben_nfgrund "nfgrund: financial"

rename HLS2200b dep_unerw_ausgaben_fgrund
replace dep_unerw_ausgaben_fgrund = . if dep_unerw_ausgaben_fgrund < 0
replace dep_unerw_ausgaben_fgrund = 0 if dep_unerw_ausgaben_fgrund == 2
replace dep_unerw_ausgaben_fgrund = 0 if dep_unerw_ausgaben == 1
label var dep_unerw_ausgaben_fgrund "fgrund: financial"

****************************************************************

rename HLS2300a dep_krankenvers
replace dep_krankenvers = . if dep_krankenvers < 0 
replace dep_krankenvers = 0 if dep_krankenvers == 2

gen dep_krankenvers_nfgrund = 0 if HLS2300b == 1
replace dep_krankenvers_nfgrund = 1 if HLS2300b == 2
replace dep_krankenvers_nfgrund = 1 if HLS2300b == -1 | HLS2300b == -2
label var dep_krankenvers_nfgrund "nfgrund: financial"

rename HLS2300b dep_krankenvers_fgrund
replace dep_krankenvers_fgrund = . if dep_krankenvers_fgrund < 0
replace dep_krankenvers_fgrund = 0 if dep_krankenvers_fgrund == 2
replace dep_krankenvers_fgrund = 0 if dep_krankenvers == 1
label var dep_krankenvers_fgrund "fgrund: financial"

***************************************************************

rename HLS2400a dep_miete_zahlen
replace dep_miete_zahlen = . if dep_miete_zahlen < 0 
replace dep_miete_zahlen = 0 if dep_miete_zahlen == 2

gen dep_miete_zahlen_nfgrund = 0 if HLS2400b == 1
replace dep_miete_zahlen_nfgrund = 1 if HLS2400b == 2
replace dep_miete_zahlen_nfgrund = 1 if HLS2400b == -1 | HLS2400b == -2
label var dep_miete_zahlen_nfgrund "nfgrund: financial"

rename HLS2400b dep_miete_zahlen_fgrund
replace dep_miete_zahlen_fgrund = . if dep_miete_zahlen_fgrund < 0
replace dep_miete_zahlen_fgrund = 0 if dep_miete_zahlen_fgrund == 2
replace dep_miete_zahlen_fgrund = 0 if dep_miete_zahlen == 1
label var dep_miete_zahlen_fgrund "fgrund: financial"

***********************************************************

rename HLS2500a dep_rechn_zahlen
replace dep_rechn_zahlen = . if dep_rechn_zahlen < 0 
replace dep_rechn_zahlen = 0 if dep_rechn_zahlen == 2

gen dep_rechn_zahlen_nfgrund = 0 if HLS2500b == 1
replace dep_rechn_zahlen_nfgrund = 1 if HLS2500b == 2
replace dep_rechn_zahlen_nfgrund = 1 if HLS2500b == -1 | HLS2500b == -2
label var dep_rechn_zahlen_nfgrund "nfgrund: financial"


rename HLS2500b dep_rechn_zahlen_fgrund
replace dep_rechn_zahlen_fgrund = . if dep_rechn_zahlen_fgrund < 0
replace dep_rechn_zahlen_fgrund = 0 if dep_rechn_zahlen_fgrund == 2
replace dep_rechn_zahlen_fgrund = 0 if dep_rechn_zahlen == 1
label var dep_rechn_zahlen_fgrund "fgrund: financial"

* HLS2600a rezeptfreie Medikamente



* Deprivationsindex

egen byte deprivation_ug_gen = rowtotal(dep_anz_zimmer_fgrund dep_wohnung_feucht_fgrund dep_bad_fgrund dep_innenklo_fgrund dep_aussen_fgrund dep_winterkl_fgrund dep_auto_fgrund dep_fernseher_fgrund dep_dvd_fgrund dep_internet_fgrund dep_waschmaschine_fgrund dep_kleidung_fgrund dep_warmeMahlzeit_fgrund dep_urlaub_fgrund dep_freunde_essen_fgrund dep_essen_gehen_fgrund dep_ausgehen_fgrund dep_sparen_fgrund dep_moebel_fgrund dep_unerw_ausgaben_fgrund dep_krankenvers_fgrund dep_miete_zahlen_fgrund dep_rechn_zahlen_fgrund), missing

*Haben-Items 
egen byte deprivation_ug_haben_gen = rowtotal(dep_anz_zimmer_fgrund dep_wohnung_feucht_fgrund dep_bad_fgrund dep_innenklo_fgrund dep_aussen_fgrund dep_winterkl_fgrund dep_auto_fgrund dep_fernseher_fgrund dep_dvd_fgrund dep_internet_fgrund dep_waschmaschine_fgrund), missing
label var deprivation_ug_haben_gen "Deprivationindex material possessions"

*Tun-Items
egen byte deprivation_ug_tun_gen = rowtotal(dep_kleidung_fgrund dep_warmeMahlzeit_fgrund dep_urlaub_fgrund dep_freunde_essen_fgrund dep_essen_gehen_fgrund dep_ausgehen_fgrund dep_sparen_fgrund dep_moebel_fgrund dep_unerw_ausgaben_fgrund dep_krankenvers_fgrund dep_miete_zahlen_fgrund dep_rechn_zahlen_fgrund), missing
label var deprivation_ug_tun_gen "Deprivationindex activities"


* Calculate weights

preserve 

clear all
use "$orig/PENDDAT.dta", clear

foreach var in PLS0100 PLS0200 PLS0300 PLS0400 PLS0500 PLS0600 PLS0700 PLS0800 PLS0900 PLS1000 PLS1100 PLS1200 PLS1300 PLS1400 PLS1500 PLS1600 PLS1700 PLS1800 PLS1900 PLS2000 PLS2100 PLS2200 PLS2300 PLS2400 PLS2500 PLS2600{
gen d_`var' = .
replace d_`var' = 1 if `var' == 1
replace d_`var' = 0 if `var' == 2 | `var' == 3

egen `var'_mean = mean(d_`var')

}

keep hnr welle PLS0100_mean PLS0200_mean PLS0300_mean PLS0400_mean PLS0500_mean PLS0600_mean PLS0700_mean PLS0800_mean PLS0900_mean PLS1000_mean PLS1100_mean PLS1200_mean PLS1300_mean PLS1400_mean PLS1500_mean PLS1600_mean PLS1700_mean PLS1800_mean PLS1900_mean PLS2000_mean PLS2100_mean PLS2200_mean PLS2300_mean PLS2400_mean PLS2500_mean PLS2600_mean

gen help = 1
duplicates drop help, force 
save "$data/deprivation_weights.dta", replace

restore

gen help = 1

merge m:m help using "$data/deprivation_weights.dta"
drop _merge
drop help

rename PLS0100_mean dep_anz_zimmer_mean
rename PLS0200_mean dep_wohnung_feucht_mean
rename PLS0300_mean dep_bad_mean
rename PLS0400_mean dep_innenklo_mean
rename PLS0600_mean dep_aussen_mean
rename PLS0700_mean dep_winterkl_mean
rename PLS0800_mean dep_auto_mean
rename PLS0900_mean dep_fernseher_mean
rename PLS1000_mean dep_dvd_mean
rename PLS1100_mean dep_internet_mean
rename PLS1200_mean dep_waschmaschine_mean
rename PLS1400_mean dep_kleidung_mean
rename PLS1500_mean dep_warmeMahlzeit_mean
rename PLS1600_mean dep_urlaub_mean
rename PLS1700_mean dep_freunde_essen_mean
rename PLS1800_mean dep_essen_gehen_mean
rename PLS1900_mean dep_ausgehen_mean
rename PLS2000_mean dep_sparen_mean
rename PLS2100_mean dep_moebel_mean
rename PLS2200_mean dep_unerw_ausgaben_mean
rename PLS2300_mean dep_krankenvers_mean
rename PLS2400_mean dep_miete_zahlen_mean
rename PLS2500_mean dep_rechn_zahlen_mean

foreach var in dep_anz_zimmer dep_wohnung_feucht dep_bad dep_innenklo dep_aussen dep_winterkl dep_auto dep_fernseher dep_dvd dep_internet dep_waschmaschine dep_kleidung dep_warmeMahlzeit dep_urlaub dep_freunde_essen dep_essen_gehen dep_ausgehen dep_sparen dep_moebel dep_unerw_ausgaben dep_krankenvers dep_miete_zahlen dep_rechn_zahlen{

gen `var'_new = 1 if `var' == 0
replace `var'_new = 0 if `var' == 1

gen `var'_help = `var'_new*`var'_mean
replace `var'_help  = round(`var'_help,0.1)

}




replace dep_anz_zimmer_help = 0 if dep_anz_zimmer_help == .
gen deprivation_g_help = dep_anz_zimmer_help

foreach var in dep_wohnung_feucht dep_bad dep_innenklo dep_aussen dep_winterkl dep_auto dep_fernseher dep_dvd dep_internet dep_waschmaschine dep_kleidung dep_warmeMahlzeit dep_urlaub dep_freunde_essen dep_essen_gehen dep_ausgehen dep_sparen dep_moebel dep_unerw_ausgaben dep_krankenvers dep_miete_zahlen dep_rechn_zahlen{

replace `var'_help  = 0 if `var'_help  == .
replace deprivation_g_help = deprivation_g_help + `var'_help 

}

foreach var in dep_anz_zimmer dep_wohnung_feucht dep_bad dep_innenklo dep_aussen dep_winterkl dep_auto dep_fernseher dep_dvd dep_internet dep_waschmaschine dep_kleidung dep_warmeMahlzeit dep_urlaub dep_freunde_essen dep_essen_gehen dep_ausgehen dep_sparen dep_moebel dep_unerw_ausgaben dep_krankenvers dep_miete_zahlen dep_rechn_zahlen{

gen `var'_nfgrund_help = `var'_nfgrund*`var'_mean
replace `var'_nfgrund_help  = round(`var'_nfgrund_help,0.1)

}


replace dep_anz_zimmer_nfgrund_help = 0 if dep_anz_zimmer_nfgrund_help == .
gen deprivation_g_help2 = dep_anz_zimmer_nfgrund_help

foreach var in dep_wohnung_feucht dep_bad dep_innenklo dep_aussen dep_winterkl dep_auto dep_fernseher dep_dvd dep_internet dep_waschmaschine dep_kleidung dep_warmeMahlzeit dep_urlaub dep_freunde_essen dep_essen_gehen dep_ausgehen dep_sparen dep_moebel dep_unerw_ausgaben dep_krankenvers dep_miete_zahlen dep_rechn_zahlen{

replace `var'_nfgrund_help  = 0 if `var'_nfgrund_help  == .
replace deprivation_g_help2 = deprivation_g_help2 + `var'_nfgrund_help 


}


gen deprivation_g_gen = deprivation_g_help - deprivation_g_help2
replace deprivation_g_gen = . if deprivation_ug_gen == .



* Haben-Items
gen deprivation_g_haben_help = dep_anz_zimmer_help
gen deprivation_g_haben_help2 = dep_anz_zimmer_nfgrund_help


foreach var in  dep_anz_zimmer dep_wohnung_feucht dep_bad dep_innenklo dep_aussen dep_winterkl dep_auto dep_fernseher dep_dvd dep_internet dep_waschmaschine{

replace deprivation_g_haben_help = deprivation_g_haben_help + `var'_help 
replace deprivation_g_haben_help2 = deprivation_g_haben_help2 + `var'_nfgrund_help 

}

gen deprivation_g_haben_gen = deprivation_g_haben_help - deprivation_g_haben_help2
replace deprivation_g_haben_gen = . if deprivation_ug_haben_gen == .

label var deprivation_g_haben_gen "Deprivationindex material possessions (weighted)"


* Tun-Items
gen deprivation_g_tun_help = dep_anz_zimmer_help
gen deprivation_g_tun_help2 = dep_anz_zimmer_nfgrund_help


foreach var in dep_kleidung dep_warmeMahlzeit dep_urlaub dep_freunde_essen dep_essen_gehen dep_ausgehen dep_sparen dep_moebel dep_unerw_ausgaben dep_krankenvers dep_miete_zahlen dep_rechn_zahlen{

replace deprivation_g_tun_help = deprivation_g_tun_help + `var'_help 
replace deprivation_g_tun_help2 = deprivation_g_tun_help2 + `var'_nfgrund_help 

}

gen deprivation_g_tun_gen = deprivation_g_tun_help - deprivation_g_tun_help2
replace deprivation_g_tun_gen = . if deprivation_ug_tun_gen == .


label var deprivation_g_tun_gen "Deprivationindex activities (weigthed)"




foreach var in dep_anz_zimmer dep_wohnung_feucht dep_bad dep_innenklo dep_aussen dep_winterkl dep_auto dep_fernseher dep_dvd dep_internet dep_waschmaschine dep_kleidung dep_warmeMahlzeit dep_urlaub dep_freunde_essen dep_essen_gehen dep_ausgehen dep_sparen dep_moebel dep_unerw_ausgaben dep_krankenvers dep_miete_zahlen dep_rechn_zahlen{

tab `var'
tab `var'_new
tab `var'_help

drop `var'_new
drop `var'_help
drop `var'_mean
drop `var'_nfgrund
drop `var'_nfgrund_help

}

drop deprivation_g_help deprivation_g_help2 deprivation_g_haben_help deprivation_g_haben_help2 deprivation_g_tun_help deprivation_g_tun_help2


sort hnr welle
********************************************************************************
**** HHtyp ****************************
********************************************************************************


replace hhtyp = . if hhtyp == -5

gen hhtyp_mis = (hhtyp == .)
gen hhtyp_1pers = (hhtyp == 1)
gen hhtyp_paarohnekind = (hhtyp == 2)
gen hhtyp_1ElternHH = (hhtyp == 3)
gen hhtyp_paarmitkindernu16 = (hhtyp == 4 | hhtyp == 6)
gen hhtyp_sonst = (hhtyp == 5 | hhtyp == 7 | hhtyp == 8)


********************************************************************************

********************************************************************************
****   Haushaltseinkommen                                **********************
********************************************************************************
** HH einkommen generiert von BA
replace oecdinca = . if oecdinca < 0
replace oecdincn = . if oecdincn < 0
replace hhincome = . if hhincome < 0

gen l_hhincome_orig = log(hhincome)
gen l_hhincome_oecd_1 = log(oecdinca)
gen l_hhincome_oecd_2 = log(oecdincn)

* HH-Einkommen auffüllen, wenn sich HH-Typ nicht ändert
bysort hnr (welle): replace hhincome = hhincome[_n-1] if hhincome == . & hhincome[_n-1] !=. & hhtyp == hhtyp[_n-1] & hhtyp != .

gsort hnr -welle 
by hnr : replace hhincome = hhincome[_n-1] if hhincome == . & hhincome[_n-1] !=. & hhtyp == hhtyp[_n-1] & hhtyp != .

sort hnr welle

gen einkommenHH500 = 0
gen einkommenHH500_1000 = 0
gen einkommenHH1000_1500 = 0
gen einkommenHH1500_2000 = 0
gen einkommenHH2000_3000 = 0
gen einkommenHH3000_4000 = 0
gen einkommenHH4000 = 0



*** in Kategorien
replace einkommenHH500 = 1 if  hhincome < 500
replace einkommenHH500_1000 = 1 if  hhincome >= 500 & hhincome < 1000
replace einkommenHH1000_1500 = 1 if hhincome >= 1000 & hhincome < 1500
replace einkommenHH1500_2000 = 1 if hhincome >= 1500 & hhincome < 2000
replace einkommenHH2000_3000 = 1 if hhincome >= 2000 & hhincome < 3000
replace einkommenHH3000_4000 = 1 if hhincome >= 3000 & hhincome < 4000
replace einkommenHH4000 = 1 if hhincome >= 4000 & hhincome !=.


* HH-Einkommen
gen einkommenHH_mis = (hhincome == .)
label var einkommenHH_mis "HHeinkommen is missing"


********************************************************************************
****   HH bezieht aktuell ALG2                            **********************
********************************************************************************
rename alg2abez ALG2
replace ALG2 = . if ALG2 < 0
replace ALG2 = 0 if ALG2 == 2

rename anzbg anzahlALG2

* ALG2
gen ALG2_mis = (ALG2 == .)
label var ALG2_mis "ALG2-Information des HH is missing"
replace ALG2 = 0 if ALG2_mis == 1



********************************************************************************
****   Wohngeld                          **********************
********************************************************************************
rename HW1800 wohngeld
replace wohngeld = 0 if wohngeld == 2 | wohngeld == -3
replace wohngeld = . if wohngeld < 0

********************************************************************************
**** lpo: Haushaltsgr??*******************************************************
********************************************************************************

gen sizeHH = HA0100
label var sizeHH "Household size"

********************************************************************************
**** lpo: ??wiegend im HH gesprochene Sprache*********************************
********************************************************************************
replace HD0600 = 17 if HD0600 == -5 | HD0600==-6
replace HD0600 = . if HD0600 < 0

gen spracheHH = (HD0600== 1) if HD0600!=.
label var spracheHH "berwiegend deutsch"

* auff??n
sort hnr welle

by hnr (welle): replace spracheHH = spracheHH[_n-1] if spracheHH == . & spracheHH[_n-1]!=.

gsort hnr -welle

by hnr: replace spracheHH = spracheHH[_n-1] if spracheHH == . & spracheHH[_n-1]!=.

sort hnr welle

********************************************************************************
**** lpo: f??inderbetreuung verantwortliche Person****************************
********************************************************************************

rename HKI0600 kinderbetreuungHH
replace kinderbetreuungHH = 4 if kinderbetreuungHH == -5
replace kinderbetreuungHH = . if kinderbetreuungHH < 0

gen  kinderbetreuungHH_mutter = (kinderbetreuungHH == 1) if kinderbetreuungHH!=.
gen  kinderbetreuungHH_vater  = (kinderbetreuungHH == 2) if kinderbetreuungHH!=.
gen  kinderbetreuungHH_beide  = (kinderbetreuungHH == 3) if kinderbetreuungHH!=.
gen  kinderbetreuungHH_sonst  = (kinderbetreuungHH == 4) if kinderbetreuungHH!=.


********************************************************************************
****  lschen von Variablen                               **********************
********************************************************************************

*drop hhinckat hintmod- blneualt bik HW* HA* HLS* HD* HEK* HKI* HBT* butaber- hbtakt3 nbgbezug- depindug2 einzugj

drop hhinckat hintmod- blneualt bik HW* HA* HLS* HD* HEK* HKI* nbgbezug- depindug2 einzugj

order hnr- bland einkommen*

sort hnr welle

* save data
save "$data/haushalt.dta", replace

********************************************************************************

log close





