cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo07_1_Prep_Biospell.log", replace

* Content: Preparation PASS - Biospells

clear all
capture set more off 

use "$orig/bio_spells.dta", clear



********************************************************************************
**** * Globals                                            **********************
********************************************************************************
global oneyear = 365
global fiveyears = 1825
global anz_wave = 10

********************************************************************************
****  Zeitangaben                                         **********************
********************************************************************************
sort pnr spellnr

rename pnr persnr

replace bjahr = . if bjahr < 0
replace ejahr = . if ejahr < 0

replace bmonat = . if bmonat < 0
replace emonat = . if emonat < 0

* falls bmonat ist missing: Annahme Beginn im Januar
replace bmonat = 1 if bmonat == . & bjahr != .

gen beg_spell = mdy(bmonat, 1, bjahr)
gen end_spell = mdy(emonat, 1, ejahr)

format beg_spell %d
format end_spell %d

label var beg_spell "Beginndatum des Spells"
label var end_spell "Enddatum des Spells"

order persnr beg_spell end_spell

********************************************************************************
****  Mergen von Interviewdatum                           **********************
********************************************************************************
sort persnr
merge m:m persnr using "$data/persnr_date.dta"

* Loeschen von unplausiblen Werten
drop if beg_spell == . | end_spell == .
drop if beg_spell == end_spell
drop if end_spell < beg_spell

bysort persnr (beg_spell): replace spellnr = _n
sort spellnr

********************************************************************************
****  Spell-Typ                                           **********************
********************************************************************************

replace spelltyp = . if spelltyp < 0

gen espell = 1 if spelltyp == 1
gen uspell = 1 if spelltyp == 2 | spelltyp == 3
gen nspell = 1 if spelltyp == 6 | spelltyp == 7 | spelltyp == 12


********************************************************************************
****  Dauer pro Spelltyp                                  **********************
********************************************************************************
* Dauer innerhalb des Spells

forvalues i = 1/$anz_wave{
*espell
bysort persnr (spellnr): gen espell_dur`i' = date`i' - beg_spell if beg_spell <= date`i' & end_spell >= date`i' & end_spell != . & espell == 1 & date`i' != .
bysort persnr (spellnr): replace espell_dur`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & end_spell != . & espell == 1 & date`i' != .

*uspell
bysort persnr (spellnr): gen uspell_dur`i' = date`i' - beg_spell if beg_spell <= date`i' & end_spell >= date`i' & end_spell != . & uspell == 1 & date`i' != .
bysort persnr (spellnr): replace uspell_dur`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & end_spell != . & uspell == 1 & date`i' != .

*nspell
bysort persnr (spellnr): gen nspell_dur`i' = date`i' - beg_spell if beg_spell <= date`i' & end_spell >= date`i' & end_spell != . & nspell == 1 & date`i' != .
bysort persnr (spellnr): replace nspell_dur`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & end_spell != . & nspell == 1 & date`i' != .
}


* Dauer in state seit letzter Welle
gen espell_dur_cumlw1 = espell_dur1
gen uspell_dur_cumlw1 = uspell_dur1
gen nspell_dur_cumlw1 = nspell_dur1

forvalues i = 2/$anz_wave{
local k = `i'-1
*espell
bysort persnr (spellnr): gen espell_dur_cum`i' = espell_dur`i'
bysort persnr (spellnr): replace espell_dur_cum`i' = end_spell - date`k' if end_spell <= date`i' & end_spell >= date`k' & end_spell != . & espell == 1 & date`i' != . & date`k' != .

gen espell_dur_cumlw`i' = .

bysort persnr espell (spellnr): replace espell_dur_cum`i' = espell_dur_cum`i' + espell_dur_cum`i'[_n-1] if beg_spell >= end_spell[_n-1]  & espell == 1 & espell[_n-1] == 1 & date`i' != .

* Dauer seit letzter Welle
bysort persnr (spellnr): replace espell_dur_cumlw`i' = espell_dur_cum`i' if espell_dur_cum`i' <= (date`i' - date`k') & espell_dur_cum`i' != . 
bysort persnr (spellnr): replace espell_dur_cumlw`i' = (date`i' - date`k') if espell_dur_cum`i' > (date`i' - date`k') & espell_dur_cum`i' != . 

drop espell_dur_cum`i'
}



forvalues i = 2/$anz_wave{
local k = `i'-1
*uspell
bysort persnr (spellnr): gen uspell_dur_cum`i' = uspell_dur`i'
bysort persnr (spellnr): replace uspell_dur_cum`i' = end_spell - date`k' if end_spell <= date`i' & end_spell >= date`k' & end_spell != . & uspell == 1 & date`i' != . & date`k' != .

gen uspell_dur_cumlw`i' = .

bysort persnr uspell (spellnr): replace uspell_dur_cum`i' = uspell_dur_cum`i' + uspell_dur_cum`i'[_n-1] if beg_spell >= end_spell[_n-1]  & uspell == 1 & uspell[_n-1] == 1 & date`i' != .

* Dauer seit letzter Welle
bysort persnr (spellnr): replace uspell_dur_cumlw`i' = uspell_dur_cum`i' if uspell_dur_cum`i' <= (date`i' - date`k') & uspell_dur_cum`i' != . 
bysort persnr (spellnr): replace uspell_dur_cumlw`i' = (date`i' - date`k') if uspell_dur_cum`i' > (date`i' - date`k') & uspell_dur_cum`i' != . 

drop uspell_dur_cum`i'
}


forvalues i = 2/$anz_wave{
local k = `i'-1
*nspell
bysort persnr (spellnr): gen nspell_dur_cum`i' = nspell_dur`i'
bysort persnr (spellnr): replace nspell_dur_cum`i' = end_spell - date`k' if end_spell <= date`i' & end_spell >= date`k' & end_spell != . & nspell == 1 & date`i' != . & date`k' != .

gen nspell_dur_cumlw`i' = .

bysort persnr nspell (spellnr): replace nspell_dur_cum`i' = nspell_dur_cum`i' + nspell_dur_cum`i'[_n-1] if beg_spell >= end_spell[_n-1]  & nspell == 1 & nspell[_n-1] == 1 & date`i' != .

* Dauer seit letzter Welle
bysort persnr (spellnr): replace nspell_dur_cumlw`i' = nspell_dur_cum`i' if nspell_dur_cum`i' <= (date`i' - date`k') & nspell_dur_cum`i' != . 
bysort persnr (spellnr): replace nspell_dur_cumlw`i' = (date`i' - date`k') if nspell_dur_cum`i' > (date`i' - date`k') & nspell_dur_cum`i' != . 

drop nspell_dur_cum`i'
}


********************************************************************************
****  Ende der Beschaeftigung                              **********************
********************************************************************************
rename ET2300 e_end
replace e_end = . if e_end < 0

forvalues i = 1/$anz_wave{
bysort persnr (spellnr): gen e_end_dauer`i' = date`i' - end_spell if beg_spell <= date`i' & end_spell <= date`i' & espell == 1 & date`i' != .

bysort persnr (spellnr): gen e_end`i' = e_end if beg_spell <= date`i' & end_spell <= date`i' & espell == 1 & date`i' != .
}

replace e_end_dauer10 = . if e_end_dauer9 != . | e_end_dauer8 != . | e_end_dauer7 != . | e_end_dauer6 != . | e_end_dauer5 != . | e_end_dauer4 != . | e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer9 = . if e_end_dauer8 != . | e_end_dauer7 != . | e_end_dauer6 != . | e_end_dauer5 != . | e_end_dauer4 != . | e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer8 = . if e_end_dauer7 != . | e_end_dauer6 != . | e_end_dauer5 != . | e_end_dauer4 != . | e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer7 = . if e_end_dauer6 != . | e_end_dauer5 != . | e_end_dauer4 != . | e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer6 = . if e_end_dauer5 != . | e_end_dauer4 != . | e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer5 = . if e_end_dauer4 != . | e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer4 = . if e_end_dauer3 != . | e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer3 = . if e_end_dauer2 != . | e_end_dauer1 != .
replace e_end_dauer2 = . if e_end_dauer1 != .

replace e_end10 = . if e_end9 != . | e_end8 != . | e_end7 != . | e_end6 != . | e_end5 != . | e_end4 != . | e_end3 != . | e_end2 != . | e_end1 != .
replace e_end9 = . if e_end8 != . | e_end7 != . | e_end6 != . | e_end5 != . | e_end4 != . | e_end3 != . | e_end2 != . | e_end1 != .
replace e_end8 = . if e_end7 != . | e_end6 != . | e_end5 != . | e_end4 != . | e_end3 != . | e_end2 != . | e_end1 != .
replace e_end7 = . if e_end6 != . | e_end5 != . | e_end4 != . | e_end3 != . | e_end2 != . | e_end1 != .
replace e_end6 = . if e_end5 != . | e_end4 != . | e_end3 != . | e_end2 != . | e_end1 != .
replace e_end5 = . if e_end4 != . | e_end3 != . | e_end2 != . | e_end1 != .
replace e_end4 = . if e_end3 != . | e_end2 != . | e_end1 != .
replace e_end3 = . if e_end2 != . | e_end1 != .
replace e_end2 = . if e_end1 != .


********************************************************************************
****  espell nspell uspell aus bio                        **********************
********************************************************************************
forvalues i = 1/$anz_wave{
bysort persnr (spellnr): gen uspell_bio`i' = 1 if beg_spell <= date`i' & end_spell >= date`i' & uspell == 1 & date`i' != .
bysort persnr (spellnr): replace uspell_bio`i' = 0 if beg_spell <= date`i' & end_spell >= date`i' & uspell != 1  & date`i' != .
bysort persnr (spellnr): replace uspell_bio`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & uspell == 1  & date`i' != .
}

forvalues i = 1/$anz_wave{
bysort persnr (spellnr): gen espell_bio`i' = 1 if beg_spell <= date`i' & end_spell >= date`i' & espell == 1 & date`i' != .
bysort persnr (spellnr): replace espell_bio`i' = 0 if beg_spell <= date`i' & end_spell >= date`i' & espell != 1 & date`i' != .
bysort persnr (spellnr): replace espell_bio`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & espell == 1  & date`i' != .
}

forvalues i = 1/$anz_wave{
bysort persnr (spellnr): gen nspell_bio`i' = 1 if beg_spell <= date`i' & end_spell >= date`i' & nspell == 1 & date`i' != .
bysort persnr (spellnr): replace nspell_bio`i' = 0 if beg_spell <= date`i' & end_spell >= date`i' & nspell != 1 & date`i' != .
bysort persnr (spellnr): replace nspell_bio`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & nspell == 1 & date`i' != .
}

forvalues i = 1/$anz_wave{
bysort persnr (spellnr): gen d_ausb_bio`i' = 1 if beg_spell <= date`i' & end_spell >= date`i' & spelltyp == 4 & date`i' != .
bysort persnr (spellnr): replace d_ausb_bio`i' = 0 if beg_spell <= date`i' & end_spell >= date`i' & spelltyp != 4 & date`i' != .
bysort persnr (spellnr): replace d_ausb_bio`i' = 0 if beg_spell <= date`i' & end_spell <= date`i' & spelltyp == 4 & date`i' != .
}

******************************************************************************
**** Auffuellen der Infos                                  **********************
********************************************************************************
forvalues i = 1/$anz_wave{
bysort persnr: egen espell_bio`i'_max = max(espell_bio`i')
bysort persnr: egen uspell_bio`i'_max = max(uspell_bio`i')
bysort persnr: egen nspell_bio`i'_max = max(nspell_bio`i')
bysort persnr: egen d_ausb_bio`i'_max = max(d_ausb_bio`i')

bysort persnr: egen espell_dur`i'_max = max(espell_dur`i')
bysort persnr: egen espell_dur_cumlw`i'_max = max(espell_dur_cumlw`i')

bysort persnr: egen uspell_dur`i'_max = max(uspell_dur`i')
bysort persnr: egen uspell_dur_cumlw`i'_max = max(uspell_dur_cumlw`i')

bysort persnr: egen nspell_dur`i'_max = max(nspell_dur`i')
bysort persnr: egen nspell_dur_cumlw`i'_max = max(nspell_dur_cumlw`i')

bysort persnr: egen e_end`i'_max = max(e_end`i')
bysort persnr: egen e_end_dauer`i'_max = max(e_end_dauer`i')

replace espell_bio`i' = espell_bio`i'_max
replace uspell_bio`i' = uspell_bio`i'_max
replace nspell_bio`i' = nspell_bio`i'_max
replace d_ausb_bio`i' = d_ausb_bio`i'_max
replace espell_dur`i' = espell_dur`i'_max

replace espell_dur_cumlw`i' = espell_dur_cumlw`i'_max
replace uspell_dur`i' = uspell_dur`i'_max
replace uspell_dur_cumlw`i' = uspell_dur_cumlw`i'_max
replace nspell_dur`i' = nspell_dur`i'_max
replace nspell_dur_cumlw`i' = nspell_dur_cumlw`i'_max
replace e_end`i' = e_end`i'_max
replace e_end_dauer`i' = e_end_dauer`i'_max


drop espell_bio`i'_max uspell_bio`i'_max nspell_bio`i'_max d_ausb_bio`i'_max espell_dur`i'_max espell_dur_cumlw`i'_max uspell_dur`i'_max uspell_dur_cumlw`i'_max nspell_dur`i'_max nspell_dur_cumlw`i'_max e_end`i'_max e_end_dauer`i'_max

}

********************************************************************************
**** save the data                                        **********************
********************************************************************************

bysort persnr (spellnr): gen spell = _n
bysort persnr (spellnr): gen spell_N = _N

keep if spell == spell_N

keep persnr  espell_dur1 - d_ausb_bio$anz_wave

reshape long espell_dur uspell_dur nspell_dur espell_bio uspell_bio nspell_bio d_ausb_bio espell_dur_cumlw  uspell_dur_cumlw  nspell_dur_cumlw e_end e_end_dauer, i(persnr) j(welle)

* save data

save "$data/data_bio_spell.dta", replace

********************************************************************************

log close




