cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************

log using "$log/lpo09_1_Prep_PASS_adiab.log", replace

* Content: Preparation PASS - ADIAB - personal data

clear all
capture set more off 

********************************************************************************
********************************************************************************
* Definition of globals
*            _           _               _
*           | |         | |             | |
*     __ _  | |   ___   | |__     __ _  | |  ___
*    / _` | | |  / _ \  | '_ \   / _` | | | / __|
*   | (_| | | | | (_) | | |_) | | (_| | | | \__ \
*    \__, | |_|  \___/  |_.__/   \__,_| |_| |___/
*     __/ |
*    |___/
*
********************************************************************************
********************************************************************************



    * Sample size
    ****************************************************************************

        global sampl = 100


    * Gap thresholds
    ****************************************************************************

	* Luecke zwischen Erwerbststatus
	
	
	    global gap_espell = 32
		global gap_uspell = 32
		global gap_nspell = 32
		
		global gap_etou = 96
		global gap_etoe = 96
		global gap_utoe = 192 
		global gap_utou = 192 

	* Validitaet der Informationen dieser Variablen
		global diff_gesund = 365
		global diff_kind = 365
		global diff_behindert = 365
		global diff_fam_stand = 365


	* Zeitraum in dem Historie berechnet wird: letzte 10 Jahre
		global hist_10 = 3651
		global hist_3  = 1095


********************************************************************************
********************************************************************************
* INPUT
*
*    _                           _
*   (_)                         | |
*    _   _ __    _ __    _   _  | |_
*   | | | '_ \  | '_ \  | | | | | __|
*   | | | | | | | |_) | | |_| | | |_
*   |_| |_| |_| | .__/   \__,_|  \__|
*               | |
*               |_|
*
********************************************************************************
********************************************************************************



    * Open data set, existing sample or draw new sample
    ****************************************************************************


 *use   $data_orig_adiab/PASS-ADIAB_7515_v1.dta, clear
 use   $orig/PASS-ADIAB_7515_v1.dta, clear

********************************************************************************
********************************************************************************
* Non-Destructive Variable Handling
*
*    _                           _   _   _
*   | |                         | | | | (_)
*   | |__     __ _   _ __     __| | | |  _   _ __     __ _
*   | '_ \   / _` | | '_ \   / _` | | | | | | '_ \   / _` |
*   | | | | | (_| | | | | | | (_| | | | | | | | | | | (_| |
*   |_| |_|  \__,_| |_| |_|  \__,_| |_| |_| |_| |_|  \__, |
*                                                     __/ |
*                                                    |___/
*
********************************************************************************
********************************************************************************

	* Stichtage
	***************************************************************************

	gen stichtag_311214 = mdy(12,31,2014)
	gen stichtag_311215 = mdy(12,31,2015)

	* global für Stichtag
	global stichtag = stichtag_311214

	rename pnr persnr


	* generate jahr Variable
	****************************************************************************
	gen jahr = year(begepi)
	gen monat = month(begepi)
	gen tag = day(begepi)

	order persnr jahr monat tag

	label var jahr "Jahr"
	label var monat "Monat"
	label var tag "Tag"


	* mergen von BHP-Daten
	****************************************************************************
	sort betnr jahr
	merge m:m betnr jahr using "$data/PASS_adiab_r_7510_v1_Betriebsdaten.dta"
	drop _merge

	sort persnr spell
	drop if persnr == .


    * Rename
    ****************************************************************************

		*** Variables names differ comapred to SIAB
		* Geschlecht
		rename frau female

		*Nation
		drop nation
		rename nation_gr nation


		* Lohn
		rename tentgelt entgelt

		* Wirtschaftszweig
		rename w93_3_gen w93


		* Familienstand
		rename kind kind_anz
		rename famst fam_stand

		* Schwerbehindertenstatus
		*rename schweb schwerbeh

    * Recode
    ****************************************************************************

		recode wo_kreis -5 -6 -7 -9 .z .n = .
		recode betnr .z .n = .

        recode nation 0 .z .n = .
        recode beruf -5 -7 -8 -9 971 981 982 983 991 997 .n .z = .
        *recode stib -9 -8 -7 -5 .n .z = .
        recode entgelt .n .z = .
        recode erwstat -8 999 .n .z = .
		recode teilzeit .n .z = .
		recode niveau .n .z = .
		recode befrist .n .z = .
		recode leih .n .z = .
        recode ausbildung 9997 9998 9999 .n .z = .
        recode schule 9997 9998 9999 .n .z = .

		rename ausbildung bild
		rename schule schbild


		* 1=BeH, 2=LEH, 7=ASU, 16=LHG, 18=XASU, 32 = MTH
        recode quelle 7 = 3
	    recode quelle 18 = 3
        recode quelle 16 = 4
        recode quelle 32 = 5


		recode fam_stand 6 9997 .n .z = .
		*recode gesund_ein 9997 9999 .n .z = .
		*recode schwerbeh .n .z = .
		recode grund 9997 9999 .n .z = .

		recode art_kuend .n .z = .

		tab art_kuend

    * Format
    ****************************************************************************

        format begepi %d
        format endepi %d
		format begorig %d
        format endorig %d
		format stichtag_311214 %d



    * New Core Variable: Spell counter
    ****************************************************************************

        by persnr (spell), sort: gen spellobs = _N





    compress



********************************************************************************
********************************************************************************
* Filling missings BEFORE deletion of episodes
*                _               _
*               (_)             (_)
*    _ __ ___    _   ___   ___   _   _ __     __ _   ___
*   | '_ ` _ \  | | / __| / __| | | | '_ \   / _` | / __|
*   | | | | | | | | \__ \ \__ \ | | | | | | | (_| | \__ \
*   |_| |_| |_| |_| |___/ |___/ |_| |_| |_|  \__, | |___/
*                                             __/ |
*                                            |___/
*
********************************************************************************
********************************************************************************




    * female
    ****************************************************************************

        * must be constant

        egen meansex = mean(female), by(persnr)

        assert meansex == 0 | meansex == 1 | meansex == .
        * If assertion holds, sex is always constant or missing

        assert meansex==. if female==.
        * If assertion holds, missings cannot be filled (no other information
        * on sex is available).

        drop meansex




   * nation
    ****************************************************************************

        * 1. Look into parallel episodes and use information if available
        egen nation_pll = mean(nation), by(persnr begepi)

            * variable that was an equal value for parallel spells:
            gen nation_imp = round(nation_pll)


        * 2. Fill with previous information based on the equalized variable
        sort persnr spell
        by persnr: replace nation_imp = nation_imp[_n-1] if nation_imp==.


        * 3. Fill with next information
        gsort persnr -spell
        by persnr: replace nation_imp = nation_imp[_n-1] if nation_imp==.


        * replace only missing values of nation with imputed values:
        replace nation = nation_imp if nation==.



        * In all other cases, nation must be always missing for one person. If
        * assertion holds no further filling is possible

        egen nation_mean = mean(nation), by(persnr)
        assert nation_mean==. if nation==.

        drop nation_pll nation_imp nation_mean

        sort persnr spell


 

    * wo_kreis
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that betnr can change ao_kreis!

        sort persnr spell
        by persnr: replace wo_kreis = wo_kreis[_n-1] if wo_kreis==. 

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr -spell
        by persnr: replace wo_kreis = wo_kreis[_n-1] if wo_kreis==. 


        sort persnr spell




   	* w93
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that betnr can change w93!

        sort persnr betnr spell
        by persnr betnr: replace w93 = w93[_n-1] if w93==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace w93 = w93[_n-1] if w93==. & quelle==1 & betnr!=.


        sort persnr spell




    * beruf
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that within betnr a person
        * can change beruf!

        sort persnr betnr spell
        by persnr betnr: replace beruf = beruf[_n-1] if beruf==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace beruf = beruf[_n-1] if beruf==. & quelle==1 & betnr!=.


        sort persnr spell



    * niveau
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that within betnr a person
        * can change niveau!

        sort persnr betnr spell
        by persnr betnr: replace niveau = niveau[_n-1] if niveau==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace niveau = niveau[_n-1] if niveau==. & quelle==1 & betnr!=.


        sort persnr spell


	* teilzeit
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that within betnr a person
        * can change teilzeit!

        sort persnr betnr spell
        by persnr betnr: replace teilzeit = teilzeit[_n-1] if teilzeit==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace teilzeit = teilzeit[_n-1] if teilzeit==. & quelle==1 & betnr!=.


        sort persnr spell

	* befrist
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that within betnr a person
        * can change befrist!

        sort persnr betnr spell
        by persnr betnr: replace befrist = befrist[_n-1] if befrist==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace befrist = befrist[_n-1] if befrist==. & quelle==1 & betnr!=.


        sort persnr spell


	* leih
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that within betnr a person
        * can change leih!

        sort persnr betnr spell
        by persnr betnr: replace leih = leih[_n-1] if leih==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace leih = leih[_n-1] if leih==. & quelle==1 & betnr!=.


        sort persnr spell


    * erwstat
    ****************************************************************************

        * 1. Fill with previous information from the same employer (same betnr):
        * sort first by betnr and then by spell! note that within betnr a person
        * can change erwstat!

        sort persnr betnr spell
        by persnr betnr: replace erwstat = erwstat[_n-1] if erwstat==. & quelle==1 & betnr!=.

        * 2. Fill with next information same employer (same betnr):
        * sort first by betnr and then by spell descending!

        gsort persnr betnr -spell
        by persnr betnr: replace erwstat = erwstat[_n-1] if erwstat==. & quelle==1 & betnr!=.


        sort persnr spell


	/*
  * Gesundheitlichen Einschränkungen
  ****************************************************************************

  * 1. Fill with previous information:


		by persnr: gen endepi_gesund_ein = endepi if gesund_ein !=.

		format endepi_gesund_ein %d

		sort persnr spell
		by persnr: replace endepi_gesund_ein = endepi_gesund_ein[_n-1] if endepi_gesund_ein == .
		by persnr: replace gesund_ein = gesund_ein[_n-1] if gesund_ein == . & (endepi - endepi_gesund_ein) <= $diff_gesund

		gsort persnr -spell
		by persnr: replace endepi_gesund_ein = endepi_gesund_ein[_n-1] if endepi_gesund_ein == .
		by persnr: replace gesund_ein = gesund_ein[_n-1] if gesund_ein == . & (endepi_gesund_ein - endepi) <= $diff_gesund


  * Schwerbehindertenstatus
  ****************************************************************************

  * 1. Fill with previous information:

        sort persnr spell

		gen behindert = 1 if schwerbeh >= 1 & schwerbeh <= 3
		replace behindert = 0 if schwerbeh == 4

		by persnr: gen endepi_behindert = endepi if behindert !=.

		format endepi_behindert %d

		sort persnr spell
		by persnr: replace endepi_behindert = endepi_behindert[_n-1] if endepi_behindert == .
		by persnr: replace behindert = behindert[_n-1] if behindert == . & (endepi - endepi_behindert) <= $diff_behindert

		gsort persnr -spell
		by persnr: replace endepi_behindert = endepi_behindert[_n-1] if endepi_behindert == .
		by persnr: replace behindert = behindert[_n-1] if behindert == . & (endepi_behindert - endepi) <= $diff_behindert


	* gesundheit - Kombination aus gesund_ein und behindert (siehe IAB Auswahl für die Kontrollpersonen)
	****************************************************************************
	gen gesundheit = gesund_ein
	replace gesundheit = 1 if behindert == 1
	replace gesundheit = 0 if behindert == 0 & gesund_ein == .

	*/

* Kinder
  ****************************************************************************

  * 1. Fill with previous information:

		by persnr: gen endepi_kind_anz = endepi if kind_anz !=.

		format endepi_kind_anz %d

		sort persnr spell
		by persnr: replace endepi_kind_anz = endepi_kind_anz[_n-1] if endepi_kind_anz == .
		by persnr: replace kind_anz = kind_anz[_n-1] if kind_anz == . & (endepi - endepi_kind_anz) <= $diff_kind

		gsort persnr -spell
		by persnr: replace endepi_kind_anz = endepi_kind_anz[_n-1] if endepi_kind_anz == .
		by persnr: replace kind_anz = kind_anz[_n-1] if kind_anz == . & (endepi_kind_anz - endepi) <= $diff_kind


* Familienstand
  ****************************************************************************

  * 1. Fill with previous information :

  		by persnr: gen endepi_fam_stand = endepi if fam_stand !=.

		format endepi_fam_stand %d

		sort persnr spell
		by persnr: replace endepi_fam_stand = endepi_fam_stand[_n-1] if endepi_fam_stand == .
		by persnr: replace fam_stand = fam_stand[_n-1] if fam_stand == . & (endepi - endepi_fam_stand) <= $diff_fam_stand

		gsort persnr -spell
		by persnr: replace endepi_fam_stand = endepi_fam_stand[_n-1] if endepi_fam_stand == .
		by persnr: replace fam_stand = fam_stand[_n-1] if fam_stand == . & (endepi_fam_stand - endepi) <= $diff_fam_stand


		* Kuendigungsgrund
		********************************************************************************

		replace art_kuend = 5 if art_kuend == 3 | art_kuend == 6 | art_kuend == 13
		replace art_kuend = 3 if art_kuend == 4
		replace art_kuend = 4 if art_kuend == 5

				#delimit;
				label define art_kuend
					1 "1 - durch Arbeitgeber"
					2 "2 - durch Arbeitnehmer"
					3 "3 - befristeter Vertrag"
					4 "4 - sonstiges";

				label values art_kuend art_kuend;

				#delimit cr

				* Auffuellen

				sort persnr spell
				by persnr: replace art_kuend = art_kuend[_n-1] if art_kuend == . & art_kuend[_n-1] != . & quelle != 1

				gsort persnr -spell
				by persnr: replace art_kuend = art_kuend[_n-1] if art_kuend == . & art_kuend[_n-1] != . & quelle != 1
				by persnr: replace art_kuend = art_kuend[_n-1] if art_kuend == . & art_kuend[_n-1] != . & quelle == 1 & quelle[_n-1] != 1

				gsort persnr betnr -spell
				by persnr betnr: replace art_kuend = art_kuend[_n-1] if art_kuend==. & quelle==1 & betnr!=.

		sort persnr spell

********************************************************************************
********************************************************************************
*
*    _                               _             _     _
*   (_)                             | |           | |   (_)
*    _   _ __ ___    _ __    _   _  | |_    __ _  | |_   _    ___    _ __
*   | | | '_ ` _ \  | '_ \  | | | | | __|  / _` | | __| | |  / _ \  | '_ \
*   | | | | | | | | | |_) | | |_| | | |_  | (_| | | |_  | | | (_) | | | | |
*   |_| |_| |_| |_| | .__/   \__,_|  \__|  \__,_|  \__| |_|  \___/  |_| |_|
*                   | |
*                   |_|
*
********************************************************************************
********************************************************************************




* Imputation/Cleanup: Education
********************************************************************************

* following Chapter 3.2 Imputation Procedure 1 in Fitzenberger et al. (2006)
* http://www.empiwifo.uni-freiburg.de/discussion-papers/fitzenberger/fitzen_osik_voel_revision2.pdf



    * Berechnung des Geburtsjahres (mbl: needed for variable degree)
    ****************************************************************************

	* Alter zu jedem endepi
	    gen age =  year(endepi) - gebjahr



    * reproduce six educ categories
    ****************************************************************************

        gen educ = .

        #delimit;

            replace educ = 1
                if (bild==1 | bild==7 | bild==8)
				&  ( schbild <= 7  );

            replace educ = 2
                if(bild==2 | bild==3 | bild==4)
				&  (schbild <= 7 );

            replace educ = 3
                if (bild==1 | bild==7 | bild==8)
                &  ( schbild > 7 | schbild == . );

            replace educ = 4
                if (bild==2 | bild==3 | bild==4)
                &  ( schbild>7 | schbild == . );

            replace educ = 5
                if bild==5
                |  bild==11 ;

            replace educ = 6
                if bild==6
                |  bild==12;


        label define educ
            1 "ND - no degree at all"
            2 "VT - vocational training degree"
            3 "HS - high school degree (Abitur)"
            4 "HSVT - HS and VT"
            5 "TC - technical college degree"
            6 "UD - university degree" ;

        label values educ educ;

        #delimit cr





    * Step 1: Preparation for Extrapolation
    ****************************************************************************

    * Step 1 distinguishes valid spells with extrapolatable information and in-
    * valid other spells. IP1 uses all employer reports for extrapolation. The
    * nonemployment spells in the IABS (benefit payment spells, interruption
    * spells) do not carry independent education information but repeat the edu-
    * cation information of the most recent employment spell. Hence we do not
    * use this information but treat the spells as spells with missing
    * information. Steps 2 and 3 will extrapolate information to these invalid
    * spells as to other spells with missing information. The original data
    * include educational degrees for persons below the age of 18 jahrs which
    * often seem implausible. Therefore, we first  impute ND for all spells in
    * this age range


        * only use employer reports

            replace educ = . if quelle != 1


        * degrees for persons below the age 18 implausible, impute ND for all
        * spells in this age range

            replace educ = 1 if age < 18



    * Step 2: Forward Extrapolation
    ****************************************************************************

    * Step 2 implements the extrapolation of degrees do later spells. The pro-
    * cedure goes over all spells of an individual person starting with the
    * first spell and ending with the last one. It extrapolates degrees to later
    * spells if the education information reported in these later spells is
    * lower or missing. The extrapolation stops if a spell with a higher degree
    * or the last spell of the person is reached.
    * The extrapolation of education information to subsequent spells has to
    * account for the fact that the degrees HS and VT cannot be ranked. When
    * persons have both degrees this has to be explicitly reported. Hence, the
    * extrapolation rule imputes HSVT if it reaches a spell with one of the two
    * degrees and there is another previous spell for this person with the other
    * degree.


        * extrapolate if the education in later spells is lower or missing:


            sort persnr spell

            #delimit;
            by persnr: replace educ = educ[_n-1]
                if ( educ==. | educ<educ[_n-1] ) & educ[_n-1]!=.;
            #delimit cr


        * imputes HSVT if it reaches a spell with one of the two degrees and
        * there is another previous spell for this person with the other degree.


            sort persnr spell

            #delimit;
            by persnr: replace educ = 4
                if ( educ<=4 & educ[_n-1]==4 )
                |  ( educ==2 & educ[_n-1]==3 )
                |  ( educ==3 & educ[_n-1]==2 );
            #delimit cr



    * Step 3: Backward Extrapolation
    ****************************************************************************

    * The forward extrapolation in step 2 leaves the education information
    * missing, when spells with missing values precede a person's first spell
    * with a valid educational report. Since the educational degree of a person
    * is basically constant over time, we also extrapolate backwards the first
    * valid educational degree to previous spells with missing information. We
    * do not extrapolate backwards degrees beyond degree specific age limits,
    * because the attainment of a certain degree implies a certain amount of
    * jahrs of schooling. The age limits are the median ages at which the
    * degrees are reported for the first time for persons in the data. We do not
    * impute backwards UD below the age of 29 jahrs, TC below 27 jahrs, HSVT
    * below 23 jahrs, HS below 21 jahrs, and VT below 20 jahrs. If the first
    * information reported is ND, this is imputed to all spells before. Note
    * that the first spells of young persons can comprise missing education
    * values, even if these persons show non-missings values in subsequent
    * spells.


        * We do not impute backwards UD below the age of 29 jahrs, TC below 27
        * jahrs, HSVT below 23 jahrs, HS below 21 jahrs, and VT below 20 jahrs.

            gsort persnr -spell
            #delimit;
            by persnr: gen noimpute = 1
                if ( educ[_n-1]==6 & age<29 )
                |  ( educ[_n-1]==5 & age<27 )
                |  ( educ[_n-1]==4 & age<23 )
                |  ( educ[_n-1]==3 & age<21 )
                |  ( educ[_n-1]==2 & age<20 );
            #delimit cr



        * extrapolate backwards the first valid educational degree to previous
        * spells with missing information

            gsort persnr -spell
            by persnr: replace educ = educ[_n-1] if educ==. & noimpute!=1





    * Step 4: Additional adjustments
    ****************************************************************************

    * For persons with missing education information in all spells, we impute VT
    * if their employment status is skilled worker (Facharbeiter ), foreman
    * (Polier ) or master craftsman (Meister ). This is justified by the fact
    * that in almost 90% of the cases with valid education information we
    * observe the degree VT together with such an employment status. Therefore,
    * we impute VT for those cases. Subsequently, we also extrapolate the
    * imputed informa- tion VT forwards and backwards analogous to steps 2 and
    * 3.
    * If persons only have employment spells with other information on em-
    * ployment status and education is missing for all spells, we leave it at
    * that. The data contain a number of parallel spells for persons who hold
    * two or more jobs at the same time. If the imputed education variable so
    * far takes different values for parallel spells we finally impute the
    * highest education information among the parallel spells to these parallel
    * spells.


        * mark persons whose educ is always missig. For these, impute VT if
        * employment status is skilled worker (Facharbeiter)

            egen educ_mean = mean(educ), by(persnr)

            sort persnr
            by persnr: replace educ = 2 if educ_mean==. & niveau==2

            drop educ_mean


        * we also extrapolate the imputed informa- tion VT forwards and
        * backwards analogous to steps 2 and 3.

            * step 2 (without HSVT adjustment)
            sort persnr spell
            #delimit;
            by persnr: replace educ = educ[_n-1]
                if ( educ==. | educ<educ[_n-1] ) & educ[_n-1]!=.;
            #delimit cr


            * step 3 (re-use noimpute age rule)
            gsort persnr -spell
            by persnr: replace educ = educ[_n-1] if educ==. & noimpute!=1

            drop noimpute



        * If the imputed education variable so far takes different values for
        * parallel spells we finally impute the highest education information
        * among the parallel spells to these parallel spells.

            egen educ_max = max(educ), by(persnr begepi)

            replace educ = educ_max

            drop educ_max



    sort persnr spell


* Schulbildung
********************************************************************************

	recode schbild 4 = 2
	recode schbild 5 = 2
	recode schbild 6 = 3
	recode schbild 7 = 4
	recode schbild 8 = 5
	recode schbild 9 = 5

    #delimit;

    label define schbild
        1 "Kein Hauptschulabschluss"
        2 "Hauptschulabschluss"
        3 "Realschulabschluss"
        4 "Fachabitur"
        5 "Abitur";

    #delimit cr

    label values schbild schbild


********************************************************************************
********************************************************************************
* Generation of New Variables after imputation
*
*                                                 _     _
*                                                | |   (_)
*     __ _    ___   _ __     ___   _ __    __ _  | |_   _    ___    _ __
*    / _` |  / _ \ | '_ \   / _ \ | '__|  / _` | | __| | |  / _ \  | '_ \
*   | (_| | |  __/ | | | | |  __/ | |    | (_| | | |_  | | | (_) | | | | |
*    \__, |  \___| |_| |_|  \___| |_|     \__,_|  \__| |_|  \___/  |_| |_|
*     __/ |
*    |___/
*
********************************************************************************
********************************************************************************




/*

    * New Variable: ow_knz = East/West dummy
    ****************************************************************************

        gen ow_knz = 0

            replace ow_knz = 1 if ao_kreis>11999 & ao_kreis<.
            replace ow_knz = . if ao_kreis==.

        label var ow_knz "East"
        label define ow_knz 0 "West" 1 "East"
        label values ow_knz ow_knz

*/



    * New Variable: jobkl (aggregate berufe)
    ****************************************************************************

	* klassifikation der Berufe 1988 - aggregiert

	gen beruf_agg = .
	replace beruf_agg = 1 if beruf <= 44
	replace beruf_agg = 2 if beruf >= 51 & beruf <= 62
	replace beruf_agg = 3 if beruf >= 71 & beruf <= 112
	replace beruf_agg = 4 if beruf > =121 & beruf <= 135
	replace beruf_agg = 5 if beruf == 141
	replace beruf_agg = 6 if beruf >= 142 & beruf <= 144
	replace beruf_agg = 7 if beruf == 151
	replace beruf_agg = 8 if beruf >= 161 & beruf <= 164
	replace beruf_agg = 9 if beruf >= 171 & beruf <= 174
	replace beruf_agg = 10 if beruf >= 175 & beruf <= 177
	replace beruf_agg = 11 if beruf >= 181 & beruf <= 184
	replace beruf_agg = 12 if beruf >= 191 & beruf <= 203
	replace beruf_agg = 13 if beruf >= 211 & beruf <= 213
	replace beruf_agg = 14 if beruf == 221
	replace beruf_agg = 15 if beruf >= 222 & beruf <= 224
	replace beruf_agg = 16 if beruf >= 225 & beruf <= 226
	replace beruf_agg = 17 if beruf >= 231 & beruf <= 244
	replace beruf_agg = 18 if beruf == 241
	replace beruf_agg = 19 if (beruf >= 251 & beruf <= 252) | beruf == 263
	replace beruf_agg = 20 if beruf == 261
	replace beruf_agg = 21 if beruf == 262
	replace beruf_agg = 22 if beruf >= 270 & beruf <= 272
	replace beruf_agg = 23 if beruf == 273
	replace beruf_agg = 24 if beruf >= 274 & beruf <= 275
	replace beruf_agg = 25 if beruf == 281
	replace beruf_agg = 26 if beruf >= 282 & beruf <= 284
	replace beruf_agg = 27 if beruf >= 285 & beruf <= 286
	replace beruf_agg = 28 if beruf >= 291 & beruf <= 302
	replace beruf_agg = 29 if beruf >= 303 & beruf <= 306
	replace beruf_agg = 30 if beruf == 311
	replace beruf_agg = 31 if beruf >= 312 & beruf <= 315
	replace beruf_agg = 32 if beruf == 314
	replace beruf_agg = 33 if beruf == 321
	replace beruf_agg = 34 if beruf == 322
	replace beruf_agg = 35 if beruf == 323
	replace beruf_agg = 36 if (beruf >= 331 & beruf <= 346) | (beruf >= 371 & beruf <= 378)
	replace beruf_agg = 37 if beruf >= 351 & beruf <= 362
	replace beruf_agg = 38 if beruf >= 391 & beruf <= 392
	replace beruf_agg = 39 if beruf >= 401 & beruf <= 403
	replace beruf_agg = 40 if beruf >= 411 & beruf <= 412
	replace beruf_agg = 41 if beruf >= 421 & beruf <= 433
	replace beruf_agg = 42 if beruf >= 441 & beruf <= 442
	replace beruf_agg = 43 if beruf == 451  | beruf == 453
	replace beruf_agg = 44 if beruf == 452
	replace beruf_agg = 45 if beruf >= 461 & beruf <= 462
	replace beruf_agg = 46 if beruf >= 463 & beruf <= 466
	replace beruf_agg = 47 if beruf >= 470 & beruf <= 472
	replace beruf_agg = 48 if beruf >= 481 & beruf <= 482
	replace beruf_agg = 49 if beruf >= 483 & beruf <= 486
	replace beruf_agg = 50 if (beruf >= 491 & beruf <= 492) | (beruf >= 502 & beruf <= 504)
	replace beruf_agg = 51 if beruf == 501
	replace beruf_agg = 52 if beruf == 511
	replace beruf_agg = 53 if beruf >= 512 & beruf <= 514
	replace beruf_agg = 54 if beruf == 521
	replace beruf_agg = 55 if beruf == 522
	replace beruf_agg = 56 if beruf == 531
	replace beruf_agg = 57 if beruf >= 541 & beruf <= 546
	replace beruf_agg = 58 if beruf >= 547 & beruf <= 549
	replace beruf_agg = 59 if beruf == 601
	replace beruf_agg = 60 if beruf == 602
	replace beruf_agg = 61 if beruf == 603
	replace beruf_agg = 62 if beruf >= 604 & beruf <= 607
	replace beruf_agg = 63 if beruf >= 611 & beruf <= 612
	replace beruf_agg = 64 if beruf == 621
	replace beruf_agg = 65 if beruf >= 622 & beruf <= 623
	replace beruf_agg = 66 if beruf >= 624 & beruf <= 627
	replace beruf_agg = 67 if beruf == 628
	replace beruf_agg = 68 if beruf == 629
	replace beruf_agg = 69 if beruf >= 631 & beruf <= 632
	replace beruf_agg = 70 if beruf >= 633 & beruf <= 634
	replace beruf_agg = 71 if beruf == 635
	replace beruf_agg = 72 if beruf == 681
	replace beruf_agg = 73 if beruf == 682
	replace beruf_agg = 74 if beruf >= 683 & beruf <= 686
	replace beruf_agg = 75 if beruf >= 687 & beruf <= 688
	replace beruf_agg = 76 if beruf >= 691 & beruf <= 692
	replace beruf_agg = 77 if beruf >= 693 & beruf <= 694
	replace beruf_agg = 78 if beruf == 701
	replace beruf_agg = 79 if beruf >= 702 & beruf <= 706
	replace beruf_agg = 80 if (beruf >= 711 & beruf <= 713) | (beruf >= 715 & beruf <= 716)
	replace beruf_agg = 81 if beruf == 714
	replace beruf_agg = 82 if beruf >= 721 & beruf <= 726
	replace beruf_agg = 83 if beruf >= 731 & beruf <= 734
	replace beruf_agg = 84 if beruf == 741
	replace beruf_agg = 85 if beruf == 742
	replace beruf_agg = 86 if beruf >= 743 & beruf <= 744
	replace beruf_agg = 87 if beruf == 751
	replace beruf_agg = 88 if beruf >= 752 & beruf <= 753
	replace beruf_agg = 89 if beruf >= 761 & beruf <= 763
	replace beruf_agg = 90 if beruf >= 771 & beruf <= 772
	replace beruf_agg = 91 if beruf == 773
	replace beruf_agg = 92 if beruf == 774
	replace beruf_agg = 93 if beruf == 781
	replace beruf_agg = 94 if beruf >= 782 & beruf <= 783
	replace beruf_agg = 95 if beruf == 784
	replace beruf_agg = 96 if beruf >= 791 & beruf <= 792
	replace beruf_agg = 97 if beruf >= 793 & beruf <= 794
	replace beruf_agg = 98 if beruf >= 801 & beruf <= 814
	replace beruf_agg = 99 if beruf >= 821 & beruf <= 823
	replace beruf_agg = 100 if beruf >= 831 & beruf <= 834
	replace beruf_agg = 101 if beruf >= 835 & beruf <= 838
	replace beruf_agg = 102 if beruf >= 841 & beruf <= 844
	replace beruf_agg = 103 if beruf >= 851 & beruf <= 852
	replace beruf_agg = 104 if beruf == 853
	replace beruf_agg = 105 if beruf == 854
	replace beruf_agg = 106 if beruf == 855  | beruf == 857
	replace beruf_agg = 107 if beruf == 856
	replace beruf_agg = 108 if (beruf >= 861 & beruf <= 863) | (beruf >= 891 & beruf <= 893)
	replace beruf_agg = 109 if beruf == 862
	replace beruf_agg = 110 if beruf == 864
	replace beruf_agg = 111 if beruf >= 871 & beruf <= 874
	replace beruf_agg = 112 if beruf >= 875 & beruf <= 877
	replace beruf_agg = 113 if beruf >= 881 & beruf <= 883
	replace beruf_agg = 114 if beruf >= 901 & beruf <= 902
	replace beruf_agg = 115 if beruf >= 911 & beruf <= 912
	replace beruf_agg = 116 if beruf == 913
	replace beruf_agg = 117 if beruf >= 921 & beruf <= 924
	replace beruf_agg = 118 if beruf >= 931 & beruf <= 932
	replace beruf_agg = 119 if beruf >= 933 & beruf <= 934
	replace beruf_agg = 120 if beruf >= 935 & beruf <= 937
	replace beruf_agg = 121 if beruf == 555 | beruf == 666 | beruf == 888


	drop beruf

	rename beruf_agg beruf


    #delimit;

    gen jobkl=.;

        replace jobkl = 1
            if ( beruf >=   1 & beruf <=   2 );

        replace jobkl = 2
            if ( beruf >=   3 & beruf <=  58 );

        replace jobkl = 3
            if ( beruf >=  59 & beruf <=  70 )
            |  ( beruf >=  87 & beruf <=  89 )
            |  ( beruf >=  98 & beruf <=  99 )
            |  ( beruf == 102 )
            |  ( beruf >= 108 & beruf <= 109 )
            |  ( beruf >= 111 & beruf <= 113 );

        replace jobkl = 4
            if ( beruf >=  73 & beruf <=  75 );

        replace jobkl = 5
            if ( beruf >=  71 & beruf <=  72 )
            |  ( beruf >=  76 & beruf <=  79 )
            |  ( beruf >=  90 & beruf <=  95 );

        replace jobkl = 6
            if ( beruf >=  80 & beruf <=  86 )
            |  ( beruf >=  96 & beruf <=  97 )
            |  ( beruf >= 100 & beruf <= 101 )
            |  ( beruf >= 103 & beruf <= 107 )
            |  ( beruf == 110 )
            |  ( beruf >= 114 & beruf <= 120 );

		*replace jobkl = 7 if beruf == 121;


        label define jobkl
            1 "Landwirtschaftsberufe"
            2 "Produktions-/Facharbeiter, Handwerker"
            3 "Hoehere Angestellte"
            4 "Vertriebs-/Verkaufstaetigkeiten"
            5 "Buerogkeiten"
            6 "Dienstleister";


    #delimit cr

    label values jobkl jobkl




	* Sector classification
	****************************************************************************


	gen sectorkl=.


		#delimit;
		replace sectorkl=1 if
		[w93>=11 & w93<=145] | [w93>=401 & w93<=410];

		replace sectorkl=2 if
		[w93>=232 & w93<=241] | [w93>=246 & w93<=268] | [w93>=201 & w93<=212];

		replace sectorkl=3 if
		[w93>=271 & w93<=296] | [w93>=300 & w93<=313];

		replace sectorkl=4 if
		[w93>=341 & w93<=355] | [w93>=331 & w93<=334] | [w93==297];

		replace sectorkl=5 if
		[w93>=361 & w93<=366] | [w93>=242 & w93<=245] | [w93>=221 & w93<=223] | [w93>=171 & w93<=193] | [w93>=314 & w93<=323] | [w93==335];

		replace sectorkl=6 if
		[w93 >=151 & w93<=160];

		replace sectorkl=7 if
		[w93>=451 & w93<=452];

		replace sectorkl=8 if
		[w93>=453 & w93<=455];

		replace sectorkl=9 if
		[w93>=511 & w93<=517];

		replace sectorkl=10 if
		[w93>=521 & w93<=526] | [w93>=503 & w93<=505] | [w93==501];

		replace sectorkl=11 if
		[w93>=601 & w93<=642]	| [w93==924];

		replace sectorkl=12 if
		[w93>=651 & w93<=703] | [w93>=721 & w93<=746];

		replace sectorkl=13 if
		[w93>=527 & w93<=555] | [w93==502] | [w93>=711 & w93<=714] | [w93>=747 & w93<=748];

		replace sectorkl=14 if
		[w93>=801 & w93<=851]	| [w93==853];

		replace sectorkl=15 if
		[w93>=900 & w93<=913];

		replace sectorkl=16 if
		[w93>=751 & w93<=753];

		replace sectorkl=17 if
		[w93>=921 & w93<=923] | [w93>=925 & w93<=990] | [w93>=371 & w93<=372];

			label define SKL
		1  	"Landwirtschaft, Energie, Bergbau"
		2  	"Grundstoff- & Güterproduktion"
		3  	"Stahl, Leichtmetall, Maschinen"
		4  	"Stahlverformung, Fahrzeugbau, Gerätebau"
		5  	"Konsumgütergewerbe"
		6  	"Nahrungsmittel-/Genussmittelgewerbe"
		7 	"Bauhauptgewerbe"
		8	"Ausbaugewerbe"
		9	"Großhandel"
		10 	"Einzelhandel"
		11	"Verkehr und Nachrichtenübermittlung"
		12	"Wirtschaftsbezogene Dienstleistungen"
		13	"Haushaltsbezogene Dienstleistungen"
		14	"Erziehung, Soziales und Gesundheitssektor"
		15	"(Straßen-)Reinigung, Verbände, Organisationen"
		16	"Öffentliche Verwaltung, Sozialversicherung"
		17	"Sonstiges";

		label values sectorkl SKL;

	#delimit cr
	*****
	tab sectorkl



    * Job status Angestellte(r)/Arbeiter(in)
    ****************************************************************************

        *gen bluecoll    = ( stib==1 | stib==2 ) if !missing(stib)
        *gen whitecoll   = ( stib==4 | stib==3 ) if !missing(stib)






    * Status
    **************************************************************************


		gen pers_gr = .

		/*Sozvers Beschäf*/
		replace pers_gr = 1 if erwstat == 101 | erwstat == 103 | erwstat == 119 |erwstat == 120 | erwstat == 140 | erwstat == 143 | erwstat == 201 | erwstat == 203

		/*Azubi*/
		replace pers_gr = 2 if erwstat == 102 | erwstat == 141 | erwstat == 121 | erwstat == 122 | erwstat == 144

		/*marginal*/
		replace pers_gr = 3 if erwstat == 109 | erwstat == 118 | erwstat == 205 | erwstat == 209 | erwstat == 112

		/*uspell*/
		replace pers_gr = 4 if erwstat < 100

		/*Praktikum/Werk/FreiwilligSoz*/
		replace pers_gr = 5 if erwstat == 105 | erwstat == 106 | erwstat == 123

		/*arbeitslos + krank*/
		replace pers_gr = 6 if erwstat == 32

		/*Ohne Status: Arbeitslos und nicht vermittelbar*/
		replace pers_gr = 7 if erwstat == 34


		label var pers_gr "Personengruppe"
		#delimit;
		label define perso
		1 "sozialvers besch"
		2 "auszubild"
		3 "geringf besch"
		4 "arbeitslos"
		5 "praktikant"
		6 "arbeitslos_krank"
		7 "alo nicht vermittelbar";
		#delimit cr

		label values pers_gr perso
		tab pers_gr


		gen d_mth = 1 if quelle == 5
		replace d_mth = 0 if quelle != 5

		label var d_mth "Maßnahme"



		************************************************************************


       * Dummies für Vollzeit oder Teilzeit

		* Create Dummys

        gen vz   = (teilzeit == 0) if !missing(teilzeit)
        gen tz   = (teilzeit == 1) if !missing(teilzeit)




	************************************************************************
	* Reallöhne


	gen deflator = 0
	replace deflator = 0.439 if jahr==1975
	replace deflator = 0.457 if jahr==1976
	replace deflator = 0.474 if jahr==1977
	replace deflator = 0.487 if jahr==1978
	replace deflator = 0.507 if jahr==1979
	replace deflator = 0.535 if jahr==1980
	replace deflator = 0.568 if jahr==1981
	replace deflator = 0.598 if jahr==1982
	replace deflator = 0.617 if jahr==1983
	replace deflator = 0.633 if jahr==1984
	replace deflator = 0.646 if jahr==1985
	replace deflator = 0.645 if jahr==1986
	replace deflator = 0.646 if jahr==1987
	replace deflator = 0.654 if jahr==1988
	replace deflator = 0.673 if jahr==1989
	replace deflator = 0.691 if jahr==1990

	* ab 1991 f𲠗est-und Ostdeutschland
	replace deflator = 0.702 if jahr==1991
	replace deflator = 0.738 if jahr==1992
	replace deflator = 0.771 if jahr==1993
	replace deflator = 0.791 if jahr==1994
	replace deflator = 0.805 if jahr==1995
	replace deflator = 0.816 if jahr==1996
	replace deflator = 0.832 if jahr==1997
	replace deflator = 0.840 if jahr==1998
	replace deflator = 0.845 if jahr==1999
	replace deflator = 0.857 if jahr==2000
	replace deflator = 0.874 if jahr==2001
	replace deflator = 0.886 if jahr==2002
	replace deflator = 0.896 if jahr==2003
	replace deflator = 0.910 if jahr==2004
	replace deflator = 0.925 if jahr==2005
	replace deflator = 0.939 if jahr==2006
	replace deflator = 0.961 if jahr==2007
	replace deflator = 0.986 if jahr==2008
	replace deflator = 0.989 if jahr==2009
	replace deflator = 1 if jahr==2010
	replace deflator = 1.021 if jahr==2011
	replace deflator = 1.041 if jahr==2012
	replace deflator = 1.057 if jahr==2013
	replace deflator = 1.066 if jahr==2014
	replace deflator = 1.069 if jahr==2015

	rename entgelt entgelt_nom
	gen entgelt = entgelt_nom/deflator

	rename te_imp_mw te_med_nom
	gen te_med = te_med_nom/deflator



********************************************************************************
********************************************************************************
* Handling and deletion episodes
*
*                   _                     _
*                  (_)                   | |
*     ___   _ __    _   ___    ___     __| |   ___   ___
*    / _ \ | '_ \  | | / __|  / _ \   / _` |  / _ \ / __|
*   |  __/ | |_) | | | \__ \ | (_) | | (_| | |  __/ \__ \
*    \___| | .__/  |_| |___/  \___/   \__,_|  \___| |___/
*          | |
*          |_|
*
********************************************************************************
********************************************************************************

	*Ursprünglicher aktueller Wert
	bysort persnr: egen endepi_max = max(endepi)


	format endepi_max %d

	* Dauer der Meldung
	bysort persnr: gen dauer = endepi - begepi + 1

	* Löschen von Dauern mit 0 oder 1 Tag
	drop if dauer == 1  & endepi != endepi_max
	
	
	
	****************************************************************************
	*---------------------------------------------------------------------------
	* Nonemployment       ******************************************************
	*---------------------------------------------------------------------------
	****************************************************************************
	sort persnr spell

	* Lücke zwischen spells
	gen gap = .
	replace gap = begepi-endepi[_n-1] if persnr==persnr[_n-1]

	gen nspell = 0
	replace nspell = 1 if gap > $gap_nspell & gap != .

	*Dauer
	bysort persnr: gen nspell_dauer_cum = sum(gap) if nspell==1
	bysort persnr: replace nspell_dauer_cum = nspell_dauer_cum[_n-1]  if nspell_dauer_cum==. & nspell_dauer_cum[_n-1] != .

	* Anzahl
	bysort persnr (spell): gen n_nspell = sum(nspell) if nspell == 1
	bysort persnr (spell): replace n_nspell =n_nspell[_n-1] if n_nspell == . & n_nspell[_n-1] != .

	* Missings mit Nullen ersetzen
	replace n_nspell = 0 if n_nspell == .
	replace nspell_dauer_cum = 0 if nspell_dauer_cum == .


    drop gap nspell


	*********************************************************************************************
	*--------------------------------------------------------------------------------------------
	* Sozialversicherungspflichtige und geringfügige Beschäftigung         **********************
	*--------------------------------------------------------------------------------------------
	*********************************************************************************************
	gen pers_soz = (pers_gr == 1)
	gen pers_ger = (pers_gr == 3)

	foreach var in soz ger {

	sort persnr pers_`var' spell

	drop if begepi >= begepi[_n-1] & endepi <= endepi[_n-1] & pers_`var' == 1 & pers_`var'[_n-1] == 1 & betnr == betnr[_n-1] & persnr==persnr[_n-1]

	sort persnr betnr pers_`var' spell
	* Lücke zwischen Einträgen beim selben Arbeitgeber
	gen gap_espell_`var' = .
	replace gap_espell_`var' = begepi-endepi[_n-1] if persnr==persnr[_n-1]  & betnr == betnr[_n-1] & pers_`var' == 1 & pers_`var'[_n-1] == 1
	
	gen dauer_help = dauer + gap_espell_`var' - 1 if gap_espell_`var'  != . & gap_espell_`var' <= $gap_espell
	replace dauer = dauer_help if dauer_help != .
	drop dauer_help

	* Indikator, wenn Lücke klein
	* erster Eintrag
	by persnr: gen espell_`var'_neu = 1 if pers_`var' == 1 & (betnr != betnr[_n-1] | pers_`var' [_n-1]!=1 | gap_espell_`var' > $gap_espell)
	by persnr: gen espell_`var' = 1 if pers_`var'  == 1

	* Anzahl
	bysort persnr (spell): gen n_espell_`var' = sum(espell_`var') if espell_`var'_neu == 1
	bysort persnr espell_`var' (spell): replace n_espell_`var' = n_espell_`var'[_n-1] if n_espell_`var' == . & n_espell_`var'[_n-1] != . & espell_`var' == 1


	* Dauer des spells
	bysort persnr (spell): gen espell_`var'_dauer_cum = sum(dauer) if espell_`var' == 1
	bysort persnr n_espell_`var' (spell): gen espell_`var'_dauer = sum(dauer)

	bysort persnr (spell): replace espell_`var'_dauer_cum = espell_`var'_dauer_cum[_n-1]  if espell_`var'_dauer_cum==. & espell_`var'_dauer_cum[_n-1] != .
	bysort persnr: replace n_espell_`var' = n_espell_`var'[_n-1] if n_espell_`var' == . & n_espell_`var'[_n-1] != .

	* Informationen des letzten spells
	sort persnr spell
	bysort persnr: gen espell_`var'_dauer_last = espell_`var'_dauer if espell_`var' == 1
	bysort persnr: replace espell_`var'_dauer_last = espell_`var'_dauer_last[_n-1]  if espell_`var'_dauer_last==. & espell_`var'_dauer_last[_n-1] != .

	bysort persnr: gen espell_`var'_entgelt_last = entgelt if espell_`var' == 1
	bysort persnr: replace espell_`var'_entgelt_last = espell_`var'_entgelt_last[_n-1] if espell_`var'_entgelt_last==. & espell_`var'_entgelt_last[_n-1] != .

	bysort persnr: gen espell_`var'_jobkl_last = jobkl if espell_`var' == 1
	bysort persnr: replace espell_`var'_jobkl_last = espell_`var'_jobkl_last[_n-1] if espell_`var'_jobkl_last==. & espell_`var'_jobkl_last[_n-1] != .

	bysort persnr: gen espell_`var'_sectorkl_last = sectorkl if espell_`var' == 1
	bysort persnr: replace espell_`var'_sectorkl_last = espell_`var'_sectorkl_last[_n-1] if espell_`var'_sectorkl_last==. & espell_`var'_sectorkl_last[_n-1] != .

	bysort persnr: gen espell_`var'_az_ges_last = az_ges if espell_`var' == 1
	bysort persnr: replace espell_`var'_az_ges_last = espell_`var'_az_ges_last[_n-1] if espell_`var'_az_ges_last==. & espell_`var'_az_ges_last[_n-1] != .

	bysort persnr: gen espell_`var'_te_med_last = te_med if espell_`var' == 1
	bysort persnr: replace espell_`var'_te_med_last = espell_`var'_te_med_last[_n-1] if espell_`var'_te_med_last==. & espell_`var'_te_med_last[_n-1] != .

	*bysort persnr: gen espell_`var'_bluecoll_last = bluecoll if espell_`var' == 1
	*bysort persnr: replace espell_`var'_bluecoll_last = espell_`var'_bluecoll_last[_n-1] if espell_`var'_bluecoll_last==. & espell_`var'_bluecoll_last[_n-1] != .

	*bysort persnr: gen espell_`var'_whitecoll_last = whitecoll if espell_`var' == 1
	*bysort persnr: replace espell_`var'_whitecoll_last = espell_`var'_whitecoll_last[_n-1] if espell_`var'_whitecoll_last==. & espell_`var'_whitecoll_last[_n-1] != .

	bysort persnr: gen espell_`var'_vz_last = vz if espell_`var' == 1
	bysort persnr: replace espell_`var'_vz_last = espell_`var'_vz_last[_n-1] if espell_`var'_vz_last==. & espell_`var'_vz_last[_n-1] != .

	bysort persnr: gen espell_`var'_tz_last = tz if espell_`var' == 1
	bysort persnr: replace espell_`var'_tz_last = espell_`var'_tz_last[_n-1] if espell_`var'_tz_last==. & espell_`var'_tz_last[_n-1] != .

	bysort persnr: gen espell_`var'_endepi_last = endepi if espell_`var' == 1
	bysort persnr: replace espell_`var'_endepi_last = espell_`var'_endepi_last[_n-1] if espell_`var'_endepi_last==. & espell_`var'_endepi_last[_n-1] != .

	bysort persnr: replace n_espell_`var' = n_espell_`var'[_n-1] if espell_`var' != 1
	bysort persnr: replace espell_`var'_dauer = espell_`var'_dauer[_n-1] if espell_`var' != 1

	* Löschen unnötiger Variablen
	drop espell_`var'_neu gap_espell_`var' pers_`var'

	* Missings mit Nullen ersetzen
	replace n_espell_`var' = 0 if n_espell_`var' == .
	replace espell_`var'_dauer_cum = 0 if espell_`var'_dauer_cum == .
	replace espell_`var'_dauer_last = 0 if espell_`var'_dauer_last == .


	}

	****************************************************************************
	*---------------------------------------------------------------------------
	* Arbeitslosigkeit          ************************************************
	*---------------------------------------------------------------------------
	****************************************************************************
	gen pers_uspell = (quelle > 1 & quelle != .)
	gen pers_uspell_krank = (pers_gr == 6)
	gen pers_uspell_kverm = (pers_gr == 7)
	gen pers_mth = (d_mth == 1)


	foreach var in uspell uspell_krank uspell_kverm mth{

	sort persnr pers_`var' spell

	drop if begepi >= begepi[_n-1] & endepi <= endepi[_n-1] & pers_`var' == 1 & pers_`var'[_n-1] == 1 & persnr==persnr[_n-1]

	sort persnr pers_`var' spell
	* Lücke zwischen Einträgen 
	gen gap_`var' = .
	replace gap_`var' = begepi-endepi[_n-1] if persnr==persnr[_n-1] & pers_`var' == 1 & pers_`var'[_n-1] == 1
	
	gen dauer_help = dauer + gap_`var' - 1 if gap_`var'  != . & gap_`var' <= $gap_uspell
	replace dauer = dauer_help if dauer_help != .
	drop dauer_help

	* Indikator, wenn Lücke klein
	* erster Eintrag
	by persnr: gen `var'_neu = 1 if pers_`var' == 1 & (pers_`var' [_n-1]!=1 | gap_`var' > $gap_uspell)
	by persnr: gen `var' = 1 if pers_`var'  == 1

	* Anzahl
	bysort persnr (spell): gen n_`var' = sum(`var') if `var'_neu == 1
	bysort persnr `var' (spell): replace n_`var' = n_`var'[_n-1] if n_`var' == . & n_`var'[_n-1] != . & `var' == 1

	* Dauer des spells
	bysort persnr (spell): gen `var'_dauer_cum = sum(dauer) if `var' == 1
	bysort persnr n_`var' (spell): gen `var'_dauer = sum(dauer) if `var' == 1

	bysort persnr (spell): replace `var'_dauer_cum = `var'_dauer_cum[_n-1]  if `var'_dauer_cum==. & `var'_dauer_cum[_n-1] != .
	bysort persnr: replace n_`var' = n_`var'[_n-1] if n_`var' == . & n_`var'[_n-1] != .

	* Löschen unnötiger Variablen
	drop `var' `var'_neu gap_`var' pers_`var'

	* Missings mit Nullen ersetzen
	replace n_`var' = 0 if n_`var' == .
	replace `var'_dauer_cum = 0 if `var'_dauer_cum == .
	}

	drop uspell_krank_dauer uspell_kverm_dauer mth_dauer
	
	
	****************************************************************************

	* Merge Arbeitslosenquoten auf Kreisebene

	gen Kreis_ID = wo_kreis
	gen year = jahr
	gen month = monat

	* Anpassen von Kreisen aufgrund von Kreisreformen:

	replace Kreis_ID = 13058 if Kreis_ID == 13074
	replace Kreis_ID = 14161 if Kreis_ID == 14511
	replace Kreis_ID = 14178 if Kreis_ID == 14523
	replace Kreis_ID = 14262 if Kreis_ID == 14612
	replace Kreis_ID = 14272 if Kreis_ID == 14625
	replace Kreis_ID = 14280 if Kreis_ID == 14627
	replace Kreis_ID = 14365 if Kreis_ID == 14713
	replace Kreis_ID = 15202 if Kreis_ID == 15002
	replace Kreis_ID = 15303 if Kreis_ID == 15003
	replace Kreis_ID = 15370 if Kreis_ID == 15081
	replace Kreis_ID = 15256 if Kreis_ID == 15084
	replace Kreis_ID = 15358 if Kreis_ID == 15086
	replace Kreis_ID = 15363 if Kreis_ID == 15090
	replace Kreis_ID = 15171 if Kreis_ID == 15091
	replace Kreis_ID = 3241  if Kreis_ID == 3241001
	replace Kreis_ID = 5313  if Kreis_ID == 5334002
	replace Kreis_ID = 10041 if Kreis_ID == 10041100


	* Monatliche Arbeitslosenquoten

	sort Kreis_ID year month
	merge m:m Kreis_ID year month using "$orig/ALO_Kreis_Monat.dta"
	drop _merge
	drop if persnr==.

	/*
	* Nimm jaehrliche Arbeitslosenquoten falls monatliche Quote ist missing

	sort Kreis_ID year
	merge m:m Kreis_ID year using "$orig/ALO_Kreis_Jahr.dta"
	drop _merge
	drop if persnr==.

	replace ALO_Quote1 = alq if ALO_Quote1 == . & alq!=.
	*/


********************************************************************************
********************************************************************************
*
*                    _                     _
*                   | |                   | |
*     ___    _   _  | |_   _ __    _   _  | |_
*    / _ \  | | | | | __| | '_ \  | | | | | __|
*   | (_) | | |_| | | |_  | |_) | | |_| | | |_
*    \___/   \__,_|  \__| | .__/   \__,_|  \__|
*                         | |
*                         |_|
*
********************************************************************************
********************************************************************************


	sort persnr spell

	* aktueller Status
	gen status_espell_soz = (pers_gr == 1)
	gen status_espell_ger = (pers_gr == 3)
	gen status_uspell = (quelle > 1 & quelle != .)
	gen status_uspell_krank = (pers_gr == 6)
	gen status_uspell_kverm = (pers_gr == 7)
	gen status_mth = (d_mth == 1)


	* mehrere spells parallel
	sort persnr begepi betnr quelle

	bysort persnr begepi (betnr): gen parallel = _n
	tab parallel


	* Neue Definition von spell
	drop spell

	sort persnr begepi parallel
	bysort persnr: gen spell = _n

	foreach var in status_espell_soz status_espell_ger status_uspell status_uspell_krank status_uspell_kverm status_mth{
	bysort persnr begepi (parallel): egen `var'_max = max(`var')
	bysort persnr begepi (parallel): replace `var' = `var'_max
	drop `var'_max
	}



	** Datensatz Zwischenspeichern
	****************************************************************************
	sort persnr spell

	save "$data/PASS_adiab_all.dta", replace



	*use "$data/PASS_adiab_all.dta", replace


	****************************************************************************
	* Definition der Treatment-Variable
	* in Periode t beschäftigt und in Periode t+1 arbeitslos; nur Personen, die nur beschäftigt bzw. nur arbeitslos sind


	* Dauern und Anzahl bei parallelen spells müssen angepasst werden
	
	foreach var in espell_soz espell_ger uspell uspell_krank uspell_kverm mth{
	bysort persnr begepi: egen `var'_dauer_cum_max = max(`var'_dauer_cum)	
	bysort persnr begepi: egen n_`var'_max = max(n_`var')
	
	replace `var'_dauer_cum = `var'_dauer_cum_max
	replace n_`var'= n_`var'_max
	
	drop `var'_dauer_cum_max n_`var'_max
	}
	
	foreach var in espell_soz espell_ger{
	bysort persnr begepi: egen `var'_dauer_last_max = max(`var'_dauer_last)
	replace `var'_dauer_last = `var'_dauer_last_max
	drop `var'_dauer_last_max
		}
		
	foreach var in uspell{
	bysort persnr begepi: egen `var'_dauer_max = max(`var'_dauer)
	replace `var'_dauer = `var'_dauer_max
	drop `var'_dauer_max
	}
		
	* Löschen von spells, die weder uspell noch Beschäftigungsspell sind

	drop if pers_gr != 1 & pers_gr != 3 & quelle == 1

	* Welche parallelen spells wollen wir behalten?

	* Löschen von uspells
	drop if parallel >=2 & quelle!=1

	sort persnr spell


	* Wer wird arbeitslos?

	bysort persnr (spell): gen treat_unempl = 1 if ((status_espell_soz[_n-1] == 1 | status_espell_ger[_n-1] == 1) & (status_uspell[_n-1] == 0 | (status_uspell[_n-1] == 1 & (begepi[_n-1] - endepi[_n-1]) <= $gap_espell ))) & (status_espell_soz == 0 & status_espell_ger == 0 & status_mth == 0 & status_uspell == 1) & ((begepi - endepi[_n-1]) <= $gap_etou)

	bysort persnr (spell): replace treat_unempl = treat_unempl[_n-1] if (status_espell_soz == 0 & status_espell_ger == 0 & status_mth == 0 & status_uspell == 1) & treat_unempl[_n-1] == 1


	* Wer bleibt in demselben Betrieb beschaeftigt?

	bysort persnr betnr (spell): replace treat_unempl = 0 if betnr == betnr[_n-1] & betnr != . & treat_unempl != 1
	bysort persnr betnr (spell): replace treat_unempl = 0 if treat_unempl[_n+1]==0

	sort persnr spell

	* Auffüllen pro gleichem Betrieb

	bysort persnr  begepi: egen treat_unempl_par = max(treat_unempl)


	sort persnr spell

	drop treat_unempl

	gen treat_unempl = treat_unempl_par


	* mehrere geringfügige Beschäftigungsspells parallel
	sort persnr begepi espell_ger_dauer

	by persnr begepi: gen parallel_ger = _n if pers_gr == 3

	bysort persnr begepi: egen parallel_ger_max = max(parallel_ger)

	* Welchen ger spell wollen wir behalten? -> Letzte Beschaeftigung

	* mehrere sozialversicherungspflichtige Beschaeftgiungsspells parallel
	sort persnr begepi espell_soz_dauer

	by persnr begepi: gen parallel_soz = _n if pers_gr == 1

	by persnr begepi: egen parallel_soz_max = max(parallel_soz)

	* Welchen soz spell wollen wir behalten? -> Letzte Beschäftigung


	* Entgelt kumulieren falls paralleler spell

	by persnr begepi: egen espell_soz_entgelt_last_par = sum(entgelt) if status_espell_soz == 1
	by persnr begepi: egen espell_ger_entgelt_last_par = sum(entgelt) if status_espell_ger == 1

	replace espell_soz_entgelt_last = espell_soz_entgelt_last_par if espell_soz_entgelt_last_par != . & espell_soz_entgelt_last_par != espell_soz_entgelt_last
	replace espell_ger_entgelt_last = espell_ger_entgelt_last_par if espell_ger_entgelt_last_par != . & espell_ger_entgelt_last_par != espell_ger_entgelt_last

	drop espell_soz_entgelt_last_par espell_ger_entgelt_last_par

	* Parallele Spells ausschließen

	sort persnr spell

	drop if parallel_ger!=parallel_ger_max & pers_gr == 3

	drop if parallel_soz!=parallel_soz_max & pers_gr == 1

	* soz geht vor ger
	sort persnr begepi pers_gr spell
	by persnr begepi: gen parallel_soz_ger = _n

	drop if parallel_soz_ger >= 2



	*****************************************************************************
	* Sind noch parallele spells uebrig?

	bysort persnr begepi: gen help = _n
	tab help
	drop help

	* Nein!

	****************************************************************************
	* Schließen von Lücken von espell to uspell und job to job transitions nach Eliminierung von parallelen Spells
	sort persnr spell
	bysort persnr (begepi): gen gap = begepi - endepi[_n-1]
	
	gen begepi_orig = begepi
	gen endepi_orig = endepi
	
	
	bysort persnr (begepi): gen d_etou = 1 if  gap[_n+1] <= $gap_etou & quelle == 1 & quelle[_n+1] > 1
	bysort persnr (begepi): gen d_etoe = 1 if  gap[_n+1] <= $gap_etoe & quelle == 1 & quelle[_n+1] == 1
	bysort persnr (begepi): gen d_utou = 1 if  gap[_n+1] <= $gap_utou & quelle > 1 & quelle[_n+1] > 1
	bysort persnr (begepi): gen d_utoe = 1 if  gap[_n+1] <= $gap_utoe & quelle > 1 & quelle[_n+1] == 1
	
	bysort persnr (begepi): replace endepi = begepi[_n+1] - 1 if  gap[_n+1] <= $gap_etou & quelle == 1 & quelle[_n+1] > 1
	bysort persnr (begepi): replace endepi = begepi[_n+1] - 1 if  gap[_n+1] <= $gap_etoe & quelle == 1 & quelle[_n+1] == 1
	bysort persnr (begepi): replace endepi = begepi[_n+1] - 1 if  gap[_n+1] <= $gap_utou & quelle > 1 & quelle[_n+1] > 1
	bysort persnr (begepi): replace endepi = begepi[_n+1] - 1 if  gap[_n+1] <= $gap_utoe & quelle > 1 & quelle[_n+1] == 1
	
	

	sort persnr spell
	****************************************************************************
	*drop espell_soz espell_ger begorig endorig bild grund entgelt_nom gleitz stib erwstat estatvor art_kuend arbzeit restanspruch traeger wo_aa wo_rd wo_kreis Kreis_ID year month wo_bula ao_aa ao_rd stichtag_311214 stichtag_311215  w93 grd_dat lzt_dat az_ges te_med_nom ao_kreis ao_bula dauer endepi_gesund_ein endepi_behindert endepi_kind_anz endepi_fam_stand

	drop espell_soz espell_ger begorig endorig bild grund entgelt_nom gleitz teilzeit erwstat estatvor arbzeit restanspruch beruf2010_3 estatnach profil alo_beg alo_dau traeger wo_rd stichtag_311214 stichtag_311215  w93 grd_jahr lzt_jahr az_ges te_med_nom ao_bula dauer endepi_kind_anz endepi_fam_stand

	* Erstellen von Datensatz basierend auf spellc
	duplicates drop persnr begepi, force
	
	* uspells können über mehrere Jahre gehen
	* diese spells werden dupliziert
	gen help = year(endepi) - year(begepi)
	gen help_2 = help + 1
	expand help_2 if help > 0
	sort persnr begepi
	
	
	* Die Jahresvariable muss angepasst werden
	bysort persnr begepi: gen help_3 = _n
	replace jahr = jahr + help_3 - 1 if help_3 > 1
	
	drop help help_2 help_3

	save "$data/PASS_adiab.dta", replace
	
	* Merge Interviewzeitpunkt
	sort persnr jahr
	use "$data/persnr_date_2.dta", replace
		
	merge m:m persnr jahr using "$data/PASS_adiab.dta"
	keep if _merge == 3
	drop _merge

	* Behalte nur spells zum Interviewzeitpunkt
	****************************************************************************
	** Stichtag: Interviewzeitpunkt
	****************************************************************************

	keep if begepi <= date & endepi >= date

	* Personen, deren Lücken aufgefüllt wurden
	gen status_nspell = 0
	replace status_nspell = 1 if endepi != endepi_orig & date > endepi_orig & date!=.
	
	gen nspell_dauer = 0
	replace nspell_dauer = date - endepi_orig if status_nspell == 1
	
	gen d_gap_etou = 1 if status_nspell == 1 & d_etou == 1
	gen d_gap_etoe = 1 if status_nspell == 1 & d_etoe == 1
	gen d_gap_utoe = 1 if status_nspell == 1 & d_utoe == 1
	gen d_gap_utou = 1 if status_nspell == 1 & d_utou == 1
	

	* Dauern anpassen, falls endepi nach date
	foreach var in espell_soz espell_ger uspell uspell_krank uspell_kverm mth{
	gen `var'_dauer_cum_2 = `var'_dauer_cum - (endepi_orig - date) if endepi_orig >= date & begepi <= date  & status_`var'==1
	replace `var'_dauer_cum = `var'_dauer_cum_2 if `var'_dauer_cum_2!=.
	drop `var'_dauer_cum_2
	}
	
	foreach var in espell_soz espell_ger{
	gen `var'_dauer_last_2 = `var'_dauer_last - (endepi_orig - date) if endepi_orig >= date & begepi <= date & status_`var'==1
	replace `var'_dauer_last = `var'_dauer_last_2 if `var'_dauer_last_2!=.
	drop `var'_dauer_last_2
	
	}
	
	foreach var in uspell{
	gen `var'_dauer_2 = `var'_dauer - (endepi_orig - date) if endepi_orig >= date & begepi <= date & status_`var'==1
	replace `var'_dauer = `var'_dauer_2 if `var'_dauer_2!=.
	drop `var'_dauer_2
	
	}
	
	sort persnr date
	order persnr date

	drop jahr monat tag betnr quelle spell begepi endepi spellobs beruf jobkl sectorkl pers_gr vz tz deflator entgelt te_med endepi_max gap


	foreach var in female nation fam_stand kind_anz age schbild educ gebjahr art_kuend befrist leih{
	rename `var' `var'_adiab
	}

	compress
	save "$data/PASS_adiab.dta", replace


    log close








