cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo10_1_Prep_merge.log", replace

* Content: Preparation PASS - Mergen data sets

clear all
capture set more off 

use "$data/soziodemo.dta", clear

merge 1:1 persnr welle using "$data/arbeitsmarkt.dta"
drop _merge
merge 1:1 persnr welle using "$data/arbeitssuche.dta"
drop _merge
*merge 1:1 persnr welle using "$data/person_weights.dta"
*drop _merge
merge m:m persnr welle using "$data/data_bio_spell.dta"
drop _merge
sort hnr welle
merge m:m hnr welle using "$data/haushalt.dta"
drop _merge
sort persnr welle
merge m:m persnr welle using "$data/partner_id.dta"
drop _merge
sort persnr date
merge m:m persnr date using "$data/PASS_adiab.dta"
drop _merge

********************************************************************************


* Loeschen von Beobachtungen
drop if persnr == .
drop if welle == .
drop if female == .
drop if age == .


* einige anpassungen von spells

* suche arbeitslos
replace suche = 1 if (suche_online == 0 | suche_online == 1) & uspell == 1

replace espell = 0 if espell == . & suche == 1
replace uspell = 1 if uspell == . & suche == 1
replace nspell = 0 if nspell == . & suche == 1

* suche employed
replace espell = 1 if espell == . & (suche_erw_d == 1 | suche_erw_d == 0)
replace uspell = 0 if uspell == . & (suche_erw_d == 1 | suche_erw_d == 0)
replace nspell = 0 if nspell == . & (suche_erw_d == 1 | suche_erw_d == 0)

* Infos aus bio-spells
replace espell = 1 if espell_bio == 1
replace espell = espell_bio if espell == .

replace uspell = 1 if uspell_bio == 1
replace uspell = uspell_bio if uspell == .

replace nspell = 1 if nspell_bio == 1
replace nspell = nspell_bio if nspell == .

replace d_ausb = 1 if d_ausb_bio == 1
replace d_ausb =  d_ausb_bio if d_ausb == .

replace espell = 1 if status_espell_soz == 1 | status_espell_ger == 1
replace espell = 0 if status_espell_soz == 0 & status_espell_ger == 0
replace uspell = 1 if status_uspell == 1 
replace uspell = 0 if status_uspell == 0
replace mspell = 1 if status_mth==1
replace mspell = 0 if status_mth==0 | uspell==0
replace nspell = 1 if status_nspell == 1
replace nspell = 0 if status_nspell == 0

* Anpassung von Berufsausbildung
replace BA_keine = 1 if BA_keine == . & (educ_adiab == 1 | educ_adiab == 3)
replace BA_keine = 0 if BA_keine == . & educ_adiab != 1 & educ_adiab  != 3 & educ_adiab  != .
replace BA_lehre = 1 if BA_lehre == . & (educ_adiab == 2 | educ_adiab == 4)
replace BA_lehre = 0 if BA_lehre == . & educ_adiab != 2 & educ_adiab  != 4 & educ_adiab  != .
replace BA_akademisch = 1 if BA_akademisch == . & (educ_adiab == 5 | educ_adiab == 6)
replace BA_akademisch = 0 if BA_akademisch == . & educ_adiab != 5 & educ_adiab  != 6 & educ_adiab  != .
replace BA_meister = 0 if BA_meister == . & educ_adiab != 2 & educ_adiab  != 4 & educ_adiab  != .

********************************************************************************

* Generieren von Partnervariablen
replace persnr_partner = 0 if partner == 0
replace partner = 1 if persnr_partner > 0 & persnr_partner != .
replace partner = 0 if persnr_partner == 0

preserve

keep persnr welle age BA_keine BA_lehre BA_meister BA_akademisch mig_dummy espell uspell nspell brutto_stunde_real

foreach var in  age BA_keine BA_lehre BA_meister BA_akademisch mig_dummy espell uspell nspell brutto_stunde_real {
gen partner_`var' = `var'
}

rename persnr persnr_partner

sort persnr_partner welle

save "$data/partner_vars.dta", replace

restore

sort persnr_partner welle 
merge m:m persnr_partner welle using "$data/partner_vars.dta"

drop if _merge == 2
drop _merge

********************************************************************************

* Partner-Variablen auffüllen

sort persnr welle

* Berufsausbildung
foreach var in  partner_BA_keine partner_BA_lehre partner_BA_meister partner_BA_akademisch  {
bysort persnr (welle): replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=. & persnr_partner == persnr_partner[_n-1] & persnr_partner !=.
}


gsort persnr -welle

* Berufsausbildung
foreach var in  partner_BA_keine partner_BA_lehre partner_BA_meister partner_BA_akademisch  {
by persnr: replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=. & persnr_partner == persnr_partner[_n-1] & persnr_partner !=.
}

foreach var in  partner_espell partner_uspell {
bysort persnr (welle): replace `var' = `var'[_n-1] if `var'[_n+1] == `var'[_n-1] & `var'[_n-1] !=. & `var' ==. & persnr_partner == persnr_partner[_n+1] & persnr_partner[_n+1] == persnr_partner[_n-1] & persnr_partner !=.
}

********************************************************************************
**** Auffuellen mit plausiblen Werten                      **********************
********************************************************************************
sort persnr welle

* Soziodemo
foreach var in  BA_keine BA_lehre BA_meister BA_akademisch {
bysort persnr (welle): replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=.
}


gsort persnr -welle

* Soziodemo
foreach var in  BA_keine BA_lehre BA_meister BA_akademisch {
by persnr: replace `var' = `var'[_n-1] if `var' == . & `var'[_n-1] !=.
}

sort persnr welle

* Anpassung Famstand
replace famstand_verheiratet = 1 if famstand_verheiratet == . & (fam_stand_adiab == 1  | fam_stand_adiab == 13)
replace famstand_verheiratet = 0 if famstand_verheiratet == . & fam_stand_adiab != 1 & fam_stand_adiab != 13 & fam_stand_adiab!=16 & fam_stand_adiab !=.


* Famstand auffuellen falls missing
replace famstand_verheiratet = 0 if partner == 0 & famstand_verheiratet == .
bysort persnr (welle): replace famstand_verheiratet = famstand_verheiratet[_n-1] if famstand_verheiratet[_n-1] != . & famstand_verheiratet == .

* Anpassung anz_kind
replace anzahl_kindHH = kind_anz_adiab if anzahl_kindHH == . & kind_anz_adiab !=.

bysort persnr (welle): replace anzahl_kindHH = anzahl_kindHH[_n+1] if anzahl_kindHH[_n+1] == 0 & anzahl_kindHH == .
bysort persnr (welle): replace anzahl_kindHH = anzahl_kindHH[_n-1] if anzahl_kindHH[_n-1] != . & anzahl_kindHH == . 

********************************************************************************

********************************************************************************
**** Daten speichern                                          **********************
********************************************************************************

save "$data/data_merged.dta", replace

* Loeschen von Datensaetzen

*capture erase "$data/soziodemo.dta"
*capture erase "$data/arbeitsmarkt.dta"
*capture erase "$data/arbeitssuche.dta"
*capture erase "$data/data_bio_spell.dta"
*capture erase "$data/haushalt.dta"
*capture erase "$data/partner_id.dta"

********************************************************************************
log close








