cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************


log using "$log/lpo12_2_Descriptives.log", replace

* Content: Descriptives

clear all

capture set more off 

use "$data/final_data.dta", clear

********************************************************************************
* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* Indicate persons that belong eihter to control or to treatment group
bysort persnr (welle): egen treat_max = max(treat)
bysort persnr (welle): gen control_treat = 1 if treat==0 & treat_max==1
bysort persnr (welle): egen control_treat_max = max(control_treat)

* Wie oft ist Person in Treatment- oder Kontrollgruppe?
bysort persnr (welle): gen counter = _n
bysort persnr (welle): egen counter_max = max(counter)


preserve
keep if counter == counter_max
tab counter
tab counter if treat_max == 1 & control_treat_max != 1
tab counter if treat_max == 0
tab counter if control_treat_max == 1
restore

********************************************************************************
* Wieviele Personen aus meinem Schätzsample kommen aus demselben Haushalt?

sort persnr welle
gen d_hh = 1 if persnr != persnr[_n-1] & hnr == hnr[_n-1]
bysort hnr: egen d_hh_max = max(d_hh)

tab d_hh_max

drop  d_hh_max
count

********************************************************************************
* Wieviele bleiben beim selben Arbeitgeber?
tab treat_empl_same_firm if treat==0
tab treat_employed if treat==0


********************************************************************************
**** Differerence table	                                  **********************
********************************************************************************

loc row = 1

* variables

global variables "$d_outcomes $outcomes $control_all_des"


foreach var in $variables{

loc row = `row' + 1

}


mat T = J(`row' - 1,8,.)


loc row = 1

foreach var in $variables{



ttest `var', by(treat)
mat T[`row',1] = r(N_2)
mat T[`row',2] = r(N_1)
mat T[`row',3] = r(mu_2)
mat T[`row',4] = r(mu_1)
mat T[`row',5] = r(mu_2) - r(mu_1)
mat T[`row',6] = r(p)

sum `var'
mat T[`row',7] = r(min)
mat T[`row',8] = r(max)

loc row = `row' + 1

}


local x

foreach var in $variables {
local x `x' `var'
}




matrix colnames T = N_1 N_0 Mean_1 Mean_0 Difference P-Value Min Max

matrix rownames T = `x'


matrix list T

putexcel set "$results/Descriptives_MW", modify
putexcel A1=matrix(T) , names



log close








