cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo13_2_Distribution_outcomes.log", replace

* Content: Distribution of outcome variables

clear all


use "$data/final_data.dta", clear


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle


* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .


* Histogramme von der Verteilung der Outcome Variablen

********************************************************************************
* Social integration

summarize d_soz_teil_ges, d
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_soz_teil_ges if d_soz_teil_ges>=-5 & d_soz_teil_ges<=5 /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-5(1)5)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -5 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))

graph export "$log/lpo13_2_Verteilung_d_soz_teil_ges.eps", replace


********************************************************************************
* Subjective well-being

summarize d_zufr_leben
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_zufr_leben if d_zufr_leben>=-5 & d_zufr_leben<=5 /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-5(1)5)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -5 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))


graph export "$log/lpo13_2_Verteilung_d_zufr_leben.eps", replace


********************************************************************************
* Mental health status

summarize d_seele
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_seele if d_seele>=-3 & d_seele <= 3  /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-3(1)3)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -3 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))

graph export "$log/lpo13_2_Verteilung_d_seele.eps", replace

********************************************************************************
* Economic resources

summarize d_depindg2
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_depindg2 if d_depindg2>=-1.75 & d_depindg2 <= 1.75 /*
*/, frac xtitle("Difference in outcome levels") bin(15) /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-1.75(0.25)1.75)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -1.75 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))

graph export "$log/lpo13_2_Verteilung_d_depindg2.eps", replace

summarize d_zufr_lebensstandard
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_zufr_lebensstandard if d_zufr_lebensstandard>=-5 & d_zufr_lebensstandard<=5 /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-5(1)5)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -5 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))


graph export "$log/lpo13_2_Verteilung_d_zufr_lebensstandard.eps", replace


********************************************************************************
* social participation

summarize d_anzahl_engefreunde
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_anzahl_engefreunde if d_anzahl_engefreunde>=-4 & d_anzahl_engefreunde <=4  /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-4(1)4)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -4 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))


graph export "$log/lpo13_2_Verteilung_d_anzahl_engefreunde.eps", replace


summarize d_engagement
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

hist d_engagement if d_engagement>=-4 & d_engagement <=4 /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-4(1)4)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -4.5 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))


graph export "$log/lpo13_2_Verteilung_d_engagement.eps", replace


********************************************************************************
* social position

summarize d_soz_pos
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

histogram d_soz_pos if d_soz_pos>=-5 & d_soz_pos <= 5 /*
*/, frac discrete xtitle("Difference in outcome levels") /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-5(1)5)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -5 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))


graph export "$log/lpo13_2_Verteilung_d_soz_pos.eps", replace

********************************************************************************
*self-efficacy


summarize d_selbstwirksamkeit
local m=r(mean)
local sd=r(sd)
local low = `m'-`sd'
local high=`m'+`sd'

 histogram d_selbstwirksamkeit if  d_selbstwirksamkeit>=-1.25 &  d_selbstwirksamkeit <= 1.25  /*
*/, frac xtitle("Difference in outcome levels") bin(15) /*
*/ bfcolor(gs3) blcolor(gs16) xlabel(-1.25(0.25)1.25)  ylabel(0 (.05) .75) plotregion(fcolor(white)) graphregion(fcolor(white)) /*
*/ text(.7 -1.25 "Mean = `=string(`m',"%6.2f")'" "Standard deviation = `=string(`sd',"%6.2f")'", /*
*/ color(gs3) orientation(horizontal) placement(o) size(medium))


graph export "$log/lpo13_2_Verteilung_d_selbstwirksamkeit.eps", replace



****************************************************************************************************
log close










