cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo16_3_IPW_diff_in_diff_placebo.log", replace

* Content: Estimation Inverse propensity score weighting with difference-in-differences for pre-period

clear all

capture set more off 

use "$data/final_data.dta", clear


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(dlag_`var')

}


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)


global variables "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos"

loc row = 1


foreach var in $variables{
preserve

* Replicating ipw for treat
qui logit treat $control_all if dlag_soz_teil_ges != . &  dlag_zufr_leben != . &  dlag_zufr_lebensstandard != . & dlag_depindg2 !=. &  dlag_anzahl_engefreunde != .  & dlag_engagement != . &  dlag_seele != . &  dlag_soz_pos != ., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if dlag_soz_teil_ges != . &  dlag_zufr_leben != . &  dlag_zufr_lebensstandard != . & dlag_depindg2 !=. &  dlag_anzahl_engefreunde != .  & dlag_engagement != . &  dlag_seele != . &  dlag_soz_pos != .

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & dlag_soz_teil_ges != . &  dlag_zufr_leben != . &  dlag_zufr_lebensstandard != . & dlag_depindg2 !=. &  dlag_anzahl_engefreunde != .  & dlag_engagement != . &  dlag_seele != . &  dlag_soz_pos != .
scalar n0 = r(N)

qui tab treat if treat==1 & dlag_soz_teil_ges != . &  dlag_zufr_leben != . &  dlag_zufr_lebensstandard != . & dlag_depindg2 !=. &  dlag_anzahl_engefreunde != .  & dlag_engagement != . &  dlag_seele != . &  dlag_soz_pos != .
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum dlag_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}


preserve
* Replicating ipw for treat
qui logit treat $control_all if dlag_selbstwirksamkeit != ., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_selbstwirksamkeit i.treat [pw=ipw_weight_normalized] if ds_selbstwirksamkeit!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_selbstwirksamkeit !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_selbstwirksamkeit !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum dlag_selbstwirksamkeit if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

drop ipw_weight_normalized w
restore



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_Placebo", modify
putexcel A1=matrix(T) , names


****************************************************************************************************
* Placebo Tests for imbalanced sample

********************************************************************************
* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1

global variables "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos"


foreach var in $variables{

* Inverse propensity score weighting with logit
reg ds_`var' treat if dlag_soz_teil_ges != . &  dlag_zufr_leben != . &  dlag_zufr_lebensstandard != . & dlag_depindg2 !=. &  dlag_anzahl_engefreunde != .  & dlag_engagement != . &  dlag_seele != . &  dlag_soz_pos != ., vce(cluster persnr)


* Store Estimates

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,1]
scalar seatt = sqrt(V[1,1])

* number of observations
sum ds_`var' if e(sample)==1 & treat==0
scalar n0 = r(N)
sum ds_`var' if e(sample)==1 & treat==1
scalar n1 = r(N)


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1

}


* Inverse propensity score weighting with logit
reg ds_selbstwirksamkeit treat if dlag_selbstwirksamkeit != ., vce(cluster persnr)

* Store Estimates

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,1]
scalar seatt = sqrt(V[1,1])

* number of observations
sum ds_selbstwirksamkeit if e(sample)==1 & treat==0
scalar n0 = r(N)
sum ds_selbstwirksamkeit if e(sample)==1 & treat==1
scalar n1 = r(N)


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_selbstwirksamkeit if e(sample)==1

mat T[`row',6] = r(sd)





local x

foreach var in $outcomes {
local x `x' ds_`var'
}




matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_Placebo_noIWP", modify
putexcel A1=matrix(T) , names

*****************************************************************************************************
log close










