cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo18_plot_placebo.log", replace

* Content: Plots for Placebo-tests

clear all

set more off


use "$data/final_data.dta", clear


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle


* drop if treat ist missing
drop if treat == .


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .


********************************************************************************
* Plot of placebo-tests (ungewichtet)

loc row = 1

* variables

global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}


mat M_t1 = J(5,`row' - 1,.)
mat SD_t1 = J(5,`row' - 1,.)
mat M_t0 = J(5,`row' - 1,.)
mat SD_t0 = J(5,`row' - 1,.)
mat M_t0_w = J(5,`row' - 1,.)


*Replicating ipw for treat_1
qui logit treat $control_all, iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.

*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalize weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}




loc row = 1

global variables "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos"

foreach var in $variables{

* Outcome-Levels for treatment group with ipw
sum `var'_lag3 if e(sample)==1 & treat==1 & soz_teil_ges_lag3 != . &  zufr_leben_lag3 != . &  zufr_lebensstandard_lag3 != . & depindg2_lag3 !=. &  anzahl_engefreunde_lag3 != .  & engagement_lag3 != . &  seele_lag3 != . &  soz_pos_lag3 != .
mat M_t1[1,`row'] = r(mean)
mat SD_t1[1,`row'] = r(sd)
sum `var'_lag2 if e(sample)==1 & treat==1 & soz_teil_ges_lag2 != . &  zufr_leben_lag2 != . &  zufr_lebensstandard_lag2 != . & depindg2_lag2 !=. &  anzahl_engefreunde_lag2 != .  & engagement_lag2 != . &  seele_lag2 != . &  soz_pos_lag2 != .
mat M_t1[2,`row'] = r(mean)
mat SD_t1[2,`row'] = r(sd)
sum `var'_lag1 if e(sample)==1 & treat==1 & soz_teil_ges_lag1 != . &  zufr_leben_lag1 != . &  zufr_lebensstandard_lag1 != . & depindg2_lag1 !=. &  anzahl_engefreunde_lag1 != .  & engagement_lag1 != . &  seele_lag1 != . &  soz_pos_lag1 != .
mat M_t1[3,`row']= r(mean)
mat SD_t1[3,`row'] = r(sd)
sum `var' if e(sample)==1 & treat==1 
mat M_t1[4,`row'] = r(mean)
mat SD_t1[4,`row'] = r(sd)
sum `var'_lead1 if e(sample)==1 & treat==1
mat M_t1[5,`row'] = r(mean)
mat SD_t1[5,`row'] = r(sd)

* Outcome-Levels for control group without ipw
sum `var'_lag3 if e(sample)==1 & treat==0 & soz_teil_ges_lag3 != . &  zufr_leben_lag3 != . &  zufr_lebensstandard_lag3 != . & depindg2_lag3 !=. &  anzahl_engefreunde_lag3 != .  & engagement_lag3 != . &  seele_lag3 != . &  soz_pos_lag3 != .
mat M_t0[1,`row'] = r(mean)
mat SD_t0[1,`row'] = r(sd)
sum `var'_lag2 if e(sample)==1 & treat==0 & soz_teil_ges_lag2 != . &  zufr_leben_lag2 != . &  zufr_lebensstandard_lag2 != . & depindg2_lag2 !=. &  anzahl_engefreunde_lag2 != .  & engagement_lag2 != . &  seele_lag2 != . &  soz_pos_lag2 != .
mat M_t0[2,`row'] = r(mean)
mat SD_t0[2,`row'] = r(sd)
sum `var'_lag1 if e(sample)==1 & treat==0 & soz_teil_ges_lag1 != . &  zufr_leben_lag1 != . &  zufr_lebensstandard_lag1 != . & depindg2_lag1 !=. &  anzahl_engefreunde_lag1 != .  & engagement_lag1 != . &  seele_lag1 != . &  soz_pos_lag1 != .
mat M_t0[3,`row'] = r(mean)
mat SD_t0[3,`row'] = r(sd)
sum `var' if e(sample)==1 & treat==0
mat M_t0[4,`row'] = r(mean)
mat SD_t0[4,`row'] = r(sd)
sum `var'_lead1 if e(sample)==1 & treat==0
mat M_t0[5,`row'] = r(mean)
mat SD_t0[5,`row'] = r(sd)

* Outcome-Levels for control group with ipw
sum `var'_lag3 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & soz_teil_ges_lag3 != . &  zufr_leben_lag3 != . &  zufr_lebensstandard_lag3 != . & depindg2_lag3 !=. &  anzahl_engefreunde_lag3 != .  & engagement_lag3 != . &  seele_lag3 != . &  soz_pos_lag3 != .
mat M_t0_w[1,`row'] =  r(mean)
sum `var'_lag2 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & soz_teil_ges_lag2 != . &  zufr_leben_lag2 != . &  zufr_lebensstandard_lag2 != . & depindg2_lag2 !=. &  anzahl_engefreunde_lag2 != .  & engagement_lag2 != . &  seele_lag2 != . &  soz_pos_lag2 != .
mat M_t0_w[2,`row'] =  r(mean)
sum `var'_lag1 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & soz_teil_ges_lag1 != . &  zufr_leben_lag1 != . &  zufr_lebensstandard_lag1 != . & depindg2_lag1 !=. &  anzahl_engefreunde_lag1 != .  & engagement_lag1 != . &  seele_lag1 != . &  soz_pos_lag1 != .
mat M_t0_w[3,`row'] =  r(mean)
sum `var' [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0
mat M_t0_w[4,`row'] =  r(mean)
sum `var'_lead1 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0
mat M_t0_w[5,`row'] =  r(mean)

estimates clear

regress `var'_lag3 i.treat [pw=ipw_weight_normalized] 
regress `var'_lag3 i.treat 
regress `var'_lag2 i.treat [pw=ipw_weight_normalized] 
regress `var'_lag2 i.treat 
regress `var'_lag1 i.treat [pw=ipw_weight_normalized] 
regress `var'_lag1 i.treat 
regress `var' i.treat [pw=ipw_weight_normalized] 
regress `var' i.treat 
regress `var'_lead1 i.treat [pw=ipw_weight_normalized] 
regress `var'_lead1 i.treat 

loc row = `row' + 1

}




* Outcome-Levels for treatment group with ipw
sum selbstwirksamkeit_lag3 if e(sample)==1 & treat==1 & d_selbstwirksamkeit != .
mat M_t1[1,`row'] = r(mean)
mat SD_t1[1,`row'] = r(sd)
sum selbstwirksamkeit_lag2 if e(sample)==1 & treat==1 & d_selbstwirksamkeit != .
mat M_t1[2,`row'] = r(mean)
mat SD_t1[2,`row'] = r(sd)
sum selbstwirksamkeit_lag1 if e(sample)==1 & treat==1 & d_selbstwirksamkeit != .
mat M_t1[3,`row'] = r(mean)
mat SD_t1[3,`row'] = r(sd)
sum selbstwirksamkeit if e(sample)==1 & treat==1 & d_selbstwirksamkeit != .
mat M_t1[4,`row'] = r(mean)
mat SD_t1[4,`row'] = r(sd)
sum selbstwirksamkeit_lead1 if e(sample)==1 & treat==1 & d_selbstwirksamkeit != .
mat M_t1[5,`row'] = r(mean)
mat SD_t1[5,`row'] = r(sd)

* Outcome-Levels for control group without ipw
sum selbstwirksamkeit_lag3 if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0[1,`row'] = r(mean)
mat SD_t0[1,`row'] = r(sd)
sum selbstwirksamkeit_lag2 if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0[2,`row'] = r(mean)
mat SD_t0[2,`row'] = r(sd)
sum selbstwirksamkeit_lag1 if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0[3,`row'] = r(mean)
mat SD_t0[3,`row'] = r(sd)
sum selbstwirksamkeit if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0[4,`row'] = r(mean)
mat SD_t0[4,`row'] = r(sd)
sum selbstwirksamkeit_lead1 if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0[5,`row'] = r(mean)
mat SD_t0[5,`row'] = r(sd)

* Outcome-Levels for control group with ipw
sum selbstwirksamkeit_lag3 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0_w[1,`row'] =  r(mean)
sum selbstwirksamkeit_lag2 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0_w[2,`row'] =  r(mean)
sum selbstwirksamkeit_lag1 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0_w[3,`row'] =  r(mean)
sum selbstwirksamkeit [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0_w[4,`row'] =  r(mean)
sum selbstwirksamkeit_lead1 [weight=ipw_weight_normalized]  if e(sample)==1 & treat==0 & d_selbstwirksamkeit != .
mat M_t0_w[5,`row'] =  r(mean)


regress selbstwirksamkeit_lag3 i.treat [pw=ipw_weight_normalized] 
regress selbstwirksamkeit_lag3 i.treat 
regress selbstwirksamkeit_lag2 i.treat [pw=ipw_weight_normalized] 
regress selbstwirksamkeit_lag2 i.treat 
regress selbstwirksamkeit_lag1 i.treat [pw=ipw_weight_normalized] 
regress selbstwirksamkeit_lag1 i.treat 
regress selbstwirksamkeit i.treat [pw=ipw_weight_normalized] 
regress selbstwirksamkeit i.treat 
regress selbstwirksamkeit_lead1 i.treat [pw=ipw_weight_normalized] 
regress selbstwirksamkeit_lead1 i.treat 


estimates clear

local x

foreach var in $outcomes {
local x `x' `var'_t1
}

matrix colnames M_t1 = `x'

matrix list M_t1

putexcel set "$results/Results_Placebo_plot_mean", modify
putexcel A1=matrix(M_t1) , names

local x

foreach var in $outcomes {
local x `x' `var'_t0
}

matrix colnames M_t0 = `x'

matrix list M_t0

putexcel set "$results/Results_Placebo_plot_mean", modify
putexcel K1=matrix(M_t0) , names

local x

foreach var in $outcomes {
local x `x' `var'_t0_w
}

matrix colnames M_t0_w = `x'

matrix list M_t0_w

putexcel set "$results/Results_Placebo_plot_mean", modify
putexcel U1=matrix(M_t0_w) , names

********************************************************************************
*Plot
clear all

import excel "$results/Results_Placebo_plot_mean.xlsx", firstrow

gen tper = _n

********************************************************************************
* Social integration

graph twoway (scatter soz_teil_ges_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter soz_teil_ges_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter soz_teil_ges_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(5(1)9) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_soz_teil_ges.eps", replace

********************************************************************************
* Subjective well-being

graph twoway (scatter zufr_leben_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter zufr_leben_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter zufr_leben_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(5(1)9) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_zufr_leben.eps", replace

********************************************************************************
* Mental health status

graph twoway (scatter seele_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter seele_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter seele_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(2(1)5) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_seele.eps", replace

********************************************************************************
* Economic resources

graph twoway (scatter depindg2_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter depindg2_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter depindg2_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(0(0.25)1.5) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_depindg2.eps", replace

graph twoway (scatter zufr_lebensstandard_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter zufr_lebensstandard_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter zufr_lebensstandard_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(5(1)9) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_zufr_lebensstandard.eps", replace


********************************************************************************
* Social participation

graph twoway (scatter anzahl_engefreunde_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter anzahl_engefreunde_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter anzahl_engefreunde_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(1(0.5)3) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_anzahl_engefreunde.eps", replace

graph twoway (scatter engagement_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter engagement_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter engagement_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(0(0.5)1) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_engagement.eps", replace

********************************************************************************
* social position

graph twoway (scatter soz_pos_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter soz_pos_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter soz_pos_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(4(1)7) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_soz_pos.eps", replace

********************************************************************************
* self-efficacy

graph twoway (scatter selbstwirksamkeit_t1 tper, msymbol(s) mcolor(black) connect(l) lcolor(black)) ///
(scatter selbstwirksamkeit_t0 tper, msymbol(+) mcolor(black) connect(l) lcolor(black) lpattern(dash)) ///
(scatter selbstwirksamkeit_t0_w tper, msymbol(o) mcolor(black) connect(l) lcolor(black) lpattern(dash_dot)), ///
legend(label(1 Treated) label(2 Controls before IPW) label(3 Controls after IPW) size(3) pos(5) ring(0) col(1)) xlin(4, lcolor(black)) plotregion(fcolor(white)) graphregion(fcolor(white)) ///
xlabel(1 "t-3" 2 "t-2" 3 "t-1" 4 "t0" 5 "t1") ylabel(2.5(0.25)3.5) xtitle("Wave") ytitle("Mean") 

graph export "$log\lpo25_3_plot_placebo_selbstwirksamkeit.eps", replace

****************************************************************************************************
log close










