cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo22_3_IPW_diff_in_diff_model_bs.log", replace

* Content: Bootstrapped standard errors (Inverse propensity score weighting with difference-in-differences, different model specifications)

********************************************************************************
* 1. Probit statt Logit

clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var' = 0 

}


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs {
mat T = J(`i',`row' - 1,.)
}




forvalues i = 1/$bs_runs {

preserve
* draw bootstrap sample
bsample, cluster(persnr)
********************************************************************************

loc row = 1

foreach var in $outcomes{
drop ds_`var'
egen ds_`var' = std(d_`var')


* Replicating ipw for treat
qui probit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
gen off_support = 1 if ps > `untreated_max' & ps!=.
disp "Observations off support"
tab off_support

*weights 
gen ipw_weight = 1 if treat==1 & off_support != 1
replace ipw_weight = ps/(1-ps) if treat==0 & off_support != 1


*Normalize weights
qui sum ipw_weight if treat==0 & off_support != 1
scalar ipw_weight_sum_control = r(mean) * r(N) 
qui sum ipw_weight if treat==1 & off_support != 1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1 & off_support != 1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0 & off_support != 1

drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
gen off_support = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
}

else{
scalar att = .
}


mat T[`i',`row'] = att

display "ATT:" att

estimates clear

loc row = `row' + 1

drop ipw_weight_normalized off_support
}

display "Run Done:" `i'

restore
}

local x

foreach var in $outcomes {
local x `x' ds_`var'
}

matrix colnames T = `x'

matrix list T

putexcel set "$results/BS_SE_Probit", modify
putexcel A1=matrix(T) , names

********************************************************************************
* 2. Inverse propensity score weighting with regression adjustment

clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var' = 0 

}


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs {
mat T = J(`i',`row' - 1,.)
}




forvalues i = 1/$bs_runs {

preserve
* draw bootstrap sample
bsample, cluster(persnr)
********************************************************************************

loc row = 1

foreach var in $outcomes{
drop ds_`var'
egen ds_`var' = std(d_`var')


* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
gen off_support = 1 if ps > `untreated_max' & ps!=.
disp "Observations off support"
tab off_support

*weights 
gen ipw_weight = 1 if treat==1 & off_support != 1
replace ipw_weight = ps/(1-ps) if treat==0 & off_support != 1


*Normalize weights
qui sum ipw_weight if treat==0 & off_support != 1
scalar ipw_weight_sum_control = r(mean) * r(N) 
qui sum ipw_weight if treat==1 & off_support != 1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1 & off_support != 1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0 & off_support != 1

drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
gen off_support = .
}


capture regress ds_`var' i.treat $control_all [pw=ipw_weight_normalized] if ds_`var'!=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
}

else{
scalar att = .
}


mat T[`i',`row'] = att

display "ATT:" att

estimates clear

loc row = `row' + 1

drop ipw_weight_normalized off_support
}

display "Run Done:" `i'

restore
}

local x

foreach var in $outcomes {
local x `x' ds_`var'
}

matrix colnames T = `x'

matrix list T

putexcel set "$results/BS_SE_IPW_RA", modify
putexcel A1=matrix(T) , names

*************************************************************************************************
log close










