cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo23_3_RadiusMatch_diff_in_diff.log", replace

* Content: Estimation Radius Matching with difference-in-differences

********************************************************************************
* 1. Radius-Matching
* Spezifikation: logit um propensity score zu schätzen
* Radius: 

clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1

foreach var in $variables{

* Inverse propensity score weighting with logit
radiusmatch treat $control_all, outcome(ds_`var') logit  

* Store Estimates

* coefficient and standard error
matrix coef = r(atet)  
matrix V = r(seatet) 
scalar att = coef[1,1]
scalar seatt = V[1,1]

* Number of observations
qui tab treat if treat==0 & ds_`var' !=. &  _support == 1
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=. &  _support == 1
scalar n1 = r(N)


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt



* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1

}



local x

foreach var in $variables {
local x `x' ds_`var'
}




matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_Radiusmatching", modify
putexcel A1=matrix(T) , names

********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1

foreach var in $variables{

* Inverse propensity score weighting with logit
radiusmatch treat $control_all, outcome(ds_`var') logit mahal(female n_uspell)

* Store Estimates

* coefficient and standard error
matrix coef = r(atet)  
matrix V = r(seatet) 
scalar att = coef[1,1]
scalar seatt = V[1,1]

* Number of observations
qui tab treat if treat==0 & ds_`var' !=. &  _support == 1
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=. &  _support == 1
scalar n1 = r(N)


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt



* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1

}



local x

foreach var in $variables {
local x `x' ds_`var'
}




matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_Radiusmatching_2", modify
putexcel A1=matrix(T) , names




*****************************************************************************************************
log close










