cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo24_3_RadiusMatch_diff_in_diff_bs.log", replace

* Content: Bootstrapped standard errors (Radius Matching with difference-in-differences)

clear all

capture set more off 

use "$data/final_data.dta", clear


* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var' = 0 

}


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs_radius {
mat T = J(`i',`row' - 1,.)
}




forvalues i = 1/$bs_runs_radius {

preserve
* draw bootstrap sample
bsample, cluster(persnr)

gen uni = uniform()
sort uni
********************************************************************************

loc row = 1

foreach var in $outcomes{
drop ds_`var'
egen ds_`var' = std(d_`var')



* Inverse propensity score weighting with logit
qui radiusmatch treat $control_all, outcome(ds_`var') logit mahal(female n_uspell)

* Store Estimates

* coefficient and standard error
matrix coef = r(atet)  
scalar att = coef[1,1]

mat T[`i',`row'] = att

display "ATT:" att

estimates clear

loc row = `row' + 1

drop _pscore _treated _untreated _support _weightt _id
}

local x

foreach var in $outcomes {
local x `x' ds_`var'
}

matrix colnames T = `x'

*matrix list T

putexcel set "$results/BS_SE_Radiusmatching", modify
putexcel A1=matrix(T) , names




display "Run Done:" `i'

restore
}


local x

foreach var in $outcomes {
local x `x' ds_`var'
}

matrix colnames T = `x'

matrix list T

*putexcel set "$results/BS_SE_Radiusmatching", modify
*putexcel A1=matrix(T) , names



*************************************************************************************************
log close










