cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo25_3_IPW_diff_in_diff_het_treat_socio.log", replace

* Content: Estimation Inverse propensity score weighting for subgroups

clear all

capture set more off 

use "$data/final_data.dta", clear



********************************************************************************
*1. Effekte fuer Maenner
keep if female == 0


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"



foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen Maenner
global control_all_men "$control_all"


* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_all_men), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve
* Anpassung der Kontrollvariablen

foreach var_x in $control_all{
qui count if treat==1 & `var_x' >= 1 & ds_`var'!=.
local m=r(N)
qui sum `var_x' if treat==1 & ds_`var'!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_men
				global control_all_men: list all -not
        }
        
}


* Replicating ipw for treat
qui logit treat $control_all_men if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T


putexcel set "$results/Results_sex_men", modify
putexcel A1=matrix(T) , names


********************************************************************************
********************************************************************************
*2. Effekte fuer Frauen
clear all

use "$data/final_data.dta", clear

keep if female == 1


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"



foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen Frauen
global control_all_women "$control_all"


* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_all_women), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve
* Anpassung der Kontrollvariablen

foreach var_x in $control_all{
qui count if treat==1 & `var_x' >= 1 & ds_`var'!=.
local m=r(N)
qui sum `var_x' if treat==1 & ds_`var'!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_women
				global control_all_women: list all -not
        }
        
}

* Replicating ipw for treat
qui logit treat $control_all_women if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T


putexcel set "$results/Results_sex_women", modify
putexcel A1=matrix(T) , names


********************************************************************************
*3. Effekte fuer low/medium skilled (Lehre oder keine Berufsausbildung)
clear all
use "$data/final_data.dta", clear

keep if BA_akademisch==0 & BA_meister == 0


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"



foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen high skilled
global control_all_educ_low "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_all_educ_low), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve
* Anpassung der Kontrollvariablen

foreach var_x in $control_all{
qui count if treat==1 & `var_x' >= 1 & ds_`var'!=.
local m=r(N)
qui sum `var_x' if treat==1 & ds_`var'!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_educ_low
				global control_all_educ_low: list all -not
        }
        
}

* Replicating ipw for treat
qui logit treat $control_all_educ_low if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T


putexcel set "$results/Results_educ_low_medium", modify
putexcel A1=matrix(T) , names


********************************************************************************
********************************************************************************
*4. Effekte fuer high skilled (Uni, FH oder Meister)
clear all
use "$data/final_data.dta", clear

keep if BA_akademisch==1 | BA_meister == 1


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"



foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen high skilled
global control_all_educ_high "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_all_educ_high), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve
* Anpassung der Kontrollvariablen

foreach var_x in $control_all{
qui count if treat==1 & `var_x' >= 1 & ds_`var'!=.
local m=r(N)
qui sum `var_x' if treat==1 & ds_`var'!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_educ_high
				global control_all_educ_high: list all -not
        }
        
}

* Replicating ipw for treat
qui logit treat $control_all_educ_high if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T


putexcel set "$results/Results_educ_high", modify
putexcel A1=matrix(T) , names

********************************************************************************
*5. Effekte fuer Personen mit Partner
clear all
use "$data/final_data.dta", clear

keep if partner == 1

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen partner
global control_part "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_part), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test



* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve
* Anpassung der Kontrollvariablen

foreach var_x in $control_all{
qui count if treat==1 & `var_x' >= 1 & ds_`var'!=.
local m=r(N)
qui sum `var_x' if treat==1 & ds_`var'!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_part
				global control_part: list all -not
        }
        
}

* Replicating ipw for treat
qui logit treat $control_part if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T


putexcel set "$results/Results_partner", modify
putexcel A1=matrix(T) , names

********************************************************************************
*6. Effekte fuer Personen mit Partner
clear all
use "$data/final_data.dta", clear

keep if partner == 0

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen partner
global control_nopart "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_nopart), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve
* Anpassung der Kontrollvariablen

foreach var_x in $control_all{
qui count if treat==1 & `var_x' >= 1 & ds_`var'!=.
local m=r(N)
qui sum `var_x' if treat==1 & ds_`var'!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_nopart
				global control_nopart: list all -not
        }
        
}

* Replicating ipw for treat
qui logit treat $control_nopart if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_partner_no", modify
putexcel A1=matrix(T) , names


*******************************************************************************

log close










