cap log close

*******************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo26_3_bs_diff_het_treat_socio.log", replace

* Content: Bootstrapped standard errors (Estimation Inverse propensity score weighting fo subgroups)

********************************************************************************
********************************************************************************
*1. Effekte fuer Frauen vs Männer
********************************************************************************
clear all

capture set more off 

use "$data/final_data.dta", clear

* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
*sort persnr welle

* drop if treat ist missing
drop if treat == .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var'_1 = 0 
gen ds_`var'_2 = 0 
}


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs {
mat T1 = J(`i',`row' - 1,.)
mat T2 = J(`i',`row' - 1,.)
mat Tdiff = J(`i',`row' - 1,.)
}


gen treat_1 = 0
gen treat_2 = 0


forvalues i = 1/$bs_runs {

preserve
* draw bootstrap sample
bsample, cluster(persnr)
********************************************************************************

loc row = 1

* Define two treatment groups
drop treat_1 treat_2
gen treat_1 = 1 if female == 0 & treat==1
replace treat_1 = 0 if female == 0 & treat==0
gen treat_2 = 1 if female == 1 & treat==1
replace treat_2 = 0 if female == 1 & treat==0


* Define standardized outcomes for both groups
foreach var in $outcomes{
drop ds_`var'_1 ds_`var'_2
egen ds_`var'_1 = std(d_`var') if treat_1 !=.
egen ds_`var'_2 = std(d_`var') if treat_2 !=.


* Anpassung der Kontrollvariablen

global control_all_1 "$control_all"

foreach var_x in $control_all{
qui count if treat_1==1 & `var_x' >= 1 & ds_`var'_1!=.
local m=r(N)
qui sum `var_x' if treat_1==1 & ds_`var'_1!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_1
				global control_all_1: list all -not
        }
        
}


global control_all_2 "$control_all"

foreach var_x in $control_all{
qui count if treat_2==1 & `var_x' >= 1 & ds_`var'_2!=.
local m=r(N)
qui sum `var_x' if treat_2==1 & ds_`var'_2!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_2
				global control_all_2: list all -not
        }
        
}

* Replicating ipw for treat_1
qui logit treat_1 $control_all_1 if ds_`var'_1!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat_1==0, d
local untreated_max = r(max)
disp "Observations off support"
gen off_support_1 = 1 if ps > `untreated_max' & ps!=.
tab off_support_1

*weights 
gen ipw_weight = 1 if treat_1==1 & off_support_1 != 1
replace ipw_weight = ps/(1-ps) if treat_1==0 & off_support_1 != 1


*Normalize weights
qui sum ipw_weight if treat_1==0 & off_support_1 != 1
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat_1==1 & off_support_1 != 1
scalar n_treat=r(N)

gen ipw_weight_normalized_1 = 1 if treat_1==1 & off_support_1 != 1
replace ipw_weight_normalized_1=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat_1==0 & off_support_1 != 1

drop ps ipw_weight 
}

else{
gen ipw_weight_normalized_1 = .
gen off_support_1 = .
}

* Replicating ipw for treat_2
qui logit treat_2 $control_all_2 if ds_`var'_2!=., iterate(50) 

*if _rc==0{
if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat_2==0, d
local untreated_max = r(max)
gen off_support_2= 1 if ps > `untreated_max' & ps!=.
disp "Observations off support"
tab off_support_2

*weights 
gen ipw_weight = 1 if treat_2==1 & off_support_2 != 1
replace ipw_weight = ps/(1-ps) if treat_2==0 & off_support_2 != 1


*Normalize weights
qui sum ipw_weight if treat_2==0 & off_support_2 != 1
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat_2==1 & off_support_2 != 1
scalar n_treat=r(N)

gen ipw_weight_normalized_2 = 1 if treat_2==1 & off_support_2 != 1
replace ipw_weight_normalized_2=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat_2==0 & off_support_2 != 1

drop ps ipw_weight 
}

else{
gen ipw_weight_normalized_2 = .
gen off_support_2 = .
}


capture regress ds_`var'_1 i.treat_1 [pw=ipw_weight_normalized_1] if ds_`var'_1!=. & off_support_1 != 1

if _rc==0{
matrix coef = e(b)
scalar att1 = coef[1,2]
}

else{
scalar att1 = .
}

capture regress ds_`var'_2 i.treat_2 [pw=ipw_weight_normalized_2] if ds_`var'_2!=. & off_support_2!= 1

if _rc==0{
matrix coef = e(b)
scalar att2 = coef[1,2]
}

else{
scalar att2 = .
}

mat T1[`i',`row'] = att1 
mat T2[`i',`row'] = att2 
mat Tdiff[`i',`row'] = att1 - att2

display "Difference:" att1 - att2

estimates clear

loc row = `row' + 1

drop ipw_weight_normalized_1 ipw_weight_normalized_2 off_support_1 off_support_2

}
display "Run Done:" `i'

restore
}

local x

foreach var in $outcomes {
local x `x' ds_`var'_1
}


matrix colnames T1 = `x'

matrix list T1

putexcel set "$results/BS_SE_sex_men", modify
putexcel A1=matrix(T1) , names

matrix colnames T2 = `x'

matrix list T2

putexcel set "$results/BS_SE_sex_women", modify
putexcel A1=matrix(T2) , names


matrix colnames Tdiff = `x'

matrix list Tdiff

putexcel set "$results/BS_DIFF_sex", modify
putexcel A1=matrix(Tdiff) , names


********************************************************************************
********************************************************************************
*2. Effekte fuer low/medium skilled vs high shilled
********************************************************************************
clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
*sort persnr welle

* drop if treat ist missing
drop if treat == .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var'_1 = 0 
gen ds_`var'_2 = 0 
}


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs {
mat T1 = J(`i',`row' - 1,.)
mat T2 = J(`i',`row' - 1,.)
mat Tdiff = J(`i',`row' - 1,.)
}


gen treat_1 = 0
gen treat_2 = 0


forvalues i = 1/$bs_runs {

preserve
* draw bootstrap sample
bsample, cluster(persnr)
********************************************************************************

loc row = 1

* Define two treatment groups
drop treat_1 treat_2
gen treat_1 = 1 if BA_akademisch==0 & BA_meister == 0 & treat==1
replace treat_1 = 0 if  BA_akademisch==0 & BA_meister == 0 & treat==0
gen treat_2 = 1 if  (BA_akademisch==1 | BA_meister == 1) & treat==1
replace treat_2 = 0 if (BA_akademisch==1 | BA_meister == 1) & treat==0


* Define standardized outcomes for both groups
foreach var in $outcomes{
drop ds_`var'_1 ds_`var'_2
egen ds_`var'_1 = std(d_`var') if treat_1 !=.
egen ds_`var'_2 = std(d_`var') if treat_2 !=.


* Anpassung der Kontrollvariablen

global control_all_1 "$control_all"

foreach var_x in $control_all{
qui count if treat_1==1 & `var_x' >= 1 & ds_`var'_1!=.
local m=r(N)
qui sum `var_x' if treat_1==1 & ds_`var'_1!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_1
				global control_all_1: list all -not
        }
        
}


global control_all_2 "$control_all"

foreach var_x in $control_all{
qui count if treat_2==1 & `var_x' >= 1 & ds_`var'_2!=.
local m=r(N)
qui sum `var_x' if treat_2==1 & ds_`var'_2!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_2
				global control_all_2: list all -not
        }
        
}

* Replicating ipw for treat_1
qui logit treat_1 $control_all_1 if ds_`var'_1!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat_1==0, d
local untreated_max = r(max)
disp "Observations off support"
gen off_support_1 = 1 if ps > `untreated_max' & ps!=.
tab off_support_1

*weights 
gen ipw_weight = 1 if treat_1==1 & off_support_1 != 1
replace ipw_weight = ps/(1-ps) if treat_1==0 & off_support_1 != 1


*Normalize weights
qui sum ipw_weight if treat_1==0 & off_support_1 != 1
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat_1==1 & off_support_1 != 1
scalar n_treat=r(N)

gen ipw_weight_normalized_1 = 1 if treat_1==1 & off_support_1 != 1
replace ipw_weight_normalized_1=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat_1==0 & off_support_1 != 1

drop ps ipw_weight 
}

else{
gen ipw_weight_normalized_1 = .
gen off_support_1 = .
}

* Replicating ipw for treat_2
qui logit treat_2 $control_all_2 if ds_`var'_2!=., iterate(50) 

*if _rc==0{
if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat_2==0, d
local untreated_max = r(max)
gen off_support_2= 1 if ps > `untreated_max' & ps!=.
disp "Observations off support"
tab off_support_2

*weights 
gen ipw_weight = 1 if treat_2==1 & off_support_2 != 1
replace ipw_weight = ps/(1-ps) if treat_2==0 & off_support_2 != 1


*Normalize weights
qui sum ipw_weight if treat_2==0 & off_support_2 != 1
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat_2==1 & off_support_2 != 1
scalar n_treat=r(N)

gen ipw_weight_normalized_2 = 1 if treat_2==1 & off_support_2 != 1
replace ipw_weight_normalized_2=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat_2==0 & off_support_2 != 1

drop ps ipw_weight 
}

else{
gen ipw_weight_normalized_2 = .
gen off_support_2 = .
}


capture regress ds_`var'_1 i.treat_1 [pw=ipw_weight_normalized_1] if ds_`var'_1!=. & off_support_1 != 1

if _rc==0{
matrix coef = e(b)
scalar att1 = coef[1,2]
}

else{
scalar att1 = .
}

capture regress ds_`var'_2 i.treat_2 [pw=ipw_weight_normalized_2] if ds_`var'_2!=. & off_support_2!= 1

if _rc==0{
matrix coef = e(b)
scalar att2 = coef[1,2]
}

else{
scalar att2 = .
}

mat T1[`i',`row'] = att1 
mat T2[`i',`row'] = att2 
mat Tdiff[`i',`row'] = att1 - att2

display "Difference:" att1 - att2

estimates clear

loc row = `row' + 1

drop ipw_weight_normalized_1 ipw_weight_normalized_2 off_support_1 off_support_2

}
display "Run Done:" `i'

restore
}

local x

foreach var in $outcomes {
local x `x' ds_`var'_1
}


matrix colnames T1 = `x'

matrix list T1

putexcel set "$results/BS_SE_educ_low_medium", modify
putexcel A1=matrix(T1) , names

matrix colnames T2 = `x'

matrix list T2

putexcel set "$results/BS_SE_educ_high", modify
putexcel A1=matrix(T2) , names


matrix colnames Tdiff = `x'

matrix list Tdiff

putexcel set "$results/BS_DIFF_educ", modify
putexcel A1=matrix(Tdiff) , names

*******************************************************************************
********************************************************************************
*3. Effekte fuer partner vs. no partner
********************************************************************************
clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
*sort persnr welle

* drop if treat ist missing
drop if treat == .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var'_1 = 0 
gen ds_`var'_2 = 0 
}


* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs {
mat T1 = J(`i',`row' - 1,.)
mat T2 = J(`i',`row' - 1,.)
mat Tdiff = J(`i',`row' - 1,.)
}


gen treat_1 = 0
gen treat_2 = 0


forvalues i = 1/$bs_runs {

preserve
* draw bootstrap sample
bsample, cluster(persnr)
********************************************************************************

loc row = 1

* Define two treatment groups
drop treat_1 treat_2
gen treat_1 = 1 if partner==1 & treat==1
replace treat_1 = 0 if  partner==1 & treat==0
gen treat_2 = 1 if  partner==0 & treat==1
replace treat_2 = 0 if partner==0 & treat==0


* Define standardized outcomes for both groups
foreach var in $outcomes{
drop ds_`var'_1 ds_`var'_2
egen ds_`var'_1 = std(d_`var') if treat_1 !=.
egen ds_`var'_2 = std(d_`var') if treat_2 !=.


* Anpassung der Kontrollvariablen

global control_all_1 "$control_all"

foreach var_x in $control_all{
qui count if treat_1==1 & `var_x' >= 1 & ds_`var'_1!=.
local m=r(N)
qui sum `var_x' if treat_1==1 & ds_`var'_1!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_1
				global control_all_1: list all -not
        }
        
}


global control_all_2 "$control_all"

foreach var_x in $control_all{
qui count if treat_2==1 & `var_x' >= 1 & ds_`var'_2!=.
local m=r(N)
qui sum `var_x' if treat_2==1 & ds_`var'_2!=.
local l=r(mean)
local n=r(max)
 if `m' < 1 | (`l' >= 0.99 & `l' <= 1 & `n'==1) {
                unab not : `var_x'
				unab all : $control_all_2
				global control_all_2: list all -not
        }
        
}

* Replicating ipw for treat_1
qui logit treat_1 $control_all_1 if ds_`var'_1!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat_1==0, d
local untreated_max = r(max)
disp "Observations off support"
gen off_support_1 = 1 if ps > `untreated_max' & ps!=.
tab off_support_1

*weights 
gen ipw_weight = 1 if treat_1==1 & off_support_1 != 1
replace ipw_weight = ps/(1-ps) if treat_1==0 & off_support_1 != 1


*Normalize weights
qui sum ipw_weight if treat_1==0 & off_support_1 != 1
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat_1==1 & off_support_1 != 1
scalar n_treat=r(N)

gen ipw_weight_normalized_1 = 1 if treat_1==1 & off_support_1 != 1
replace ipw_weight_normalized_1=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat_1==0 & off_support_1 != 1

drop ps ipw_weight 
}

else{
gen ipw_weight_normalized_1 = .
gen off_support_1 = .
}

* Replicating ipw for treat_2
qui logit treat_2 $control_all_2 if ds_`var'_2!=., iterate(50) 

*if _rc==0{
if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat_2==0, d
local untreated_max = r(max)
gen off_support_2= 1 if ps > `untreated_max' & ps!=.
disp "Observations off support"
tab off_support_2

*weights 
gen ipw_weight = 1 if treat_2==1 & off_support_2 != 1
replace ipw_weight = ps/(1-ps) if treat_2==0 & off_support_2 != 1


*Normalize weights
qui sum ipw_weight if treat_2==0 & off_support_2 != 1
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat_2==1 & off_support_2 != 1
scalar n_treat=r(N)

gen ipw_weight_normalized_2 = 1 if treat_2==1 & off_support_2 != 1
replace ipw_weight_normalized_2=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat_2==0 & off_support_2 != 1

drop ps ipw_weight 
}

else{
gen ipw_weight_normalized_2 = .
gen off_support_2 = .
}


capture regress ds_`var'_1 i.treat_1 [pw=ipw_weight_normalized_1] if ds_`var'_1!=. & off_support_1 != 1

if _rc==0{
matrix coef = e(b)
scalar att1 = coef[1,2]
}

else{
scalar att1 = .
}

capture regress ds_`var'_2 i.treat_2 [pw=ipw_weight_normalized_2] if ds_`var'_2!=. & off_support_2!= 1

if _rc==0{
matrix coef = e(b)
scalar att2 = coef[1,2]
}

else{
scalar att2 = .
}

mat T1[`i',`row'] = att1 
mat T2[`i',`row'] = att2 
mat Tdiff[`i',`row'] = att1 - att2

display "Difference:" att1 - att2

estimates clear

loc row = `row' + 1

drop ipw_weight_normalized_1 ipw_weight_normalized_2 off_support_1 off_support_2

}
display "Run Done:" `i'

restore
}

local x

foreach var in $outcomes {
local x `x' ds_`var'_1
}


matrix colnames T1 = `x'

matrix list T1

putexcel set "$results/BS_SE_partner", modify
putexcel A1=matrix(T1) , names

matrix colnames T2 = `x'

matrix list T2

putexcel set "$results/BS_SE_nopartner", modify
putexcel A1=matrix(T2) , names


matrix colnames Tdiff = `x'

matrix list Tdiff

putexcel set "$results/BS_DIFF_partner", modify
putexcel A1=matrix(Tdiff) , names


********************************************************************************
log close










