cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo27_3_IPW_diff_in_diff_het_treat_job.log", replace

* Content: Estimation Inverse propensity score weighting for subgroups

clear all

capture set more off 

use "$data/final_data.dta", clear

***********************************************************************************
*1. Effekte fuer Personen, denen gekuendigt wurde 

* Deskriptionen

preserve
tab invol_loss if treat == 1 & d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .
tab invol_loss if treat == 1 & (BA_keine == 1 | BA_lehre ==1) & d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .
tab invol_loss if treat == 1 & (BA_keine == 0 & BA_lehre ==0) & d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .
restore

keep if invol_loss == 1 | treat == 0

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen involuntary job loss
global control_invol_loss "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_invol_loss), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test



********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att1 = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_invol_jobloss", modify
putexcel A1=matrix(T) , names



***********************************************************************************
*2. Effekte fuer Personen, denen nicht gekündigt wurde 

clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

tab invol_loss if treat==1

keep if invol_loss == 0 | treat == 0

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen involuntary job loss
global control_invol_loss "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_invol_loss), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att1 = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_invol_no_jobloss", modify
putexcel A1=matrix(T) , names


********************************************************************************
*5. Effekte fuer Personen mit mindestens 6 Monaten Arbeitslosigkeit
clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear


* drop if treat ist missing
drop treat
gen treat = treat_unempl_dauer_ge6

sum uspell_dauer_treat, d

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"



********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


* Kontrollvariablen Dauer > 6 Monate
global control_treat_dauer_ge6 "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_treat_dauer_ge6), atet vce(robust) aequations pstolerance(0.00000000001)

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att1 = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_uspell_dur_ge6", modify
putexcel A1=matrix(T) , names


********************************************************************************
*6. Effekte fuer Personen mit mindestens 6 Monaten Arbeitslosigkeit
clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

* drop if treat ist missing
drop treat
gen treat = treat_unempl_dauer_s6

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


* Kontrollvariablen Dauer > 6 Monate
global control_treat_dauer_s6 "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_treat_dauer_s6), atet vce(robust) aequations pstolerance(0.00000000001)

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test



********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att1 = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_uspell_dur_s6", modify
putexcel A1=matrix(T) , names


********************************************************************************
*7. Effekte nach 2 Wellen
clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

replace d_`var' = d_2_`var' if treat_unempl_2 != . & d_2_`var'!=.

}

drop treat
gen treat = treat_unempl_2

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


* Kontrollvariablen Dauer > 6 Monate
global control_treat_dauer_s6 "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_treat_dauer_s6), atet vce(robust) aequations pstolerance(0.00000000001)

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att1 = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_longterm", modify
putexcel A1=matrix(T) , names


********************************************************************************
* 8. Effekte fuer Personen, die zwischen zwei Wellen wieder Arbeit gefunden haben
clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

drop treat
gen treat = treat_employed 


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle


* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == . & treat_employed == .


* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}

* Kontrollvariablen wieder beschaeftigt
global control_treat_empl "$control_all"

* Modelldiagnose nur fuer erste Schaetzung: outcome: Lebenszufriedenheit

* Inverse propensity score weighting with logit
teffects ipw (ds_zufr_leben) (treat $control_treat_empl), atet vce(robust) aequations

* Overlap assumption
*teffects overlap, ptlevel(1) legend(lab(1 "Control") lab(2 "Treated")) title("", size(small)) xtitle("Propensity score") ytitle("Kernel density") graphregion(color(white)) bgcolor(white) saving("$log/lpo16_3_IPW_diff_in_diff_overlap", replace asis)

* Overidentification test
*tebalance overid

* Balancing test
tebalance summarize $control_all_test


********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=.

if _rc==0{

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,2]
scalar seatt = sqrt(V[2,2])

* Number of observations
qui tab treat if treat==0 & ds_`var' !=.
scalar n0 = r(N)

qui tab treat if treat==1 & ds_`var' !=.
scalar n1 = r(N)

}

else{
scalar att1 = .
scalar seatt = .
}


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}



********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_reemployedagain", modify
putexcel A1=matrix(T) , names


********************************************************************************


log close










