cap log close
set more off

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo31_3_Relation_Outcomes.log", replace

* Content: Relationship of outcome variables

********************************************************************************

use "$data/final_data_all.dta", clear

* Sample selection
keep if age >= 18 & age <= 64 & d_ausb != 1 & mig_dummy_mis == 0 & famstand_mis == 0 & gesund_einschr_mis == 0 ///
 & BA_mis == 0 & einkommenHH_mis == 0 & HHkind_mis == 0 ///
 & work_attitude_mis == 0 & soz_teil_ges_mis == 0 & soz_pos_mis == 0 & zufr_leben_mis == 0  & zufr_gesundheit_mis == 0 & seele_mis == 0 ///
 & U_ratio !=.

 
foreach var in $espell_last $firm_last{

replace `var' = 0 if `var' == .

}

**********************************************************************************************************
* FE Schätzung All

global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 
* Standardisierte Outcomes
foreach var in $outcomes{

egen s_`var' = std(`var')

}
global s_outcomes "s_zufr_leben s_seele s_depindg2 s_zufr_lebensstandard s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"

* Nur Personen, die nicht mehr nebenbei erwerbstätig sind
gen uspell_FE = 1 if uspell==1 & espell==0
replace uspell_FE = 0 if uspell!=. & uspell_FE == .


global control_all_fe "uspell_FE $control_ind $control_HH $control_partner U_ratio $control_welle"

xtset persnr welle
xtreg s_soz_teil_ges $control_all_fe, fe vce(robust)
outreg2 using "$results/FE_Schaetzung_all", ctitle("s_soz_teil_ges")  alpha(.01, .05, .10) dec(3)  replace excel 


foreach var in $s_outcomes{
xtreg `var' $control_all_fe, fe vce(robust)
outreg2 using "$results/FE_Schaetzung_all", ctitle("`var'")  alpha(.01, .05, .10) dec(3)  append excel 
}


********************************************************************************
* FE Schätzung fuer das Schätzsample

********************************************************************************
clear all

preserve

use "$data/final_data.dta", clear

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

gen final_sample = 1

keep persnr welle final_sample

save "$data/sample_id.dta", replace

restore

use "$data/final_data_all.dta", clear

merge 1:1 persnr welle using "$data/sample_id.dta"

gen help = 1 if final_sample == 1 | final_sample[_n-1] == 1

keep if help == 1
keep if selbstwirksamkeit!=.

* Schätzung basierend auf treatment indicator
gen treat_new = 0 if treat!=.
bysort persnr (welle): replace treat_new = treat[_n-1] if treat_new ==.


/*
use "$data/final_data.dta", clear

bysort persnr (welle): egen treat_max = max(treat)
keep if treat_max !=.

sort persnr welle

xtset persnr welle

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .
keep if selbstwirksamkeit!=.


* Schätzung basierend auf treatment indicator
gen treat_new = 0 if treat!=.
bysort persnr (welle): replace treat_new = treat[_n-1] if treat_new ==.
*/


global control_all_fe "$control_ind $control_HH $control_partner $espell_last $firm_last $dauern U_ratio $control_welle"
global outcomes "soz_teil_ges zufr_leben seele depindg2 anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 
global mediators "depindg2 anzahl_engefreunde engagement soz_pos selbstwirksamkeit"


* Standardisierte Outcomes
foreach var in $outcomes{

egen s_`var' = std(`var')

}

global s_mediators "s_depindg2 s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"



***********************************************************************************************************
sort persnr welle

xtset persnr welle

* Relation of outcomes


* Soziale Teilhabe gesamt
xtreg soz_teil_ges $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  replace excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B2=(e(r2_a))

xtreg soz_teil_ges depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B3=(e(r2_a)) 

xtreg soz_teil_ges anzahl_engefreunde engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B4=(e(r2_a)) 

xtreg soz_teil_ges soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B5=(e(r2_a)) 

xtreg soz_teil_ges selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B6=(e(r2_a)) 

xtreg soz_teil_ges $mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B7=(e(r2_a)) 


* Lebenzufriedenheit
xtreg zufr_leben $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C2=(e(r2_a)) 

xtreg zufr_leben depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C3=(e(r2_a)) 

xtreg zufr_leben anzahl_engefreunde engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C4=(e(r2_a)) 

xtreg zufr_leben soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C5=(e(r2_a)) 

xtreg zufr_leben selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C6=(e(r2_a)) 

xtreg zufr_leben $mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C7=(e(r2_a)) 



* Seele
xtreg seele $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D2=(e(r2_a)) 

xtreg seele depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D3=(e(r2_a)) 

xtreg seele anzahl_engefreunde engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D4=(e(r2_a)) 

xtreg seele soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D5=(e(r2_a)) 

xtreg seele selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D6=(e(r2_a)) 

xtreg seele $mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D7=(e(r2_a)) 


* Soziale Teilhabe gesamt
xtreg s_soz_teil_ges $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  replace excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B2=(e(r2_a)) 

xtreg s_soz_teil_ges s_depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B3=(e(r2_a)) 

xtreg s_soz_teil_ges s_anzahl_engefreunde s_engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B4=(e(r2_a)) 

xtreg s_soz_teil_ges s_soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B5=(e(r2_a)) 

xtreg s_soz_teil_ges s_selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B6=(e(r2_a)) 

xtreg s_soz_teil_ges $s_mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B7=(e(r2_a)) 

* Lebenzufriedenheit
xtreg s_zufr_leben $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C2=(e(r2_a)) 

xtreg s_zufr_leben s_depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C3=(e(r2_a)) 

xtreg s_zufr_leben s_anzahl_engefreunde s_engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C4=(e(r2_a)) 

xtreg s_zufr_leben s_soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C5=(e(r2_a)) 

xtreg s_zufr_leben s_selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C6=(e(r2_a)) 

xtreg s_zufr_leben $s_mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C7=(e(r2_a)) 


* Seele
xtreg s_seele $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D2=(e(r2_a)) 

xtreg s_seele s_depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D3=(e(r2_a)) 

xtreg s_seele s_anzahl_engefreunde s_engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D4=(e(r2_a)) 

xtreg s_seele s_soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D5=(e(r2_a)) 

xtreg s_seele s_selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D6=(e(r2_a)) 

xtreg s_seele $s_mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D7=(e(r2_a)) 

keep if e(sample) == 1

* Correlation of outcomes
/*
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != . 

* Duplikate erstellen
expand 2

bysort persnr welle: gen help = _n
tab help

* non-standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"


foreach var in $outcomes{

replace `var' = `var'_lead1 if help==2

}

*/


global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 
foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


global s_outcomes "s_zufr_leben s_seele s_depindg2 s_zufr_lebensstandard s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"
global ds_outcomes "ds_soz_teil_ges ds_zufr_leben ds_seele ds_depindg2 ds_zufr_lebensstandard ds_anzahl_engefreunde ds_engagement ds_soz_pos ds_selbstwirksamkeit"

********************************************************************************


* all Outcomes
disp "Correlation"
corr $outcomes
pwcorr $outcomes, star(.05)

 
matrix corr = r(C)

matrix list corr

putexcel set "$results/Correlation_matrix", modify
putexcel A1=matrix(corr) , names
 
disp "Correlation"
corr $ds_outcomes
 

disp "Cronbachs Alpha"
alpha $outcomes
 
factor $outcomes, pcf 
rotate
 
estat kmo
 /* specifies  that  the  Kaiser׍eyer׏lkin  (KMO)  measure  of  sampling  adequacy  be displayed.
KMO takes  values  between  0  and  1,  with  small  values  meaning  that  overall  the  variables have too little in common to warrant a factor analysis.
Historically, the following labels are given to values of KMO (Kaiser 1974): 0.00 to 0.49 unacceptable
0.50 to 0.59 miserable
0.60 to 0.69 mediocre
0.70 to 0.79 middling
0.80 to 0.89 meritorious
0.90 to 1.00 marvelous
*/
 
 
 estat structure
 *displays the factor structure, that is, the correlations between the variables and the common factors

 
*use https://stats.idre.ucla.edu/stat/stata/output/m255, clear
 
 * Ploychorische Korrelation

*findit polychoric // find package to calculate polychoric correlation by stas kolenikov

// See also: https://stats.idre.ucla.edu/stata/faq/how-can-i-perform-a-factor-analysis-with-categorical-or-categorical-and-continuous-variables/

/*
** Calculate polycoric correlation matrix
polychoric $outcomes
matrix r=r(R)	// Store corr mat
local N = r(sum_w)	// store no of obs


**
* - Saving vector of means (m) and sd's (s) of vars previously used in polychoric
* - m and s must be inserted into the means() and sds() options in factormat
*    if one wishes to predict factor scores AND variables used in polychoric have 
*    not been standardized before  

local colnms: coln r
di "`colnms'"

tabstat `colnms', col(s) statistics(mean sd) save
tempname A m s
mat A = r(StatTotal)
mat m = A[1..1,1..`= colsof(A)']	// 1xk-vector of item means
mat s = A[2..2,1..`= colsof(A)']	// 1xk-vector of standard deviations


** Use stored matrices for FA/PCA:
factormat r, n(`N') means(m) sds(s)
pcamat r, n(`N') means(m) sds(s)

*/

********************************************************************************
* Mediationanalysis

clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != . & d_selbstwirksamkeit != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"
global s_mediators "s_depindg2 s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


global outcomes "soz_teil_ges zufr_leben seele"
global ds_mediators_1 "ds_depindg2"
global ds_mediators_2 "ds_depindg2 ds_anzahl_engefreunde ds_engagement"
global ds_mediators_3 "ds_depindg2 ds_anzahl_engefreunde ds_engagement ds_soz_pos"
global ds_mediators_4 "ds_depindg2 ds_anzahl_engefreunde ds_engagement ds_soz_pos ds_selbstwirksamkeit"


foreach var in $outcomes{
preserve

* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
disp "Observations off support"
drop if ps > `untreated_max' & ps!=.


*weights 
gen ipw_weight = 1 if treat==1
replace ipw_weight = ps/(1-ps) if treat==0


*Normalized weights
qui sum ipw_weight if treat==0
scalar ipw_weight_sum_control = r(mean) * r(N)
qui sum ipw_weight if treat==1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0

* Ausschluss von non-treated?
gen w = ipw_weight/ipw_weight_sum_control if treat==0
sum w 


drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
}

regress ds_`var' treat [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=.
outreg2 using "$results/Mediatoranalysis", ctitle("`var'")  alpha(.01, .05, .10) sortvar(treat $ds_mediators_4) dec(3)  append excel 

regress ds_`var' treat $ds_mediators_1  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=.
outreg2 using "$results/Mediatoranalysis", ctitle("`var'")  alpha(.01, .05, .10) sortvar(treat $ds_mediators_4) dec(3)  append excel 

regress ds_`var' treat $ds_mediators_2  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=.
outreg2 using "$results/Mediatoranalysis", ctitle("`var'")  alpha(.01, .05, .10) sortvar(treat $ds_mediators_4) dec(3)  append excel 

regress ds_`var' treat $ds_mediators_3  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=.
outreg2 using "$results/Mediatoranalysis", ctitle("`var'")  alpha(.01, .05, .10) sortvar(treat $ds_mediators_4) dec(3)  append excel 

regress ds_`var' treat $ds_mediators_4  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=.
outreg2 using "$results/Mediatoranalysis", ctitle("`var'")  alpha(.01, .05, .10) sortvar(treat $ds_mediators_4) dec(3)  append excel 

estimates clear

loc row = `row' + 1


drop ipw_weight_normalized w
restore
}

********************************************************************************
* Bootstrapping of standard errors

clear all

capture set more off // damit das Programm durchlaeuft

use "$data/final_data.dta", clear


* Replizierbarkeit der Schaetzergebnisse
********************************************************************************
* set seed
****************************************************************************
set seed 123456


********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != . & d_selbstwirksamkeit != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"
global s_mediators "s_depindg2 s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"

global outcomes "soz_teil_ges zufr_leben seele"
global ds_mediators_1 "ds_depindg2"
global ds_mediators_2 "ds_depindg2 ds_anzahl_engefreunde ds_engagement"
global ds_mediators_3 "ds_depindg2 ds_anzahl_engefreunde ds_engagement ds_soz_pos"
global ds_mediators_4 "ds_depindg2 ds_anzahl_engefreunde ds_engagement ds_soz_pos ds_selbstwirksamkeit"
global mediators "depindg2 anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{
gen ds_`var' = 0 

}

foreach var in $mediators{
gen ds_`var' = 0 


}

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1


* variables

global variables "$outcomes"


foreach var in $variables{

loc row = `row' + 1

}

forvalues i = 1/$bs_runs {
mat T = J(`i',`row' - 1,.)
mat T1 = J(`i',`row' - 1,.)
mat T2 = J(`i',`row' - 1,.)
mat T3 = J(`i',`row' - 1,.)
mat T4 = J(`i',`row' - 1,.)
}


forvalues i = 1/$bs_runs {
mat S11 = J(`i',`row' - 1,.)
mat S12 = J(`i',`row' - 1,.)
mat S13 = J(`i',`row' - 1,.)
mat S14 = J(`i',`row' - 1,.)
}

forvalues i = 1/$bs_runs {
mat S21 = J(`i',`row' - 1,.)
mat S22 = J(`i',`row' - 1,.)
mat S23 = J(`i',`row' - 1,.)
}

forvalues i = 1/$bs_runs {
mat S31 = J(`i',`row' - 1,.)
mat S32 = J(`i',`row' - 1,.)
mat S33 = J(`i',`row' - 1,.)
}

forvalues i = 1/$bs_runs {
mat S41 = J(`i',`row' - 1,.)
mat S42 = J(`i',`row' - 1,.)
}

forvalues i = 1/$bs_runs {
mat S51 = J(`i',`row' - 1,.)
}


forvalues i = 1/$bs_runs {

preserve
* draw bootstrap sample
bsample, cluster(persnr)
********************************************************************************

loc row = 1

foreach var in $outcomes{
drop ds_`var'
egen ds_`var' = std(d_`var')

foreach var_med in $mediators{
drop ds_`var_med'
egen ds_`var_med' = std(d_`var_med')
}


* Replicating ipw for treat
qui logit treat $control_all if ds_`var'!=., iterate(50)

*if _rc==0{

if  e(converged) == 1 & e(ll) != 0{
predict ps if e(sample), pr

* Wer ist off support?
sum ps if treat==0, d
local untreated_max = r(max)
gen off_support = 1 if ps > `untreated_max' & ps!=.
disp "Observations off support"
tab off_support

*weights 
gen ipw_weight = 1 if treat==1 & off_support != 1
replace ipw_weight = ps/(1-ps) if treat==0 & off_support != 1


*Normalize weights
qui sum ipw_weight if treat==0 & off_support != 1
scalar ipw_weight_sum_control = r(mean) * r(N) 
qui sum ipw_weight if treat==1 & off_support != 1
scalar n_treat=r(N)

gen ipw_weight_normalized = 1 if treat==1 & off_support != 1
replace ipw_weight_normalized=(n_treat*ipw_weight)/(ipw_weight_sum_control) if treat==0 & off_support != 1

drop ps ipw_weight
}

else{
gen ipw_weight_normalized = .
gen off_support = .
}


capture regress ds_`var' i.treat [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
}

else{
scalar att = .
}


mat T[`i',`row'] = att
estimates clear

****
capture regress ds_`var' i.treat $ds_mediators_1  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
scalar b1 = coef[1,3]
}

else{
scalar att = .
scalar b1 = .
}


mat T1[`i',`row'] = att
mat S11[`i',`row'] = b1
estimates clear
****

capture regress ds_`var' i.treat $ds_mediators_2  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
scalar b1 = coef[1,3]
scalar b2 = coef[1,4]
scalar b3 = coef[1,5]
}

else{
scalar att = .
scalar b1 = .
scalar b2 = .
scalar b3 = .
}


mat T2[`i',`row'] = att
mat S12[`i',`row'] = b1
mat S21[`i',`row'] = b2
mat S31[`i',`row'] = b3
estimates clear

****

capture regress ds_`var' i.treat $ds_mediators_3  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
scalar b1 = coef[1,3]
scalar b2 = coef[1,4]
scalar b3 = coef[1,5]
scalar b4 = coef[1,6]
}

else{
scalar att = .
scalar b1 = .
scalar b2 = .
scalar b3 = .
scalar b4 = .
}


mat T3[`i',`row'] = att
mat S13[`i',`row'] = b1
mat S22[`i',`row'] = b2
mat S32[`i',`row'] = b3
mat S41[`i',`row'] = b4
estimates clear


****

capture regress ds_`var' i.treat $ds_mediators_4  [pw=ipw_weight_normalized] if ds_`var'!=. & ds_selbstwirksamkeit !=. & off_support != 1

if _rc==0{
matrix coef = e(b)
scalar att = coef[1,2]
scalar b1 = coef[1,3]
scalar b2 = coef[1,4]
scalar b3 = coef[1,5]
scalar b4 = coef[1,6]
scalar b5 = coef[1,7]
}

else{
scalar att = .
scalar b1 = .
scalar b2 = .
scalar b3 = .
scalar b4 = .
scalar b5 = .
}


mat T4[`i',`row'] = att
mat S14[`i',`row'] = b1
mat S23[`i',`row'] = b2
mat S33[`i',`row'] = b3
mat S42[`i',`row'] = b4
mat S51[`i',`row'] = b5
estimates clear





loc row = `row' + 1

drop ipw_weight_normalized off_support
}

display "Run Done:" `i'

restore
}

local x

foreach var in $outcomes {
local x `x' ds_`var'
}

matrix colnames T = `x'
matrix colnames T1 = `x'
matrix colnames T2 = `x'
matrix colnames T3 = `x'
matrix colnames T4 = `x'

matrix colnames S11 = `x'
matrix colnames S12 = `x'
matrix colnames S13 = `x'
matrix colnames S14 = `x'

matrix colnames S21 = `x'
matrix colnames S22 = `x'
matrix colnames S23 = `x'

matrix colnames S31 = `x'
matrix colnames S32 = `x'
matrix colnames S33 = `x'

matrix colnames S41 = `x'
matrix colnames S42 = `x'

matrix colnames S51 = `x'

putexcel set "$results/BS_Mediatoranalysis", sheet(Sheet1) modify
putexcel A1=matrix(T) , names

putexcel set "$results/BS_Mediatoranalysis", sheet(Sheet2) modify
putexcel A1=matrix(T1) , names

putexcel set "$results/BS_Mediatoranalysis", sheet(Sheet3) modify
putexcel A1=matrix(T2) , names

putexcel set "$results/BS_Mediatoranalysis", sheet(Sheet4) modify
putexcel A1=matrix(T3) , names

putexcel set "$results/BS_Mediatoranalysis", sheet(Sheet5) modify
putexcel A1=matrix(T4) , names

putexcel set "$results/BS_Mediatoranalysis_1", sheet(Sheet1) modify
putexcel A1=matrix(S11) , names

putexcel set "$results/BS_Mediatoranalysis_1", sheet(Sheet2) modify
putexcel A1=matrix(S12) , names

putexcel set "$results/BS_Mediatoranalysis_1", sheet(Sheet3) modify
putexcel A1=matrix(S13) , names

putexcel set "$results/BS_Mediatoranalysis_1", sheet(Sheet4) modify
putexcel A1=matrix(S14) , names

putexcel set "$results/BS_Mediatoranalysis_2", sheet(Sheet1) modify
putexcel A1=matrix(S21) , names

putexcel set "$results/BS_Mediatoranalysis_2", sheet(Sheet2) modify
putexcel A1=matrix(S22) , names

putexcel set "$results/BS_Mediatoranalysis_2", sheet(Sheet3) modify
putexcel A1=matrix(S23) , names

putexcel set "$results/BS_Mediatoranalysis_3", sheet(Sheet1) modify
putexcel A1=matrix(S31) , names

putexcel set "$results/BS_Mediatoranalysis_3", sheet(Sheet2) modify
putexcel A1=matrix(S32) , names

putexcel set "$results/BS_Mediatoranalysis_3", sheet(Sheet3) modify
putexcel A1=matrix(S33) , names

putexcel set "$results/BS_Mediatoranalysis_4", sheet(Sheet1) modify
putexcel A1=matrix(S41) , names

putexcel set "$results/BS_Mediatoranalysis_4", sheet(Sheet2) modify
putexcel A1=matrix(S42) , names

putexcel set "$results/BS_Mediatoranalysis_5", sheet(Sheet1) modify
putexcel A1=matrix(S51) , names

********************************************************************************

log close


