cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo32_3_Employment_prospects.log", replace

* Content: Impact of social exclusion on re-employment probabilities

clear all

capture set more off 


********************************************************************************

use "$data/final_data_all.dta", clear

* Sample selection
keep if age >= 18 & age <= 64 & d_ausb != 1 & mig_dummy_mis == 0 & famstand_mis == 0 & gesund_einschr_mis == 0 ///
 & BA_mis == 0 & einkommenHH_mis == 0 & HHkind_mis == 0 ///
 & work_attitude_mis == 0 & soz_teil_ges_mis == 0 & soz_pos_mis == 0 & zufr_leben_mis == 0  & zufr_gesundheit_mis == 0 & seele_mis == 0 ///
 & U_ratio !=.

 
foreach var in $espell_last $firm_last{

replace `var' = 0 if `var' == .

}

* Sind outcomes relevant für Beschäftigungswahrscheinlichkeit? 
keep if uspell == 1 & espell==0

**********************************************************************************************************
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 


foreach var in $outcomes{
egen s_`var' = std(`var')
}

global outcomes "soz_teil_ges zufr_leben seele depindg2 anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 

global s_outcomes "s_soz_teil_ges s_zufr_leben s_seele s_depindg2 s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit" 

logit utoe $s_outcomes uspell_dauer $control_ind $control_HH $control_partner $dauern U_ratio $control_welle  if uspell==1 & suche!=., vce(cluster persnr)

outreg2 using "$results/Prob_empl", ctitle("Prob u to e") stats(coef) addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  replace excel 
outreg2 using "$results/Prob_empl", ctitle("Standard errors") stats(se)addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 

tab utoe if e(sample) == 1

*margins, dydx($s_outcomes)

* Wer sucht nach einem Job?

logit suche $s_outcomes uspell_dauer $control_ind $control_HH $control_partner $dauern U_ratio $control_welle if uspell==1, vce(cluster persnr)


outreg2 using "$results/Prob_empl", ctitle("Prob suche") stats(coef) addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 
outreg2 using "$results/Prob_empl", ctitle("Standard errors") stats(se)addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 


logit suche $s_outcomes uspell_dauer $control_ind $control_HH $control_partner $dauern U_ratio $control_welle if uspell==1 & utoe!=., vce(cluster persnr)


outreg2 using "$results/Prob_empl", ctitle("Prob suche (balanced panel)") stats(coef) addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 
outreg2 using "$results/Prob_empl", ctitle("Standard errors") stats(se)addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 

*margins, dydx($s_outcomes)

* Heckman selection model
heckprobit utoe $s_outcomes $control_ind $control_HH $control_partner $dauern U_ratio $control_welle if suche !=. & utoe !=. & uspell ==1, select(suche = $s_outcomes $control_ind $control_HH $control_partner $dauern U_ratio $control_welle) vce(cluster persnr)

*****************************************************************************************************
log close










