cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo33_3_mechanism_FE.log", replace

* Content: FE-Estimation for relationship between social integration, life satisfaction and mental health

clear all

capture set more off 

********************************************************************************

use "$data/final_data_all.dta", clear

* Sample selection
keep if age >= 18 & age <= 64 & d_ausb != 1 & mig_dummy_mis == 0 & famstand_mis == 0 & gesund_einschr_mis == 0 ///
 & BA_mis == 0 & einkommenHH_mis == 0 & HHkind_mis == 0 ///
 & work_attitude_mis == 0 & soz_teil_ges_mis == 0 & soz_pos_mis == 0 & zufr_leben_mis == 0  & zufr_gesundheit_mis == 0 & seele_mis == 0 ///
 & U_ratio !=.

 
foreach var in $espell_last $firm_last{

replace `var' = 0 if `var' == .

}

**********************************************************************************************************
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 
* FE Schätzung

* Standardisierte Outcomes
foreach var in $outcomes{

egen s_`var' = std(`var')

}
global s_outcomes "s_zufr_leben s_seele s_depindg2 s_zufr_lebensstandard s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"

* Nur Personen, die nicht mehr nebenbei erwerbstätig sind
gen uspell_FE = 1 if uspell==1 & espell==0
replace uspell_FE = 0 if uspell!=. & uspell_FE == .


global control_all_fe "uspell_FE $control_ind $control_HH $control_partner U_ratio $control_welle"

xtset persnr welle
xtreg s_soz_teil_ges $control_all_fe, fe vce(robust)
outreg2 using "$results/FE_Schaetzung_all", ctitle("s_soz_teil_ges")  alpha(.01, .05, .10) dec(3)  replace excel 


foreach var in $s_outcomes{
xtreg `var' $control_all_fe, fe vce(robust)
outreg2 using "$results/FE_Schaetzung_all", ctitle("`var'")  alpha(.01, .05, .10) dec(3)  append excel 
}


********************************************************************************
* Sind outcomes relevant für Beschäftigungswahrscheinlichkeit? 
keep if uspell == 1 & espell==0

foreach var in $outcomes{

drop s_`var'
egen s_`var' = std(`var')

}

global outcomes "soz_teil_ges zufr_leben seele depindg2 anzahl_engefreunde engagement soz_pos selbstwirksamkeit" 

global s_outcomes "s_soz_teil_ges s_zufr_leben s_seele s_depindg2 s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit" 

tab utoe 

logit utoe $s_outcomes $control_ind $control_HH $control_partner $dauern U_ratio $control_welle  if uspell==1, vce(cluster persnr)

outreg2 using "$results/Prob_empl", ctitle("Prob u to e") stats(coef) addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  replace excel 
outreg2 using "$results/Prob_empl", ctitle("Standard errors") stats(se)addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 

*margins, dydx($s_outcomes)

* Wer sucht nach einem Job?

logit suche $s_outcomes $control_ind $control_HH $control_partner $dauern U_ratio $control_welle if uspell==1, vce(cluster persnr)


outreg2 using "$results/Prob_empl", ctitle("Prob suche") stats(coef) addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 
outreg2 using "$results/Prob_empl", ctitle("Standard errors") stats(se)addstat(Pseudo R2, e(r2_p)) alpha(.01, .05, .10) dec(3)  append excel 

*margins, dydx($s_outcomes)

* Heckman selection model
heckprobit utoe $s_outcomes $control_ind $control_HH $control_partner $dauern U_ratio $control_welle if suche !=. & utoe !=. & uspell ==1, select(suche = $s_outcomes $control_ind $control_HH $control_partner $dauern U_ratio $control_welle) vce(cluster persnr)

********************************************************************************
* FE Schätzung fuer das Schätzsample

********************************************************************************
use "$data/final_data.dta", clear

bysort persnr (welle): egen treat_max = max(treat)
keep if treat_max !=.

sort persnr welle

xtset persnr welle

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .
keep if selbstwirksamkeit!=.


* Schätzung basierend auf treatment indicator
gen treat_new = 0 if treat!=.
bysort persnr (welle): replace treat_new = treat[_n-1] if treat_new ==.



global control_all_fe "treat_new $control_ind $control_HH $control_partner $espell_last $firm_last $dauern U_ratio $control_welle"

global mediators "depindg2 anzahl_engefreunde engagement soz_pos selbstwirksamkeit"


* Standardisierte Outcomes
foreach var in $outcomes{

egen s_`var' = std(`var')

}

global s_mediators "s_depindg2 s_anzahl_engefreunde s_engagement s_soz_pos s_selbstwirksamkeit"



***********************************************************************************************************
* Mediator Analysis


* Soziale Teilhabe gesamt
xtreg soz_teil_ges $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  replace excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B2=(e(r2_a))

xtreg soz_teil_ges depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B3=(e(r2_a)) 

xtreg soz_teil_ges anzahl_engefreunde engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B4=(e(r2_a)) 

xtreg soz_teil_ges soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B5=(e(r2_a)) 

xtreg soz_teil_ges selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B6=(e(r2_a)) 

xtreg soz_teil_ges $mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel B7=(e(r2_a)) 


* Lebenzufriedenheit
xtreg zufr_leben $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C2=(e(r2_a)) 

xtreg zufr_leben depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C3=(e(r2_a)) 

xtreg zufr_leben anzahl_engefreunde engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C4=(e(r2_a)) 

xtreg zufr_leben soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C5=(e(r2_a)) 

xtreg zufr_leben selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C6=(e(r2_a)) 

xtreg zufr_leben $mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel C7=(e(r2_a)) 



* Seele
xtreg seele $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D2=(e(r2_a)) 

xtreg seele depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D3=(e(r2_a)) 

xtreg seele anzahl_engefreunde engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D4=(e(r2_a)) 

xtreg seele soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D5=(e(r2_a)) 

xtreg seele selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D6=(e(r2_a)) 

xtreg seele $mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_R2", modify 
putexcel D7=(e(r2_a)) 


* Soziale Teilhabe gesamt
xtreg s_soz_teil_ges $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  replace excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B2=(e(r2_a)) 

xtreg s_soz_teil_ges s_depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B3=(e(r2_a)) 

xtreg s_soz_teil_ges s_anzahl_engefreunde s_engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B4=(e(r2_a)) 

xtreg s_soz_teil_ges s_soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B5=(e(r2_a)) 

xtreg s_soz_teil_ges s_selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B6=(e(r2_a)) 

xtreg s_soz_teil_ges $s_mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Social integration")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel B7=(e(r2_a)) 

* Lebenzufriedenheit
xtreg s_zufr_leben $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C2=(e(r2_a)) 

xtreg s_zufr_leben s_depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C3=(e(r2_a)) 

xtreg s_zufr_leben s_anzahl_engefreunde s_engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C4=(e(r2_a)) 

xtreg s_zufr_leben s_soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C5=(e(r2_a)) 

xtreg s_zufr_leben s_selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C6=(e(r2_a)) 

xtreg s_zufr_leben $s_mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Subjective well-being")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel C7=(e(r2_a)) 


* Seele
xtreg s_seele $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D2=(e(r2_a)) 

xtreg s_seele s_depindg2 $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D3=(e(r2_a)) 

xtreg s_seele s_anzahl_engefreunde s_engagement $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D4=(e(r2_a)) 

xtreg s_seele s_soz_pos $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D5=(e(r2_a)) 

xtreg s_seele s_selbstwirksamkeit $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D6=(e(r2_a)) 

xtreg s_seele $s_mediators $control_all_fe , fe vce(robust)
outreg2 using "$results/FE_Schaetzung_med_s", ctitle("Mental health status")  alpha(.01, .05, .10) sortvar($s_mediators) dec(3)  append excel 

putexcel set "$results/FE_Schaetzung_med_s_R2", modify 
putexcel D7=(e(r2_a)) 


*****************************************************************************************************
log close










