cap log close

********************************************************************************
**** load data & log File                               **********************
********************************************************************************
log using "$log/lpo34_3_diff_in_diff.log", replace

* Content: Estimation conditional and unconditional difference-in-differences

clear all

capture set more off 

use "$data/final_data.dta", clear

********************************************************************************
**** Regressionen                                         **********************
********************************************************************************
sort persnr welle

* drop if treat ist missing
drop if treat == .

* Keep sample with all outcome variables
keep if d_soz_teil_ges != . &  d_zufr_leben != . &  d_zufr_lebensstandard != . & d_depindg2 !=. &  d_anzahl_engefreunde != .  & d_engagement != . &  d_seele != . &  d_soz_pos != .

* standardized outcome measures
global outcomes "soz_teil_ges zufr_leben seele depindg2 zufr_lebensstandard anzahl_engefreunde engagement soz_pos selbstwirksamkeit"

foreach var in $outcomes{

egen ds_`var' = std(d_`var')

}


*********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{

* Inverse propensity score weighting with logit
reg ds_`var' treat if ds_`var'!=., vce(cluster persnr)


* Store Estimates

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,1]
scalar seatt = sqrt(V[1,1])

* number of observations
sum ds_`var' if e(sample)==1 & treat==0
scalar n0 = r(N)
sum ds_`var' if e(sample)==1 & treat==1
scalar n1 = r(N)


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1

}


********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_DiD_unconditional", modify
putexcel A1=matrix(T) , names


*********************************************************************************

* Schaetzungen fuer alle outcome variablen
* Wird in eine Matrix geschrieben

loc row = 1

* variables

global variables "$outcomes"


foreach var in $outcomes{

loc row = `row' + 1

}


mat T = J(`row' - 1,6,.)



loc row = 1


foreach var in $outcomes{

* Inverse propensity score weighting with logit
reg ds_`var' treat $control_all if ds_`var'!=., vce(cluster persnr)


* Store Estimates

* coefficient and standard error
matrix coef = e(b)
matrix V = e(V)
scalar att = coef[1,1]
scalar seatt = sqrt(V[1,1])

* number of observations
sum ds_`var' if e(sample)==1 & treat==0
scalar n0 = r(N)
sum ds_`var' if e(sample)==1 & treat==1
scalar n1 = r(N)


mat T[`row',1] = n0
mat T[`row',2] = n1
mat T[`row',3] = att
mat T[`row',4] = seatt
mat T[`row',5] = att/seatt

* Descriptives
sum d_`var' if e(sample)==1

mat T[`row',6] = r(sd)

estimates clear

loc row = `row' + 1

}


********************************************************************************


local x

foreach var in $outcomes {
local x `x' ds_`var'
}


matrix colnames T = N_control N_treated ATT SE T SD

matrix rownames T = `x'

matrix list T

putexcel set "$results/Results_DiD_conditional", modify
putexcel A1=matrix(T) , names

********************************************************************************

gen treat_f = treat * female
gen treat_p = treat * partner
gen educ_l  = 1 if BA_akademisch==0 & BA_meister == 0
replace educ_l = 0 if  BA_akademisch==1 | BA_meister == 1
gen treat_e = treat * educ_l


* Test für Interaktionsterme

foreach var in $outcomes{

* Inverse propensity score weighting with logit
reg ds_`var' treat treat_f $control_all if ds_`var'!=., vce(cluster persnr)

}

foreach var in $outcomes{

* Inverse propensity score weighting with logit
reg ds_`var' treat treat_p $control_all if ds_`var'!=., vce(cluster persnr)

}

foreach var in $outcomes{

* Inverse propensity score weighting with logit
reg ds_`var' treat treat_e $control_all if ds_`var'!=., vce(cluster persnr)

}

********************************************************************************
log close










